@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2022, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -60,20 +62,22 @@ void Add_instance::check_cluster_members_limit() const {
 void Add_instance::resolve_local_address(
     checks::Check_type check_type, Group_replication_options *gr_options,
     const Group_replication_options &user_gr_options) {
-  auto hostname = m_target_instance->get_canonical_hostname();
-  auto communication_stack =
-      get_communication_stack(*m_cluster_impl->get_cluster_server());
+  {
+    auto hostname = m_target_instance->get_canonical_hostname();
+    auto communication_stack =
+        get_communication_stack(*m_cluster_impl->get_cluster_server());
 
-  bool check_if_busy =
-      check_type == checks::Check_type::REJOIN ? false : !m_already_member;
-  bool quiet = (check_type == checks::Check_type::REJOIN);
+    bool check_if_busy =
+        check_type == checks::Check_type::REJOIN ? false : !m_already_member;
+    bool quiet = (check_type == checks::Check_type::REJOIN);
 
-  gr_options->local_address = mysqlsh::dba::resolve_gr_local_address(
-      user_gr_options.local_address.value_or("").empty()
-          ? gr_options->local_address
-          : user_gr_options.local_address,
-      communication_stack, hostname, *m_target_instance->get_sysvar_int("port"),
-      check_if_busy, quiet);
+    gr_options->local_address = mysqlsh::dba::resolve_gr_local_address(
+        user_gr_options.local_address.value_or("").empty()
+            ? gr_options->local_address
+            : user_gr_options.local_address,
+        communication_stack, hostname,
+        *m_target_instance->get_sysvar_int("port"), check_if_busy, quiet);
+  }
 
   // Validate that the local_address value we want to use as well as the
   // local address values in use on the cluster are compatible with the
@@ -88,10 +92,11 @@ void Add_instance::check_and_resolve_instance_configuration(
     checks::Check_type check_type, bool is_switching_comm_stack) {
   Group_replication_options user_options(m_gr_opts);
 
-  bool using_clone_recovery = !m_clone_opts.recovery_method
-                                  ? false
-                                  : m_clone_opts.recovery_method.get_safe() ==
-                                        Member_recovery_method::CLONE;
+  bool using_clone_recovery =
+      !m_clone_opts.recovery_method
+          ? false
+          : m_clone_opts.recovery_method.value_or(
+                Member_recovery_method::AUTO) == Member_recovery_method::CLONE;
 
   // Check instance version compatibility with cluster.
   m_cluster_impl->check_instance_configuration(
@@ -99,8 +104,8 @@ void Add_instance::check_and_resolve_instance_configuration(
 
   // Resolve the SSL Mode to use to configure the instance.
   if (m_primary_instance) {
-    resolve_instance_ssl_mode_option(*m_target_instance, *m_primary_instance,
-                                     &m_gr_opts.ssl_mode);
+    m_gr_opts.ssl_mode = resolve_instance_ssl_mode_option(*m_target_instance,
+                                                          *m_primary_instance);
     log_info("SSL mode used to configure the instance: '%s'",
              to_string(m_gr_opts.ssl_mode).c_str());
   }
@@ -135,20 +140,19 @@ void Add_instance::refresh_target_connections() const {
   try {
     m_target_instance->reconnect_if_needed("Target");
   } catch (const shcore::Error &err) {
+    if (err.code() != ER_ACCESS_DENIED_ERROR) throw;
+
     auto cluster_coptions =
         m_cluster_impl->get_cluster_server()->get_connection_options();
-
-    if (err.code() == ER_ACCESS_DENIED_ERROR &&
-        m_target_instance->get_connection_options().get_user() !=
-            cluster_coptions.get_user()) {
-      // try again with cluster credentials
-      auto copy = m_target_instance->get_connection_options();
-      copy.set_login_options_from(cluster_coptions);
-      m_target_instance->get_session()->connect(copy);
-      m_target_instance->prepare_session();
-    } else {
+    if (m_target_instance->get_connection_options().get_user() ==
+        cluster_coptions.get_user())
       throw;
-    }
+
+    // try again with cluster credentials
+    auto copy = m_target_instance->get_connection_options();
+    copy.set_login_options_from(cluster_coptions);
+    m_target_instance->get_session()->connect(copy);
+    m_target_instance->prepare_session();
   }
 
   m_cluster_impl->refresh_connections();
@@ -246,8 +250,7 @@ void Add_instance::store_cloned_replication_account() const {
   // Get the "donor" recovery account
   auto md_inst = m_cluster_impl->get_metadata_storage()->get_md_server();
 
-  std::string recovery_user, recovery_user_host;
-  std::tie(recovery_user, recovery_user_host) =
+  auto [recovery_user, recovery_user_host] =
       m_cluster_impl->get_metadata_storage()->get_instance_repl_account(
           md_inst->get_uuid(), Cluster_type::GROUP_REPLICATION,
           Replica_type::GROUP_MEMBER);
@@ -323,7 +326,7 @@ void Add_instance::prepare(checks::Check_type check_type,
   if (add_instance) {
     try {
       mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
-          m_target_instance, m_primary_instance, m_cluster_impl->get_id());
+          *m_target_instance, *m_primary_instance, m_cluster_impl->get_id());
     } catch (const shcore::Exception &exp) {
       m_already_member =
           (exp.code() == SHERR_DBA_ASYNC_MEMBER_INCONSISTENT) ||
@@ -371,16 +374,16 @@ void Add_instance::prepare(checks::Check_type check_type,
       case mysqlsh::dba::Replication_auth_type::CERT_SUBJECT_PASSWORD:
         if (m_auth_cert_subject.empty()) {
           current_console()->print_error(shcore::str_format(
-              "The cluster's SSL mode is set to '%s' but the instance being "
-              "rejoined doesn't have a valid 'certSubject' option. Please stop "
-              "GR on that instance and then add it back using "
-              "Cluster.<<<addInstance>>>() with the appropriate authentication "
-              "options.",
+              "The Cluster's SSL mode is set to '%s' but the instance being "
+              "rejoined doesn't have the 'certSubject' option set. Please "
+              "remove the instance with Cluster.<<<removeInstance>>>() and "
+              "then add it back using Cluster.<<<addInstance>>>() with the "
+              "appropriate authentication options.",
               to_string(auth_type).c_str()));
 
           throw shcore::Exception(
               shcore::str_format(
-                  "The cluster's SSL mode is set to '%s' but the 'certSubject' "
+                  "The Cluster's SSL mode is set to '%s' but the 'certSubject' "
                   "option for the instance isn't valid.",
                   to_string(auth_type).c_str()),
               SHERR_DBA_MISSING_CERT_OPTION);
@@ -397,7 +400,7 @@ void Add_instance::prepare(checks::Check_type check_type,
       *m_target_instance,
       add_instance ? Member_op_action::ADD_INSTANCE
                    : Member_op_action::REJOIN_INSTANCE,
-      *m_clone_opts.recovery_method, m_options.interactive());
+      *m_clone_opts.recovery_method, current_shell_options()->get().wizards);
 
   // Check for various instance specific configuration issues
   check_and_resolve_instance_configuration(
@@ -465,9 +468,7 @@ void Add_instance::prepare(checks::Check_type check_type,
       get_transaction_size_limit(*m_primary_instance);
 
   // Set the paxos_single_leader option
-  // Verify whether the primary supports it, meaning it's in use. Checking if
-  // the target supports it is not valid since the target might be 8.0 and the
-  // primary 5.7
+  // Verify whether the primary supports it, meaning it's in use.
   if (supports_paxos_single_leader(m_primary_instance->get_version())) {
     m_gr_opts.paxos_single_leader =
         get_paxos_single_leader_enabled(*m_primary_instance).value_or(false);
@@ -729,8 +730,9 @@ void Add_instance::do_run() {
       }
 
       // Wait until recovery done. Will throw an exception if recovery fails.
-      m_cluster_impl->wait_instance_recovery(
-          *m_target_instance, join_begin_time, m_options.get_wait_recovery());
+      m_cluster_impl->wait_instance_recovery(*m_target_instance,
+                                             join_begin_time,
+                                             m_options.get_recovery_progress());
 
       // When clone is used, the target instance will restart and all
       // connections are closed so we need to test if the connection to the
@@ -781,7 +783,8 @@ void Add_instance::do_run() {
       // Store the username in the Metadata instances table
       if (owns_repl_user) {
         if (m_comm_stack == kCommunicationStackMySQL &&
-            m_options.get_wait_recovery() == Recovery_progress_style::NOWAIT) {
+            m_options.get_recovery_progress() ==
+                Recovery_progress_style::NOWAIT) {
           store_local_replication_account();
         } else {
           store_cloned_replication_account();
@@ -800,7 +803,7 @@ void Add_instance::do_run() {
     // may be running and the change master command will fail as the slave io
     // thread is running
     if (owns_repl_user &&
-        m_options.get_wait_recovery() != Recovery_progress_style::NOWAIT) {
+        m_options.get_recovery_progress() != Recovery_progress_style::NOWAIT) {
       restore_group_replication_account();
     }
 
@@ -848,10 +851,10 @@ void Add_instance::do_run() {
     // using clone, all members are currently using the new recovery user, which
     // means that we need to restore them all back to their corresponding users.
     {
-      auto restore_accounts =
-          (m_comm_stack == kCommunicationStackMySQL) &&
-          !recovery_certificates &&
-          (m_options.get_wait_recovery() != Recovery_progress_style::NOWAIT);
+      auto restore_accounts = (m_comm_stack == kCommunicationStackMySQL) &&
+                              !recovery_certificates &&
+                              (m_options.get_recovery_progress() !=
+                               Recovery_progress_style::NOWAIT);
       restore_accounts |= (m_comm_stack != kCommunicationStackMySQL) &&
                           recovery_certificates &&
                           (restore_clone_threshold > 0);
