@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2022, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -30,10 +32,10 @@
 #include "modules/adminapi/cluster/cluster_impl.h"
 #include "modules/adminapi/common/async_topology.h"
 #include "modules/adminapi/common/common.h"
+#include "modules/adminapi/common/connectivity_check.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/instance_validations.h"
 #include "modules/adminapi/common/metadata_storage.h"
-#include "modules/adminapi/common/undo.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/utils/logger.h"
@@ -42,10 +44,8 @@ namespace mysqlsh::dba::cluster {
 
 std::shared_ptr<Instance> Add_replica_instance::get_source_instance(
     const std::string &source) {
-  std::shared_ptr<Instance> source_instance;
-
   try {
-    source_instance = m_cluster_impl->get_session_to_cluster_instance(source);
+    return m_cluster_impl->get_session_to_cluster_instance(source);
   } catch (const shcore::Exception &e) {
     mysqlsh::current_console()->print_error(
         "Unable to use '" + source +
@@ -55,13 +55,11 @@ std::shared_ptr<Instance> Add_replica_instance::get_source_instance(
         "Source is not reachable",
         SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_UNREACHABLE);
   }
-
-  return source_instance;
 }
 
 void Add_replica_instance::validate_instance_is_standalone() {
-  TargetType::Type instance_type;
   // Check if the instance's metadata is empty, i.e. the instance is standalone
+  TargetType::Type instance_type;
   if (validate_instance_standalone(*m_target_instance, &instance_type)) return;
 
   if (instance_type == TargetType::InnoDBCluster) {
@@ -77,9 +75,10 @@ void Add_replica_instance::validate_instance_is_standalone() {
       throw shcore::Exception(
           "Target instance already part of this InnoDB Cluster",
           SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
-    } else if (m_cluster_impl->is_cluster_set_member() &&
-               m_cluster_impl->is_instance_cluster_set_member(
-                   *m_target_instance)) {
+    }
+
+    if (m_cluster_impl->is_cluster_set_member() &&
+        m_cluster_impl->is_instance_cluster_set_member(*m_target_instance)) {
       mysqlsh::current_console()->print_error(
           "The instance '" + m_target_instance->descr() +
           "' is already part of a Cluster of the ClusterSet. A new "
@@ -91,11 +90,11 @@ void Add_replica_instance::validate_instance_is_standalone() {
     }
 
     // Check if the instance's Metadata includes itself as part of this Cluster
-    auto i_metadata = std::make_shared<MetadataStorage>(m_target_instance);
+    MetadataStorage i_metadata(m_target_instance);
 
     Cluster_metadata instance_cluster_md;
-    if (i_metadata->get_cluster_for_server_uuid(m_target_instance->get_uuid(),
-                                                &instance_cluster_md)) {
+    if (i_metadata.get_cluster_for_server_uuid(m_target_instance->get_uuid(),
+                                               &instance_cluster_md)) {
       // The instance's metadata indicates it belongs to this Cluster, so it
       // must have been forcefully removed and should be possible to add it
       // back
@@ -142,7 +141,8 @@ Member_recovery_method Add_replica_instance::validate_instance_recovery() {
   return mysqlsh::dba::validate_instance_recovery(
       Cluster_type::GROUP_REPLICATION, Member_op_action::ADD_INSTANCE,
       *m_donor_instance, *m_target_instance, check_recoverable,
-      m_options.clone_options.recovery_method.get_safe(),
+      m_options.clone_options.recovery_method.value_or(
+          Member_recovery_method::AUTO),
       m_cluster_impl->get_gtid_set_is_complete(),
       current_shell_options()->get().wizards);
 }
@@ -181,10 +181,7 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
 
   // When replicationSources is set to a list of instances the main source must
   // be the first member of the list (the one with highest weight)
-  auto first_element =
-      m_options.replication_sources_option.replication_sources.begin();
-
-  std::string source_str = first_element->to_string();
+  assert(!m_options.replication_sources_option.replication_sources.empty());
 
   // Validate all sources are reachable, belong to the Cluster, and are
   // ONLINE
@@ -192,8 +189,6 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
 
   for (const auto &source :
        m_options.replication_sources_option.replication_sources) {
-    std::string source_string = source.to_string();
-
     auto source_instance = get_source_instance(source.to_string());
     Instance_metadata instance_md;
 
@@ -211,12 +206,12 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
 
       instance_md =
           m_cluster_impl->get_metadata_storage()->get_instance_by_address(
-              source_canononical_address);
+              source_canononical_address, m_cluster_impl->get_id());
     } catch (const shcore::Exception &e) {
       mysqlsh::current_console()->print_error(
-          "Unable to use '" + source_string +
-          "' as a source, instance does not belong to the Cluster: " +
-          e.format());
+          shcore::str_format("Unable to use '%s' as a source, instance does "
+                             "not belong to the Cluster: %s",
+                             source.to_string().c_str(), e.format().c_str()));
 
       throw shcore::Exception(
           "Source does not belong to the Cluster",
@@ -226,8 +221,9 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
     // Check if the instance is a Read-Replica
     if (instance_md.instance_type == Instance_type::READ_REPLICA) {
       mysqlsh::current_console()->print_error(
-          "Unable to use '" + source_string +
-          "' as a source: instance is a Read-Replica of the Cluster");
+          shcore::str_format("Unable to use '%s' as a source: instance is a "
+                             "Read-Replica of the Cluster",
+                             source.to_string().c_str()));
 
       throw shcore::Exception(
           "Invalid source type: Read-Replica",
@@ -238,9 +234,9 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
     auto state = mysqlshdk::gr::get_member_state(*source_instance);
 
     if (state != mysqlshdk::gr::Member_state::ONLINE) {
-      mysqlsh::current_console()->print_error(
-          "Unable to use '" + source_str +
-          "' as a source: instance's state is '" + to_string(state) + "'");
+      mysqlsh::current_console()->print_error(shcore::str_format(
+          "Unable to use '%s' as a source: instance's state is '%s'",
+          source.to_string().c_str(), to_string(state).c_str()));
       throw shcore::Exception(
           "Source is not ONLINE",
           SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_NOT_ONLINE);
@@ -258,41 +254,6 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
   return main_source;
 }
 
-void Add_replica_instance::check_ssl_mode() {
-  Cluster_ssl_mode ssl_mode = to_cluster_ssl_mode(
-      m_cluster_impl->get_cluster_server()->get_sysvar_string(
-          "group_replication_ssl_mode", ""));
-
-  switch (ssl_mode) {
-    case Cluster_ssl_mode::AUTO:
-      // Not possible
-      assert(0);
-      break;
-
-    case Cluster_ssl_mode::VERIFY_CA:
-      mysqlsh::current_console()->print_error(
-          "The Cluster has TLS (encryption) enabled with SSL certificate "
-          "issuer verification (VERIFY_CA) which is currently not supported in "
-          "Read-Replicas.");
-      throw shcore::Exception::runtime_error(
-          "Unsupported Cluster's sslMode: VERIFY_CA");
-
-    case Cluster_ssl_mode::VERIFY_IDENTITY:
-      mysqlsh::current_console()->print_error(
-          "The Cluster has TLS (encryption) enabled with SSL certificate "
-          "subject verification (VERIFY_IDENTITY) which is not supported in "
-          "Read-Replicas.");
-      throw shcore::Exception::runtime_error(
-          "Unsupported Cluster's sslMode: VERIFY_IDENTITY");
-
-    case Cluster_ssl_mode::NONE:
-    case Cluster_ssl_mode::DISABLED:
-    case Cluster_ssl_mode::REQUIRED:
-      log_info("SSL mode used to configure the Read-Replica: '%s'",
-               to_string(ssl_mode).c_str());
-  }
-}
-
 void Add_replica_instance::do_run() {
   auto console = mysqlsh::current_console();
 
@@ -340,20 +301,17 @@ void Add_replica_instance::do_run() {
     m_options.clone_options.check_option_values(
         m_target_instance->get_version());
 
-    // Validate and resolve the SSL mode
-    check_ssl_mode();
+    // Resolve the SSL Mode to use to configure the instance.
+    m_ssl_mode = resolve_instance_ssl_mode_option(
+        *m_target_instance, *m_cluster_impl->get_cluster_server());
+    log_info("SSL mode used to configure the instance: '%s'",
+             to_string(m_ssl_mode).c_str());
 
-    // Check if the Cluster's memberAuthType is different than password
-    if (auto auth_type = m_cluster_impl->query_cluster_auth_type();
-        auth_type != Replication_auth_type::PASSWORD) {
-      mysqlsh::current_console()->print_error(
-          "The Cluster is configured to use an authentication type different "
-          "than '" +
-          to_string(Replication_auth_type::PASSWORD) +
-          "' which is not supported in Read-Replicas.");
-      throw shcore::Exception::runtime_error(
-          "Unsupported Cluster's memberAuthType: '" + to_string(auth_type) +
-          "'");
+    // check if certSubject was correctly supplied
+    {
+      auto auth_type = m_cluster_impl->query_cluster_auth_type();
+      validate_instance_member_auth_options("cluster", false, auth_type,
+                                            m_options.cert_subject);
     }
 
     // Check the replicationSources option
@@ -372,8 +330,7 @@ void Add_replica_instance::do_run() {
     if (*m_options.clone_options.recovery_method ==
             Member_recovery_method::CLONE &&
         m_options.clone_options.clone_donor.has_value()) {
-      std::string donor = *m_options.clone_options.clone_donor;
-
+      const auto &donor = *m_options.clone_options.clone_donor;
       m_donor_instance =
           Scoped_instance(m_cluster_impl->connect_target_instance(donor));
     }
@@ -386,6 +343,27 @@ void Add_replica_instance::do_run() {
     m_options.clone_options.recovery_method = validate_instance_recovery();
   }
 
+  // Check connectivity and SSL
+  if (current_shell_options()->get().dba_connectivity_checks) {
+    console->print_info("* Checking connectivity and SSL configuration...");
+
+    auto cert_issuer = m_cluster_impl->query_cluster_auth_cert_issuer();
+    auto instance_cert_subject =
+        m_cluster_impl->query_cluster_instance_auth_cert_subject(
+            m_donor_instance->get_uuid());
+
+    mysqlshdk::mysql::Set_variable disable_sro(*m_target_instance,
+                                               "super_read_only", false, true);
+
+    auto auth_type = m_cluster_impl->query_cluster_auth_type();
+
+    test_peer_connection(*m_target_instance, "", m_options.cert_subject,
+                         *m_donor_instance, "", instance_cert_subject,
+                         m_ssl_mode, auth_type, cert_issuer, "");
+
+    console->print_info();
+  }
+
   // Create the Read-Replica:
   //
   //  - Create the replication account
@@ -399,7 +377,8 @@ void Add_replica_instance::do_run() {
 
     std::tie(ar_options, repl_account_host) =
         m_cluster_impl->create_read_replica_replication_user(
-            m_target_instance.get(), "", m_options.timeout, m_options.dry_run);
+            m_target_instance.get(), m_options.cert_subject, m_options.timeout,
+            m_options.dry_run);
 
     m_undo_tracker.add("Dropping replication account", [=, this]() {
       log_info("Dropping replication account '%s'",
@@ -444,8 +423,9 @@ void Add_replica_instance::do_run() {
 
       m_cluster_impl->handle_clone_provisioning(
           m_target_instance, m_donor_instance, ar_options, repl_account_host,
-          "", "", m_options.get_recovery_progress(), m_options.timeout,
-          m_options.dry_run);
+          m_cluster_impl->query_cluster_auth_cert_issuer(),
+          m_options.cert_subject, m_options.get_recovery_progress(),
+          m_options.timeout, m_options.dry_run);
 
       // Cancel this step from the undo_list since it's only necessary if clone
       // is cancelled/fails
@@ -470,7 +450,7 @@ void Add_replica_instance::do_run() {
     // we need a point in time as close as possible, but still earlier than
     // when recovery starts to monitor the recovery phase. The timestamp
     // resolution is timestamp(3) irrespective of platform
-    std::string join_begin_time =
+    auto join_begin_time =
         m_target_instance->queryf_one_string(0, "", "SELECT NOW(3)");
 
     // Update Metadata
@@ -489,6 +469,10 @@ void Add_replica_instance::do_run() {
           shcore::Value(join_begin_time), false,
           add_read_replica_trx_undo.get());
 
+      m_cluster_impl->get_metadata_storage()->update_instance_attribute(
+          m_target_instance->get_uuid(), k_instance_attribute_cert_subject,
+          shcore::Value(m_options.cert_subject));
+
       // Store the replication account
       m_cluster_impl->get_metadata_storage()->update_read_replica_repl_account(
           m_target_instance->get_uuid(), ar_options.repl_credentials->user,
@@ -601,9 +585,9 @@ void Add_replica_instance::do_run() {
   }
 
   console->print_info();
-  console->print_info("'" + m_target_instance->descr() +
-                      "' successfully added as a Read-Replica of Cluster '" +
-                      m_cluster_impl->get_name() + "'.");
+  console->print_info(shcore::str_format(
+      "'%s' successfully added as a Read-Replica of Cluster '%s'.",
+      m_target_instance->descr().c_str(), m_cluster_impl->get_name().c_str()));
   console->print_info();
 
   if (m_options.dry_run) {
