@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -135,6 +137,8 @@ class Cluster_impl final : public Base_cluster_impl,
   shcore::Value list_routers(bool only_upgrade_required) override;
 
   shcore::Dictionary_t routing_options(const std::string &router) override;
+  shcore::Dictionary_t router_options(
+      const shcore::Option_pack_ref<Router_options_options> &options) override;
   void set_routing_option(const std::string &option,
                           const shcore::Value &value);
   void set_routing_option(const std::string &router, const std::string &option,
@@ -148,7 +152,6 @@ class Cluster_impl final : public Base_cluster_impl,
   void set_primary_instance(
       const Connection_options &instance_def,
       const cluster::Set_primary_instance_options &options);
-  shcore::Value check_instance_state(const Connection_options &instance_def);
   void reset_recovery_password(std::optional<bool> force,
                                const bool interactive);
   void fence_all_traffic();
@@ -251,6 +254,7 @@ class Cluster_impl final : public Base_cluster_impl,
       const std::set<Managed_async_channel_source,
                      std::greater<Managed_async_channel_source>> &sources,
       const std::string &target_instance_address,
+      std::string_view target_instance_uuid, bool is_rejoin,
       std::vector<std::string> *out_sources_canonical_address = nullptr) const;
 
   cluster::Replication_sources get_read_replica_replication_sources(
@@ -520,7 +524,7 @@ class Cluster_impl final : public Base_cluster_impl,
 
   /**
    * Checks for missing metadata recovery account entries, and fix them using
-   * info from mysql.slave_master_info.
+   * info from the performance schema replication tables.
    *
    * @param allow_non_standard_format If true, account that don't follow the
    * AdminAPI format are stored, otherwise, a message is generated and the
@@ -602,7 +606,7 @@ class Cluster_impl final : public Base_cluster_impl,
 
   void ensure_compatible_clone_donor(
       const mysqlshdk::mysql::IInstance &donor,
-      const mysqlshdk::mysql::IInstance &recipient) override;
+      const mysqlshdk::mysql::IInstance &recipient) const override;
 
   // Lock methods
 
