@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2022, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -22,17 +24,17 @@
  */
 
 #include "modules/adminapi/cluster/rejoin_replica_instance.h"
+
+#include <cassert>
 #include <string>
-#include <vector>
+
 #include "modules/adminapi/cluster/api_options.h"
-#include "modules/adminapi/cluster/status.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/gtid_validations.h"
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/utils/logger.h"
-#include "mysqlshdk/libs/utils/options.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlsh::dba::cluster {
@@ -81,7 +83,7 @@ bool Rejoin_replica_instance::check_rejoinable() {
     // Check if the replicationSources are reachable and ONLINE cluster members
     m_cluster_impl->validate_replication_sources(
         m_replication_sources.replication_sources,
-        m_target_read_replica_address);
+        m_target_read_replica_address, m_target_instance->get_uuid(), true);
   }
 
   auto status = mysqlshdk::mysql::get_read_replica_status(*m_target_instance);
@@ -140,8 +142,10 @@ Member_recovery_method Rejoin_replica_instance::validate_instance_recovery() {
   return mysqlsh::dba::validate_instance_recovery(
       Cluster_type::GROUP_REPLICATION, Member_op_action::ADD_INSTANCE,
       *m_donor_instance, *m_target_instance, check_recoverable,
-      m_options.clone_options.recovery_method.get_safe(),
-      m_cluster_impl->get_gtid_set_is_complete(), m_options.interactive());
+      m_options.clone_options.recovery_method.value_or(
+          Member_recovery_method::AUTO),
+      m_cluster_impl->get_gtid_set_is_complete(),
+      current_shell_options()->get().wizards);
 }
 
 void Rejoin_replica_instance::validate_replication_channels() {
@@ -169,32 +173,24 @@ Rejoin_replica_instance::get_default_donor_instance() {
   if (m_replication_sources.source_type == Source_type::PRIMARY ||
       m_replication_sources.source_type == Source_type::SECONDARY) {
     return m_cluster_impl->get_cluster_server();
-  } else {
-    // When replicationSources is set to a list of instances the main source
-    // must be the first member of the list (the one with highest weight)
-    assert(!m_replication_sources.replication_sources.empty());
-    auto first_element = *(m_replication_sources.replication_sources.begin());
+  }
 
-    std::string source_str = first_element.to_string();
+  // When replicationSources is set to a list of instances the main source
+  // must be the first member of the list (the one with highest weight)
+  assert(!m_replication_sources.replication_sources.empty());
+  auto source_str =
+      m_replication_sources.replication_sources.begin()->to_string();
 
-    std::shared_ptr<Instance> source_instance;
-
-    try {
-      source_instance =
-          m_cluster_impl->get_session_to_cluster_instance(source_str);
-    } catch (const shcore::Exception &e) {
-      throw shcore::Exception(
-          "Source is not reachable",
-          SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_UNREACHABLE);
-    }
-
-    return source_instance;
+  try {
+    return m_cluster_impl->get_session_to_cluster_instance(source_str);
+  } catch (const shcore::Exception &) {
+    throw shcore::Exception(
+        "Source is not reachable",
+        SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_UNREACHABLE);
   }
 }
 
 void Rejoin_replica_instance::prepare() {
-  auto console = current_console();
-
   // Validate the Clone options.
   m_options.clone_options.check_option_values(m_target_instance->get_version());
 
@@ -210,13 +206,44 @@ void Rejoin_replica_instance::prepare() {
   if (*m_options.clone_options.recovery_method ==
       Member_recovery_method::CLONE) {
     if (m_options.clone_options.clone_donor.has_value()) {
-      std::string donor = *m_options.clone_options.clone_donor;
+      const std::string &donor = *m_options.clone_options.clone_donor;
 
       m_donor_instance =
           Scoped_instance(m_cluster_impl->connect_target_instance(donor));
     }
   }
 
+  // get the cert subject to use (we're in a rejoin, so it should be there, but
+  // check it anyway)
+  m_auth_cert_subject =
+      m_cluster_impl->query_cluster_instance_auth_cert_subject(
+          *m_target_instance);
+
+  switch (auto auth_type = m_cluster_impl->query_cluster_auth_type();
+          auth_type) {
+    case mysqlsh::dba::Replication_auth_type::CERT_SUBJECT:
+    case mysqlsh::dba::Replication_auth_type::CERT_SUBJECT_PASSWORD:
+      if (m_auth_cert_subject.empty()) {
+        current_console()->print_error(shcore::str_format(
+            "The Cluster's SSL mode is set to '%s' but the instance being "
+            "rejoined doesn't have the 'certSubject' option set. Please remove "
+            "the instance with Cluster.<<<removeInstance>>>() and then add it "
+            "back using Cluster.<<<addReplicaInstance>>>() with the "
+            "appropriate authentication options.",
+            to_string(auth_type).c_str()));
+
+        throw shcore::Exception(
+            shcore::str_format(
+                "The Cluster's SSL mode is set to '%s' but the 'certSubject' "
+                "option for the instance isn't valid.",
+                to_string(auth_type).c_str()),
+            SHERR_DBA_MISSING_CERT_OPTION);
+      }
+      break;
+    default:
+      break;
+  }
+
   // Validate instance configuration and state
   // Check if the instance is running MySQL >= 8.0.23
   cluster_topology_executor_ops::validate_read_replica_version(
@@ -226,7 +253,8 @@ void Rejoin_replica_instance::prepare() {
   // Ensure no pre-existing replication channels are configured
   validate_replication_channels();
 
-  console->print_info("* Checking transaction state of the instance...");
+  current_console()->print_info(
+      "* Checking transaction state of the instance...");
   m_options.clone_options.recovery_method = validate_instance_recovery();
 
   // Check if the donor is valid
@@ -235,15 +263,12 @@ void Rejoin_replica_instance::prepare() {
 }
 
 void Rejoin_replica_instance::do_run() {
-  auto console = mysqlsh::current_console();
-
   m_target_read_replica_address = m_target_instance->get_canonical_address();
 
   // Check if the instance can be rejoined
-  if (!check_rejoinable()) {
-    return;
-  }
+  if (!check_rejoinable()) return;
 
+  auto console = mysqlsh::current_console();
   console->print_info("Rejoining Read-Replica '" + m_target_instance->descr() +
                       "' to Cluster '" + m_cluster_impl->get_name() + "'...");
   console->print_info();
@@ -257,7 +282,8 @@ void Rejoin_replica_instance::do_run() {
 
   std::tie(ar_options, repl_account_host) =
       m_cluster_impl->create_read_replica_replication_user(
-          m_target_instance.get(), "", m_options.timeout, m_options.dry_run);
+          m_target_instance.get(), m_auth_cert_subject, m_options.timeout,
+          m_options.dry_run);
 
   m_undo_tracker.add("Dropping replication account", [=, this]() {
     log_info("Dropping replication account '%s'",
@@ -269,8 +295,9 @@ void Rejoin_replica_instance::do_run() {
   if (*m_options.clone_options.recovery_method ==
       Member_recovery_method::CLONE) {
     m_cluster_impl->handle_clone_provisioning(
-        m_target_instance, m_donor_instance, ar_options, repl_account_host, "",
-        "", m_options.get_recovery_progress(), m_options.timeout,
+        m_target_instance, m_donor_instance, ar_options, repl_account_host,
+        m_cluster_impl->query_cluster_auth_cert_issuer(), m_auth_cert_subject,
+        m_options.get_recovery_progress(), m_options.timeout,
         m_options.dry_run);
 
     // Clone will copy all tables, including the replication settings stored
