@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -26,8 +28,8 @@
 #include <algorithm>
 #include <iterator>
 #include <set>
-#include <utility>
 
+#include "adminapi/common/common.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/server_features.h"
@@ -37,6 +39,7 @@
 #include "mysqlshdk/libs/config/config.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "utils/utils_string.h"
 #include "utils/version.h"
 
 namespace mysqlsh {
@@ -115,7 +118,7 @@ void Rescan::ensure_unavailable_instances_not_auto_rejoining(
     try {
       auto instance = Instance::connect_raw(instance_conn_opt);
       is_rejoining = mysqlshdk::gr::is_running_gr_auto_rejoin(*instance);
-    } catch (const std::exception &e) {
+    } catch (const std::exception &) {
       // if you cant connect to the instance then we assume it really is offline
       // or unreachable and it is not auto-rejoining
     }
@@ -134,8 +137,9 @@ void Rescan::ensure_unavailable_instances_not_auto_rejoining(
 std::vector<std::string> Rescan::detect_invalid_members(
     const std::vector<mysqlshdk::db::Connection_options> &instances_list,
     bool is_active) {
-  std::vector<std::string> invalid_instances;
+  std::shared_ptr<Instance> cluster_instance = m_cluster->get_cluster_server();
 
+  std::vector<std::string> invalid_instances;
   for (const auto &cnx_opt : instances_list) {
     std::string instance_address =
         cnx_opt.as_uri(mysqlshdk::db::uri::formats::only_transport());
@@ -145,9 +149,6 @@ std::vector<std::string> Rescan::detect_invalid_members(
         "Checking if the instance '%s' is %san active member of the group.",
         instance_address.c_str(), check_type);
 
-    std::shared_ptr<Instance> cluster_instance =
-        m_cluster->get_cluster_server();
-
     if (mysqlshdk::gr::is_active_member(*cluster_instance, cnx_opt.get_host(),
                                         cnx_opt.get_port()) != is_active) {
       invalid_instances.push_back(instance_address);
@@ -245,7 +246,7 @@ void Rescan::check_mismatched_hostnames_addresses(
         bool grendpoint_valid = true;
         try {
           mysqlshdk::utils::split_host_and_port(info.first.grendpoint);
-        } catch (const std::invalid_argument &e) {
+        } catch (const std::invalid_argument &) {
           log_debug("Unable to parse endpoint: %s",
                     info.first.grendpoint.c_str());
           grendpoint_valid = false;
@@ -327,7 +328,74 @@ void Rescan::check_mismatched_hostnames_addresses(
          const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
-shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
+bool Rescan::is_clusterset_metadata_consistent() {
+  // All metadata update are atomic, to ensure consistency. On top of that, the
+  // AdminAPI reverts any failing operation to ensure there are no leftovers.
+  // To achieve that, operations are executed inside transactions:
+  //   - Create topology (Cluster, ReplicaSet, ClusterSet)
+  //   - Add instances to the topology
+  //   - Remove instances from the topology
+  //   - etc.
+  //
+  // However, there is 1 exception:
+  //   - Adding a new Replica Cluster to a ClusterSet
+  //
+  //  That operations is split into 2 transactions: Creating a new Cluster (with
+  //  its Metadata entries) and adding that Cluster to the ClusterSet's
+  //  metadata (set the ClusterSet id, etc.). If one fails and the changes are
+  //  not reverted, the Metadata becomes inconsistent.
+
+  // Check if this Cluster belongs to a ClusterSet first
+  if (!m_cluster->is_cluster_set_member()) return true;
+
+  auto cs_id = m_cluster->get_metadata().cluster_set_id;
+
+  // Iterate all Cluster's metadata
+  for (const auto &c : m_cluster->get_metadata_storage()->get_all_clusters()) {
+    // If cluster_set_id is set and the same continue looking
+    if (c.cluster_set_id == cs_id) continue;
+
+    auto console = mysqlsh::current_console();
+    console->print_warning(
+        shcore::str_format("The Cluster '%s' was detected in the ClusterSet "
+                           "Metadata, but it does not appear to be a valid "
+                           "member of the ClusterSet.",
+                           c.full_cluster_name().c_str()));
+    console->print_info();
+
+    m_invalid_clusterset_clusters.emplace_back(c);
+
+    return false;
+  }
+
+  return true;
+}
+
+void Rescan::repair_metadata() const {
+  auto metadata = m_cluster->get_metadata_storage();
+
+  mysqlsh::current_console()->print_note(
+      "Repairing Metadata inconsistencies...");
+
+  for (const auto &c : m_invalid_clusterset_clusters) {
+    log_info("Removing Cluster '%s' from the Metadata.",
+             c.full_cluster_name().c_str());
+
+    for (const auto &i : metadata->get_all_instances(c.cluster_id)) {
+      log_info("Removing Instance '%s' from the Metadata.", i.endpoint.c_str());
+    }
+  }
+
+  auto clusterset_id = m_cluster->get_clusterset_metadata().cluster_set_id;
+
+  MetadataStorage::Transaction trx(metadata);
+
+  metadata->prune_clusterset_metadata(clusterset_id);
+
+  trx.commit();
+}
+
+shcore::Value::Map_type_ref Rescan::get_rescan_report() {
   auto cluster_map = std::make_shared<shcore::Value::Map_type>();
 
   // Set the Cluster name on the result map
@@ -348,17 +416,16 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
         shcore::Value(instance.member_id);
     (*newly_discovered_instance)["name"] = shcore::Value::Null();
 
-    std::string instance_address =
-        instance.host + ":" + std::to_string(instance.port);
-
-    (*newly_discovered_instance)["host"] = shcore::Value(instance_address);
+    (*newly_discovered_instance)["host"] =
+        shcore::Value(mysqlshdk::utils::make_host_and_port(
+            instance.host, static_cast<uint16_t>(instance.port)));
 
     if (!instance.version.empty()) {
       (*newly_discovered_instance)["version"] = shcore::Value(instance.version);
     }
 
     newly_discovered_instances->push_back(
-        shcore::Value(newly_discovered_instance));
+        shcore::Value(std::move(newly_discovered_instance)));
   }
 
   std::sort(newly_discovered_instances->begin(),
@@ -448,6 +515,10 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
     (*cluster_map)["newTopologyMode"] = shcore::Value::Null();
   }
 
+  // Check if the metadata is consistent
+  (*cluster_map)["metadataConsistent"] =
+      shcore::Value(is_clusterset_metadata_consistent());
+
   return cluster_map;
 }
 
@@ -521,8 +592,7 @@ void Rescan::update_metadata_for_instance(
 
 void Rescan::remove_instance_from_metadata(
     const std::string &instance_address) {
-  mysqlshdk::db::Connection_options instance_cnx_opts =
-      shcore::get_connection_options(instance_address, false);
+  mysqlshdk::db::Connection_options instance_cnx_opts(instance_address);
 
   auto console = mysqlsh::current_console();
   console->print_info("Removing instance from the cluster metadata...");
@@ -589,13 +659,11 @@ void Rescan::add_metadata_for_instances(
       instance_cnx_opts = *list_iter;
       m_options.add_instances_list.erase(list_iter);
     } else if (m_options.auto_add) {
-      instance_cnx_opts =
-          shcore::get_connection_options(instance_address, false);
-    } else if (m_options.interactive()) {
+      instance_cnx_opts = mysqlshdk::db::Connection_options(instance_address);
+    } else if (current_shell_options()->get().wizards) {
       if (console->confirm("Would you like to add it to the cluster metadata?",
                            Prompt_answer::YES) == Prompt_answer::YES) {
-        instance_cnx_opts =
-            shcore::get_connection_options(instance_address, false);
+        instance_cnx_opts = mysqlshdk::db::Connection_options(instance_address);
       }
     }
 
@@ -628,7 +696,7 @@ void Rescan::remove_metadata_for_instances(
     } else if (m_options.auto_remove) {
       // Remove instance automatically if "auto" was used.
       remove_instance_from_metadata(instance_address);
-    } else if (m_options.interactive()) {
+    } else if (current_shell_options()->get().wizards) {
       console->print_info(
           "The instance is either offline or left the HA group. You can try "
           "to add it to the cluster again with the cluster.rejoinInstance('" +
@@ -698,7 +766,7 @@ void Rescan::update_metadata_for_instances(
 
     // Decide to add/remove instance based on given operation options.
     auto instance_cnx_opts =
-        shcore::get_connection_options(instance_address, false);
+        mysqlshdk::db::Connection_options(instance_address);
 
     update_metadata_for_instance(instance_cnx_opts,
                                  instance_map->get_uint("id"), label);
@@ -1073,7 +1141,7 @@ shcore::Value Rescan::execute() {
             "'group_replication_view_change_uuid', which is required "
             "for InnoDB ClusterSet. Configuring it requires a full Cluster "
             "reboot.");
-        if (m_options.interactive()) {
+        if (current_shell_options()->get().wizards) {
           // Prompt the user to update the View Change UUID
           if (console->confirm(
                   "Would you like 'group_replication_view_change_uuid' to be "
@@ -1169,6 +1237,32 @@ shcore::Value Rescan::execute() {
     }
   }
 
+  // Check if the Metadata is not consistent so it needs a clean-up
+  if (result->has_key("metadataConsistent") &&
+      !result->get_bool("metadataConsistent")) {
+    if (!m_options.repair_metadata.has_value()) {
+      console->print_warning(
+          "Metadata inconsistencies detected, possibly due to one or more "
+          "failed commands. Please review the topology status before "
+          "proceeding.");
+      if (current_shell_options()->get().wizards) {
+        // Prompt the user to confirm the action
+        if (console->confirm(
+                "The invalid Cluster(s) listed above will be removed from the "
+                "metadata. Do you want to proceed?",
+                Prompt_answer::YES) == Prompt_answer::YES) {
+          repair_metadata();
+        }
+      } else {
+        console->print_info(shcore::str_format(
+            "Use the '%s' option to repair the Metadata inconsistencies.",
+            kRepairMetadata));
+      }
+    } else if (*m_options.repair_metadata) {
+      repair_metadata();
+    }
+  }
+
   return shcore::Value();
 }
 
