@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -21,31 +23,22 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#include "modules/adminapi/cluster_set/create_replica_cluster.h"
+
 #include <memory>
-#include <set>
-#include <utility>
 #include <vector>
 
 #include "adminapi/common/async_topology.h"
 #include "adminapi/common/instance_validations.h"
-#include "adminapi/common/member_recovery_monitoring.h"
-#include "modules/adminapi/cluster/create_cluster_set.h"
-#include "modules/adminapi/cluster_set/create_replica_cluster.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/connectivity_check.h"
 #include "modules/adminapi/common/dba_errors.h"
-#include "modules/adminapi/common/errors.h"
 #include "modules/adminapi/common/gtid_validations.h"
-#include "modules/adminapi/common/instance_monitoring.h"
 #include "modules/adminapi/common/instance_validations.h"
-#include "modules/adminapi/common/member_recovery_monitoring.h"
 #include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/provision.h"
 #include "modules/adminapi/common/server_features.h"
-#include "mysql/clone.h"
-#include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/utils_net.h"
 #include "shellcore/console.h"
 
 namespace mysqlsh {
@@ -77,8 +70,6 @@ Create_replica_cluster::prepare_create_cluster_options() {
 
   options->gr_options.ssl_mode = m_options.gr_options.ssl_mode;
   options->gr_options.ip_allowlist = m_options.gr_options.ip_allowlist;
-  options->gr_options.ip_allowlist_option_name =
-      m_options.gr_options.ip_allowlist_option_name;
   options->gr_options.local_address = m_options.gr_options.local_address;
   options->gr_options.exit_state_action =
       m_options.gr_options.exit_state_action;
@@ -346,9 +337,10 @@ void Create_replica_cluster::prepare() {
   m_options.clone_options.recovery_method =
       m_cluster_set->validate_instance_recovery(
           Member_op_action::ADD_INSTANCE, *m_target_instance,
-          m_options.clone_options.recovery_method.get_safe(),
+          m_options.clone_options.recovery_method.value_or(
+              Member_recovery_method::AUTO),
           m_cluster_set->get_primary_cluster()->get_gtid_set_is_complete(),
-          m_options.interactive());
+          current_shell_options()->get().wizards);
 
   // check connectivity between this and the primary of the clusterset
   if (current_shell_options()->get().dba_connectivity_checks) {
@@ -457,8 +449,8 @@ shcore::Value Create_replica_cluster::execute() {
       //   - It's an ONLINE member of the Primary Cluster
       //   - It has the same version of the recipient
       //   - It has the same operating system as the recipient
-      m_cluster_set->get_primary_cluster()->ensure_compatible_clone_donor(
-          donor_instance, *m_target_instance);
+      m_cluster_set->ensure_compatible_clone_donor(donor_instance,
+                                                   *m_target_instance);
 
       m_cluster_set->handle_clone_provisioning(
           m_target_instance, donor_instance, ar_options, repl_account_host,
@@ -472,8 +464,8 @@ shcore::Value Create_replica_cluster::execute() {
                     { throw std::logic_error("debug"); });
 
     // Create a new InnoDB Cluster and update its Metadata
-    auto repl_user = *ar_options.repl_credentials;
-    auto cluster = create_cluster_object(repl_user, repl_account_host);
+    auto cluster =
+        create_cluster_object(*ar_options.repl_credentials, repl_account_host);
 
     undo_list.push_front([=, this]() {
       log_info("Revert: Dropping Cluster '%s' from Metadata",
@@ -719,6 +711,11 @@ shcore::Value Create_replica_cluster::execute() {
     console->print_error("Error creating Replica Cluster: " +
                          format_active_exception());
 
+    DBUG_EXECUTE_IF("dba_create_replica_cluster_fail_revert", {
+      undo_list.cancel();
+      throw;
+    });
+
     console->print_note("Reverting changes...");
 
     undo_list.call();
