@@ -29,6 +29,7 @@
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -117,16 +118,13 @@ struct Privilege_versions {
 // Global privs needed for managing cluster instances
 // BUG#29743910: clusterAdmin needs SELECT on *.* for tables compliance check.
 // BUG#30339460: SYSTEM_VARIABLES_ADMIN and PERSIST_RO_VARIABLES_ADMIN
-//               privileges needed to change Global system variables for 8.0
-//               servers (not for 5.7).
+//               privileges needed to change Global system variables.
 const std::vector<Privilege_versions> k_admin_global_privileges{
     {"RELOAD", Version(), Version()},
     {"SHUTDOWN", Version(), Version()},
     {"PROCESS", Version(), Version()},
     {"FILE", Version(), Version()},
     {"SELECT", Version(), Version()},
-    {"SUPER", Version(5, 7, 0),
-     Version(5, 7, 9999)},  // SUPER is exclusive of 5.7
     {"REPLICATION SLAVE", Version(), Version()},
     {"REPLICATION CLIENT", Version(), Version()},
     {"CREATE USER", Version(), Version()},
@@ -227,8 +225,15 @@ const std::map<std::string, std::map<std::string, std::set<std::string>>>
                             {"replication_group_member_stats", {"SELECT"}},
                             {"global_variables", {"SELECT"}}}},
                           {"mysql_innodb_cluster_metadata",
-                           {{"routers", {"INSERT", "UPDATE", "DELETE"}},
-                            {"v2_routers", {"INSERT", "UPDATE", "DELETE"}}}}};
+                           {
+                               {"routers", {"INSERT", "UPDATE", "DELETE"}},
+                               {"v2_routers", {"INSERT", "UPDATE", "DELETE"}},
+                               {"clusters", {"UPDATE"}},
+                               {"clustersets", {"UPDATE"}},
+                               {"v2_gr_clusters", {"UPDATE"}},
+                               {"v2_ar_clusters", {"UPDATE"}},
+                               {"v2_cs_clustersets", {"UPDATE"}},
+                           }}};
 
 std::string create_grant(const std::string &username,
                          const std::set<std::string> &privileges,
@@ -364,10 +369,19 @@ std::vector<std::string> create_router_grants(
   // tables on older metadata version from the list of tables
   std::map<std::string, std::map<std::string, std::set<std::string>>>
       router_table_grants = k_router_table_grants;
-  // For old metadata versions, there is no v2_routers table, so drop it
-  // from table_grants
-  if (metadata_version <= mysqlshdk::utils::Version(1, 0, 1)) {
+  // For old metadata versions, there is no v2_routers, v2_gr_clusters,
+  // v2_ar_clusters, and v2_cs_clustersets tables, so drop them from
+  // table_grants
+  if (metadata_version <= mysqlshdk::utils::Version(2, 0, 0)) {
     router_table_grants["mysql_innodb_cluster_metadata"].erase("v2_routers");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_gr_clusters");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_ar_clusters");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase(
+        "v2_cs_clustersets");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase("clustersets");
+    router_table_grants["mysql_innodb_cluster_metadata"].erase("clusters");
   }
 
   // privileges for tables
