@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -569,69 +571,130 @@ void Base_cluster_impl::handle_clone_provisioning(
   }
 }
 
-void Base_cluster_impl::ensure_compatible_clone_donor(
+bool Base_cluster_impl::verify_compatible_clone_versions(
+    const mysqlshdk::utils::Version &donor,
+    const mysqlshdk::utils::Version &recipient) {
+  // both must support clone (>= 8.0.17)
+  if (!supports_mysql_clone(donor) || !supports_mysql_clone(recipient))
+    return false;
+
+  // easy path: if {major.minor.patch.build/extra} are equal
+  if ((donor == recipient) && (donor.get_extra() == recipient.get_extra()))
+    return true;
+
+  // can't mix LTS with innovation releases: {major.minor} must always match
+  if (donor.numeric_version_series() != recipient.numeric_version_series())
+    return false;
+
+  // reaching this point, both donor and recipient have the same {major.minor}
+  // version but with different patch numbers and or build/extra.
+
+  const mysqlshdk::utils::Version min_mix_patch_version(8, 4, 0);
+  constexpr uint32_t mix_build_version_series(800);
+
+  // from 8.4 or newer, cloning is allowed if {major.minor} is the same (the
+  // rest is ignored)
+  if ((donor >= min_mix_patch_version) && (recipient >= min_mix_patch_version))
+    return true;
+
+  // if neither are in the 8.0 series, there's nothing to do and clone isn't
+  // supported
+  if ((donor.numeric_version_series() != mix_build_version_series) ||
+      (recipient.numeric_version_series() != mix_build_version_series))
+    return false;
+
+  // cloning is allowed if {major.minor.patch} is the same (the build/extra is
+  // ignored)
+  if (donor == recipient) return true;
+
+  // reaching this point, both donor and recipient are in the 8.0 series,
+  // {major.minor} is the same but patch (and possibly build/extra) is different
+
+  const mysqlshdk::utils::Version backported_mix_patch_version(8, 0, 37);
+
+  // cloning between different patch numbers is allowed if *both* versions
+  // are 8.0.37 or newer
+  if ((donor >= backported_mix_patch_version) &&
+      (recipient >= backported_mix_patch_version))
+    return true;
+
+  // anything else isn't supported
+  return false;
+}
+
+void Base_cluster_impl::check_compatible_clone_donor(
     const mysqlshdk::mysql::IInstance &donor,
     const mysqlshdk::mysql::IInstance &recipient) {
   /*
    * A donor is compatible if:
    *
    *   - Supports clone
-   *   - It has the same version of the recipient
+   *   - The versions of the donor and recipient are compatible
    *   - It has the same operating system as the recipient
    */
-  std::string target_address = donor.get_canonical_address();
 
-  // Check if the instance support clone
-  if (!supports_mysql_clone(donor.get_version())) {
+  // Check if the instance supports clone
+  auto donor_version = donor.get_version();
+  if (!supports_mysql_clone(donor_version)) {
     throw shcore::Exception(
-        "Instance " + target_address + " does not support MySQL Clone.",
+        shcore::str_format("Instance '%s' does not support MySQL Clone.",
+                           donor.get_canonical_address().c_str()),
         SHERR_DBA_CLONE_NO_SUPPORT);
   }
 
-  auto donor_version = donor.get_version();
-  auto recipient_version = recipient.get_version();
+  // Check version compatibility of donor / recipient
+  {
+    DBUG_EXECUTE_IF("dba_clone_version_check_fail",
+                    { donor_version = mysqlshdk::utils::Version(8, 0, 17); });
 
-  DBUG_EXECUTE_IF("dba_clone_version_check_fail",
-                  { donor_version = mysqlshdk::utils::Version(8, 0, 17); });
+    auto recipient_version = recipient.get_version();
 
-  // Check if the instance has the same version of the recipient
-  if (donor_version != recipient_version) {
-    throw shcore::Exception("Instance " + target_address +
-                                " cannot be a donor because it has a different "
-                                "version (" +
-                                donor_version.get_full() +
-                                ") than the recipient (" +
-                                recipient_version.get_full() + ").",
-                            SHERR_DBA_CLONE_DIFF_VERSION);
+    if (!Base_cluster_impl::verify_compatible_clone_versions(
+            donor_version, recipient_version)) {
+      throw shcore::Exception(
+          shcore::str_format(
+              "Instance '%s' cannot be a donor because its version (%s) isn't "
+              "compatible with the recipient's (%s).",
+              donor.get_canonical_address().c_str(),
+              donor_version.get_full().c_str(),
+              recipient_version.get_full().c_str()),
+          SHERR_DBA_CLONE_DIFF_VERSION);
+    }
   }
 
   // Check if the instance has the same OS the recipient
-  auto donor_version_compile_os = donor.get_version_compile_os();
-  auto recipient_version_compile_os = recipient.get_version_compile_os();
+  {
+    auto donor_version_compile_os = donor.get_version_compile_os();
+    auto recipient_version_compile_os = recipient.get_version_compile_os();
 
-  if (donor_version_compile_os != recipient_version_compile_os) {
-    throw shcore::Exception("Instance " + target_address +
-                                " cannot be a donor because it has a different "
-                                "Operating System (" +
-                                donor_version_compile_os +
-                                ") than the recipient (" +
-                                recipient_version_compile_os + ").",
-                            SHERR_DBA_CLONE_DIFF_OS);
+    if (donor_version_compile_os != recipient_version_compile_os) {
+      throw shcore::Exception(
+          shcore::str_format(
+              "Instance '%s' cannot be a donor because it has a different "
+              "Operating System (%s) than the recipient (%s).",
+              donor.get_canonical_address().c_str(),
+              donor_version_compile_os.c_str(),
+              recipient_version_compile_os.c_str()),
+          SHERR_DBA_CLONE_DIFF_OS);
+    }
   }
 
   // Check if the instance is running on the same platform of the recipient
-  auto donor_version_compile_machine = donor.get_version_compile_machine();
-  auto recipient_version_compile_machine =
-      recipient.get_version_compile_machine();
+  {
+    auto donor_version_compile_machine = donor.get_version_compile_machine();
+    auto recipient_version_compile_machine =
+        recipient.get_version_compile_machine();
 
-  if (donor_version_compile_machine != recipient_version_compile_machine) {
-    throw shcore::Exception(
-        "Instance " + target_address +
-            " cannot be a donor because it is running on a different "
-            "platform (" +
-            donor_version_compile_machine + ") than the recipient (" +
-            recipient_version_compile_machine + ").",
-        SHERR_DBA_CLONE_DIFF_PLATFORM);
+    if (donor_version_compile_machine != recipient_version_compile_machine) {
+      throw shcore::Exception(
+          shcore::str_format(
+              "Instance '%s' cannot be a donor because it is running on a "
+              "different platform (%s) than the recipient (%s).",
+              donor.get_canonical_address().c_str(),
+              donor_version_compile_machine.c_str(),
+              recipient_version_compile_machine.c_str()),
+          SHERR_DBA_CLONE_DIFF_PLATFORM);
+    }
   }
 }
 
@@ -679,15 +742,20 @@ std::shared_ptr<Instance> Base_cluster_impl::connect_target_instance(
   mysqlshdk::db::Connection_options connect_opts(main_opts);
 
   // overwrite address related options
-  connect_opts.clear_scheme();
   connect_opts.clear_host();
   connect_opts.clear_port();
   connect_opts.clear_socket();
   connect_opts.set_scheme(main_opts.get_scheme());
-  if (instance_def.has_host()) connect_opts.set_host(instance_def.get_host());
-  if (instance_def.has_port()) connect_opts.set_port(instance_def.get_port());
-  if (instance_def.has_socket())
+  if (instance_def.has_socket()) {
     connect_opts.set_socket(instance_def.get_socket());
+    connect_opts.set_host("localhost");
+  } else {
+    if (instance_def.has_host()) connect_opts.set_host(instance_def.get_host());
+    if (instance_def.has_port()) connect_opts.set_port(instance_def.get_port());
+  }
+  connect_opts.clear_transport_type();
+  if (instance_def.has_transport_type())
+    connect_opts.set_transport_type(instance_def.get_transport_type());
 
   // is user has specified the connect-timeout connection option, use that
   // value explicitly
@@ -820,14 +888,14 @@ void Base_cluster_impl::setup_account_common(
   // contain unsupported grants.
 
   // The pool is initialized with the metadata using the current session
-  auto metadata = std::make_shared<MetadataStorage>(get_cluster_server());
+  MetadataStorage metadata(get_cluster_server());
 
   const auto primary_instance = get_primary_master();
   shcore::on_leave_scope finally_primary([this]() { release_primary(); });
 
   // get the metadata version to build an accurate list of grants
   mysqlshdk::utils::Version metadata_version;
-  if (!metadata->check_version(&metadata_version)) {
+  if (!metadata.check_version(&metadata_version)) {
     throw std::logic_error("Internal error, metadata not found.");
   }
 
@@ -1169,8 +1237,16 @@ shcore::Dictionary_t Base_cluster_impl::routing_options(
     const std::string &router) {
   check_preconditions("routingOptions");
 
-  return router_options(get_metadata_storage().get(), get_type(), get_id(),
-                        router);
+  return mysqlsh::dba::routing_options(get_metadata_storage().get(), get_type(),
+                                       get_id(), router);
+}
+
+shcore::Dictionary_t Base_cluster_impl::router_options(
+    const shcore::Option_pack_ref<Router_options_options> &options) {
+  check_preconditions("routerOptions");
+
+  return mysqlsh::dba::router_options(get_metadata_storage().get(), get_type(),
+                                      get_id(), get_name(), *options);
 }
 
 }  // namespace dba
