@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -34,10 +36,8 @@
 #include <set>
 #include <string>
 #include <string_view>
-#include <utility>
 #include <vector>
 
-#include "modules/adminapi/common/clone_options.h"
 #include "modules/adminapi/common/cluster_types.h"
 #include "modules/adminapi/common/metadata_management_mysql.h"
 #include "modules/mod_utils.h"
@@ -202,9 +202,7 @@ inline constexpr const char kGrExitStateAction[] =
     "group_replication_exit_state_action";
 inline constexpr const char kGroupSeeds[] = "groupSeeds";
 inline constexpr const char kGrGroupSeeds[] = "group_replication_group_seeds";
-inline constexpr const char kIpWhitelist[] = "ipWhitelist";
 inline constexpr const char kIpAllowlist[] = "ipAllowlist";
-inline constexpr const char kGrIpWhitelist[] = "group_replication_ip_whitelist";
 inline constexpr const char kGrIpAllowlist[] = "group_replication_ip_allowlist";
 inline constexpr const char kLocalAddress[] = "localAddress";
 inline constexpr const char kGrLocalAddress[] =
@@ -215,7 +213,6 @@ inline constexpr const char kGrMemberWeight[] =
 inline constexpr const char kExpelTimeout[] = "expelTimeout";
 inline constexpr const char kGrExpelTimeout[] =
     "group_replication_member_expel_timeout";
-inline constexpr const char kFailoverConsistency[] = "failoverConsistency";
 inline constexpr const char kGrFailoverConsistency[] =
     "group_replication_consistency";
 inline constexpr const char kConsistency[] = "consistency";
@@ -253,10 +250,8 @@ inline constexpr const char kClusterAdminCertSubject[] =
 inline constexpr const char kClusterAdminPasswordExpiration[] =
     "clusterAdminPasswordExpiration";
 inline constexpr const char kRestart[] = "restart";
-inline constexpr const char kClearReadOnly[] = "clearReadOnly";
 inline constexpr const char kApplierWorkerThreads[] = "applierWorkerThreads";
 inline constexpr const char kMultiPrimary[] = "multiPrimary";
-inline constexpr const char kMultiMaster[] = "multiMaster";
 inline constexpr const char kForce[] = "force";
 inline constexpr const char kAdoptFromGR[] = "adoptFromGR";
 inline constexpr const char kAddInstances[] = "addInstances";
@@ -264,16 +259,15 @@ inline constexpr const char kRemoveInstances[] = "removeInstances";
 inline constexpr const char kAddUnmanaged[] = "addUnmanaged";
 inline constexpr const char kRemoveObsolete[] = "removeObsolete";
 inline constexpr const char kRejoinInstances[] = "rejoinInstances";
-inline constexpr const char kWaitRecovery[] = "waitRecovery";
 inline constexpr const char kRecoveryProgress[] = "recoveryProgress";
 inline constexpr const char kLabel[] = "label";
 inline constexpr const char kExtended[] = "extended";
 inline constexpr const char kQueryMembers[] = "queryMembers";
 inline constexpr const char kOnlyUpgradeRequired[] = "onlyUpgradeRequired";
 inline constexpr const char kUpdate[] = "update";
-inline constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
 inline constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
 inline constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
+inline constexpr const char kRepairMetadata[] = "repairMetadata";
 inline constexpr const char kAll[] = "all";
 inline constexpr const char kTimeout[] = "timeout";
 inline constexpr const char kInvalidateErrorInstances[] =
@@ -308,15 +302,15 @@ inline constexpr const char kReplicationNetworkNamespace[] = "NetworkNamespace";
 inline constexpr const char kReplicationSources[] = "replicationSources";
 inline constexpr const char kReplicationSourcesAutoPrimary[] = "primary";
 inline constexpr const char kReplicationSourcesAutoSecondary[] = "secondary";
+inline constexpr const char kRouter[] = "router";
 
 inline constexpr const int k_group_replication_members_limit = 9;
 
 // Group Replication configuration option availability regarding MySQL Server
 // version
 struct Option_availability {
-  std::string option_variable;
-  mysqlshdk::utils::Version support_in_80;
-  mysqlshdk::utils::Version support_in_57;
+  std::string option;
+  mysqlshdk::utils::Version support;
 };
 
 /**
@@ -327,22 +321,14 @@ struct Option_availability {
 inline const std::map<std::string, Option_availability>
     k_global_cluster_supported_options{
         {kExitStateAction,
-         {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12"),
-          mysqlshdk::utils::Version("5.7.24")}},
-        {kMemberWeight,
-         {kGrMemberWeight, mysqlshdk::utils::Version("8.0.11"),
-          mysqlshdk::utils::Version("5.7.20")}},
-        {kExpelTimeout,
-         {kGrExpelTimeout, mysqlshdk::utils::Version("8.0.13"), {}}},
-        {kFailoverConsistency,
-         {kGrFailoverConsistency, mysqlshdk::utils::Version("8.0.14"), {}}},
-        {kConsistency,
-         {kGrConsistency, mysqlshdk::utils::Version("8.0.14"), {}}},
+         {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12")}},
+        {kMemberWeight, {kGrMemberWeight, mysqlshdk::utils::Version("8.0.11")}},
+        {kExpelTimeout, {kGrExpelTimeout, mysqlshdk::utils::Version("8.0.13")}},
+        {kConsistency, {kGrConsistency, mysqlshdk::utils::Version("8.0.14")}},
         {kAutoRejoinTries,
-         {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16"), {}}},
-        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}, {}}},
-        {kIpAllowlist,
-         {kGrIpAllowlist, mysqlshdk::utils::Version("8.0.24"), {}}}};
+         {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16")}},
+        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}}},
+        {kIpAllowlist, {kGrIpAllowlist, mysqlshdk::utils::Version("8.0.24")}}};
 
 /**
  * List with the supported build-in tags for setOption and setInstanceOption
@@ -479,10 +465,9 @@ void resolve_ssl_mode_option(const std::string &option,
                              const mysqlshdk::mysql::IInstance &instance,
                              Cluster_ssl_mode *ssl_mode);
 
-void resolve_instance_ssl_mode_option(
+Cluster_ssl_mode resolve_instance_ssl_mode_option(
     const mysqlshdk::mysql::IInstance &instance,
-    const mysqlshdk::mysql::IInstance &pinstance,
-    Cluster_ssl_mode *member_ssl_mode);
+    const mysqlshdk::mysql::IInstance &pinstance);
 
 void validate_instance_ssl_mode(Cluster_type type,
                                 const mysqlshdk::mysql::IInstance &instance,
@@ -512,15 +497,15 @@ std::vector<MissingInstanceInfo> get_unavailable_instances(
 bool SHCORE_PUBLIC validate_cluster_group_name(
     const mysqlshdk::mysql::IInstance &instance, const std::string &group_name);
 
-bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                              std::optional<bool> clear_read_only);
+bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance);
 
 enum class Instance_rejoinability {
   REJOINABLE,
   NOT_MEMBER,
   ONLINE,
   RECOVERING,
-  READ_REPLICA
+  READ_REPLICA,
+  ERROR
 };
 
 Instance_rejoinability validate_instance_rejoinable(
