@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -27,7 +29,6 @@
 #include <list>
 #include <map>
 #include <memory>
-#include <optional>
 #include <set>
 #include <string>
 #include <utility>
@@ -37,6 +38,8 @@
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/instance_pool.h"
 #include "modules/adminapi/common/metadata_management_mysql.h"
+#include "modules/adminapi/common/router_options.h"
+#include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/undo.h"
@@ -143,7 +146,7 @@ struct Router_metadata {
   shcore::Dictionary_t tags = nullptr;
 };
 
-struct Router_options_metadata {
+struct Routing_options_metadata {
   std::map<std::string, shcore::Value> global;
   std::map<std::string, std::map<std::string, shcore::Value>> routers;
 };
@@ -227,6 +230,15 @@ class MetadataStorage {
    */
   void cleanup_for_cluster(Cluster_id cluster_id);
 
+  /**
+   * Deletes any dangling Clusters the ClusterSet's Metadata may have
+   *
+   * Ensures that any unrelated Cluster entries on the ClusterSet's Metadata are
+   * removed. Those can be resulting of failed actions, such as adding a new
+   * Replica Cluster.
+   */
+  void prune_clusterset_metadata(const Cluster_set_id &cs_id);
+
   Cluster_set_id create_cluster_set_record(
       Cluster_set_impl *cs, Cluster_id seed_cluster_id,
       shcore::Dictionary_t seed_attributes);
@@ -447,10 +459,11 @@ class MetadataStorage {
       Cluster_id cluster_id = "", bool include_read_replicas = false);
 
   Instance_metadata get_instance_by_uuid(
-      const std::string &uuid, const Cluster_id &cluster_id = "") const;
+      std::string_view uuid, const Cluster_id &cluster_id = "") const;
 
   Instance_metadata get_instance_by_address(
-      std::string_view instance_address) const;
+      std::string_view instance_address,
+      const Cluster_id &cluster_id = "") const;
 
   Instance_metadata get_instance_by_label(std::string_view label) const;
 
@@ -460,8 +473,29 @@ class MetadataStorage {
   std::vector<Router_metadata> get_routers(const Cluster_id &cluster_id);
   std::vector<Router_metadata> get_clusterset_routers(const Cluster_set_id &cs);
 
-  Router_options_metadata get_routing_options(Cluster_type type,
-                                              const std::string &id);
+  Routing_options_metadata get_routing_options(Cluster_type type,
+                                               const std::string &id);
+
+  shcore::Value get_router_options(Cluster_type type, const std::string &id,
+                                   const std::string &router_name = "");
+
+  mysqlshdk::utils::Version get_router_version(Cluster_type type,
+                                               const std::string &id,
+                                               const std::string &router_name);
+
+  mysqlshdk::utils::Version get_highest_bootstrapped_router_version(
+      Cluster_type type, const std::string &id);
+
+  mysqlshdk::utils::Version get_highest_router_configuration_schema_version(
+      Cluster_type type, const std::string &id);
+
+  shcore::Value get_default_router_options(
+      Cluster_type type, const std::string &id,
+      const mysqlshdk::utils::Version &max_version);
+
+  shcore::Value get_router_configuration_changes_schema(
+      Cluster_type type, const std::string &id,
+      const mysqlshdk::utils::Version &max_version);
 
   std::string get_cluster_name(const std::string &group_replication_group_name);
   std::string get_cluster_group_name(const std::string &cluster_name);
@@ -686,10 +720,9 @@ class MetadataStorage {
                                const char *operation, uint32_t *out_aclvid,
                                uint32_t *last_aclvid);
 
-  void set_table_tag(const std::string &tablename,
-                     const std::string &uuid_column_name,
-                     const std::string &uuid, const std::string &tagname,
-                     const shcore::Value &value);
+  void set_table_tag(std::string_view tablename,
+                     std::string_view uuid_column_name, std::string_view uuid,
+                     std::string_view tagname, const shcore::Value &value);
 
   bool cluster_sets_supported() const;
 
