@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -34,8 +36,8 @@
 #include <list>
 #include <numeric>
 #include <string>
-#include <thread>
 #include <vector>
+
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/global_topology_check.h"
@@ -43,8 +45,8 @@
 #include "modules/adminapi/common/validations.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/mysql/replication.h"
+#include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlsh {
@@ -131,11 +133,12 @@ void validate_unsupported_options(
         SHERR_DBA_UNSUPPORTED_ASYNC_CONFIGURATION);
   };
 
-  if (master_info.enabled_auto_position == 0) {
-    throw shcore::Exception(target +
-                                " uses replication without auto-positioning, "
-                                "which is not supported by the AdminAPI.",
-                            SHERR_DBA_UNSUPPORTED_ASYNC_CONFIGURATION);
+  if (!master_info.enabled_auto_position) {
+    throw shcore::Exception(
+        shcore::str_format("%s uses replication without auto-positioning, "
+                           "which is not supported by the AdminAPI.",
+                           target.c_str()),
+        SHERR_DBA_UNSUPPORTED_ASYNC_CONFIGURATION);
   }
 
   constexpr auto k_default_connect_retry = 60;
@@ -151,11 +154,10 @@ void validate_unsupported_options(
   check_equal(std::string(source_term + "_CONNECT_RETRY").c_str(),
               master_info.connect_retry, k_default_connect_retry);
   check_equal(std::string(source_term + "_SSL_VERIFY_SERVER_CERT").c_str(),
-              master_info.ssl_verify_server_cert, 0);
+              master_info.ssl_verify_server_cert ? 1 : 0, 0);
   check_double_equal(std::string(source_term + "_HEARTBEAT_PERIOD").c_str(),
                      master_info.heartbeat_period, k_default_heartbeat_period);
   check_blank(std::string(source_term + "_BIND").c_str(), master_info.bind);
-  check_strequal("IGNORE_SERVER_IDS", master_info.ignored_server_ids, "0");
   check_equal(std::string(source_term + "_RETRY_COUNT").c_str(),
               master_info.retry_count, k_default_retry_count);
   check_blank(std::string(source_term + "_PUBLIC_KEY_PATH").c_str(),
@@ -168,9 +170,7 @@ void validate_unsupported_options(
   check_equal(std::string(source_term + "_DELAY").c_str(),
               channel.relay_log_info.sql_delay, 0);
   check_blank("PRIVILEGE_CHECKS_USER",
-              channel.relay_log_info.privilege_checks_username.value_or(""));
-  check_blank("PRIVILEGE_CHECKS_USER",
-              channel.relay_log_info.privilege_checks_hostname.value_or(""));
+              channel.relay_log_info.privilege_checks_user.value_or(""));
 
   // channel.relay_log_info.require_row_format is allowed. It's new in 8.0.19
   // and if it's set to 1, it requires the binlog_format to be ROW, which is
@@ -214,6 +214,16 @@ void Star_global_topology_manager::validate_adopt_cluster(
       throw shcore::Exception("Unsupported replication topology",
                               SHERR_DBA_UNSUPPORTED_ASYNC_TOPOLOGY);
     }
+
+    for (const auto &replica : server->get_primary_member()->invalid_replicas) {
+      console->print_error(shcore::str_format(
+          "Ignoring replica '%s', connected to '%s', because its address can't "
+          "be resolved: '%s'.",
+          replica.uuid.c_str(), server->label.c_str(),
+          mysqlshdk::utils::make_host_and_port(replica.host, replica.port)
+              .c_str()));
+    }
+
     if (!server->get_primary_member()->unmanaged_replicas.empty()) {
       console->print_error(
           server->label +
