@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -94,9 +96,6 @@ class SHCORE_PUBLIC ClassicSession
   std::shared_ptr<ClassicResult> _commit();
   std::shared_ptr<ClassicResult> _rollback();
 
-  std::shared_ptr<ClassicResult> query(const std::string &query,
-                                       const shcore::Array_t &args = {});
-
   std::vector<mysqlshdk::db::Query_attribute> query_attributes() const override;
 
   std::shared_ptr<ClassicResult> run_sql(const std::string &query,
@@ -138,7 +137,6 @@ class SHCORE_PUBLIC ClassicSession
   String getUri();
   String getSshUri();
   ClassicResult runSql(String query, Array args = []);
-  ClassicResult query(String query, Array args = []);
   Undefined close();
   ClassicResult startTransaction();
   ClassicResult commit();
@@ -151,7 +149,6 @@ class SHCORE_PUBLIC ClassicSession
   str get_uri();
   str get_ssh_uri();
   ClassicResult run_sql(str query, list args = []);
-  ClassicResult query(str query, list args = []);
   None close();
   ClassicResult start_transaction();
   ClassicResult commit();
