@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -25,26 +27,15 @@
 #include <memory>
 #include <vector>
 
-#include "modules/adminapi/common/common.h"
-#include "modules/devapi/base_database_object.h"
 #include "modules/devapi/mod_mysqlx_schema.h"
 #include "modules/devapi/mod_mysqlx_session.h"
-#include "modules/mod_mysql_session.h"
 #include "modules/mod_utils.h"
-#include "modules/mysqlxtest_utils.h"
 #include "mysqlshdk/include/scripting/shexcept.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
-#include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
-#include "mysqlshdk/include/shellcore/shell_notifications.h"
 #include "mysqlshdk/include/shellcore/shell_resultset_dumper.h"
 #include "mysqlshdk/include/shellcore/utils_help.h"
-#include "mysqlshdk/libs/db/utils_connection.h"
-#include "mysqlshdk/libs/ssh/ssh_common.h"
 #include "mysqlshdk/libs/utils/strformat.h"
-#include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/libs/utils/utils_path.h"
 #include "mysqlshdk/shellcore/credential_manager.h"
 
 using namespace std::placeholders;
@@ -594,9 +585,7 @@ The following options are also valid when a dictionary is used:
 @li uri: a URI string.
 @li scheme: the protocol to be used on the connection.
 @li user: the MySQL user name to be used on the connection.
-@li dbUser: alias for user.
 @li password: the password to be used on the connection.
-@li dbPassword: same as password.
 @li host: the hostname or IP address to be used on the connection.
 @li port: the port to be used in a TCP connection.
 @li socket: the socket file name to be used on a connection through unix sockets.
@@ -609,8 +598,6 @@ The following options are also valid when a dictionary is used:
 @li ssh-identity-file-password: the SSH key file password.
 @li ssh-config-file: the SSH configuration file, default is the value of shell.options['ssh.configFile']
 
-@attention The dbUser and dbPassword options are will be removed in a future release.
-
 @attention The connection options have precedence over options specified in the connection options uri
 
 The connection options are case insensitive and can only be defined once.
@@ -977,7 +964,7 @@ std::shared_ptr<ShellBaseSession> Shell::open_session(
   if (connection_options_.has_data()) {
     auto connection_options = connection_options_;
     mysqlsh::set_password_from_string(&connection_options, password);
-    return _shell->connect(connection_options, false, false);
+    return _shell->connect(connection_options, false);
   } else {
     auto session = _shell_core->get_dev_session();
 
@@ -986,7 +973,7 @@ std::shared_ptr<ShellBaseSession> Shell::open_session(
           "An open session is required when duplicating sessions.");
     }
 
-    return _shell->connect(session->get_connection_options(), false, false);
+    return _shell->connect(session->get_connection_options(), false);
   }
 }
 
@@ -1208,7 +1195,7 @@ bool Shell::reconnect() {
       session->reconnect();
       ret_val = true;
     }
-  } catch (const shcore::Exception &e) {
+  } catch (const shcore::Exception &) {
   }
 
   return ret_val;
@@ -1350,20 +1337,19 @@ Undefined Shell::storeCredential(String url, String password) {}
 #elif DOXYGEN_PY
 None Shell::store_credential(str url, str password) {}
 #endif
-void Shell::store_credential(
-    const std::string &url,
-    const mysqlshdk::utils::nullable<std::string> &password) {
+void Shell::store_credential(const std::string &url,
+                             std::optional<std::string> password) {
   std::string pwd_to_store;
-  if (password.is_null()) {
-    const std::string prompt =
-        "Please provide the password for '" + url + "': ";
+  if (!password.has_value()) {
+    auto prompt = shcore::str_format("Please provide the password for '%s': ",
+                                     url.c_str());
     const auto result =
         current_console()->prompt_password(prompt, &pwd_to_store);
     if (result != shcore::Prompt_result::Ok) {
       throw shcore::cancelled("Cancelled");
     }
   } else {
-    pwd_to_store = *password;
+    pwd_to_store = std::move(*password);
   }
 
   shcore::Credential_manager::get().store_credential(url, pwd_to_store);
