@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -55,7 +57,7 @@ namespace {
 Connection_options get_connection_options(const std::string &instance_def) {
   if (instance_def.empty()) throw std::invalid_argument("Invalid URI: empty.");
 
-  auto ret_val = shcore::get_connection_options(instance_def, false);
+  auto ret_val = Connection_options(instance_def);
   for (const auto &warning : ret_val.get_warnings())
     mysqlsh::current_console()->print_warning(warning);
   ret_val.clear_warnings();
@@ -468,22 +470,56 @@ std::shared_ptr<mysqlshdk::db::ISession> create_session(
 void password_prompt(Connection_options *options) {
   const std::string uri =
       options->as_uri(mysqlshdk::db::uri::formats::user_transport());
-  const std::string prompt = "Please provide the password for '" + uri + "': ";
-  std::string answer;
-  const auto result = current_console()->prompt_password(prompt, &answer);
+  for (int factor = 0; factor < mysqlshdk::db::k_max_auth_factors; factor++) {
+    if (!options->should_prompt_password(factor)) continue;
+    const std::string prompt = "Please provide the password" +
+                               (factor == 0 ? "" : std::to_string(factor + 1)) +
+                               " for '" + uri + "': ";
+    std::string answer;
+    const auto result = current_console()->prompt_password(prompt, &answer);
 
-  if (result == shcore::Prompt_result::Ok) {
-    options->set_password(answer);
-  } else {
-    throw shcore::cancelled("Cancelled");
+    if (result == shcore::Prompt_result::Ok) {
+      options->set_mfa_password(factor, answer);
+    } else {
+      throw shcore::cancelled("Cancelled");
+    }
   }
 }
 
 }  // namespace
 
+/**
+ * Password Retrieval Logic
+ *
+ * When attempting to create a connection the connection data will be taken from
+ * the following sources in order of precedence:
+ *
+ * 1) Options File
+ * 2) Login Path
+ * 3) Command line options
+ * 4) Stored Password
+ * 5) Interactive Password Prompt
+ *
+ * Connection Option Resolution
+ * ============================
+ * Fron 1 to 3 the last connection option found overrides earlier occurrences.
+ *
+ * In 3, the right-most option overrides any previous definition.
+ *
+ * 4 and 5 are specific to passwords and are used only if the password is not
+ * defined by any of the previous means.
+ *
+ *
+ * Disabling Elements
+ * ==================
+ * Usage of options file is disabled through --no-defaults
+ * Usage of Login Path is disabled through --no-login-paths
+ * Usage of Stored Passwords is disabled through -p
+ */
+
 std::shared_ptr<mysqlshdk::db::ISession> establish_session(
     const Connection_options &options, bool prompt_for_password,
-    bool prompt_in_loop) {
+    bool prompt_in_loop, bool enable_stored_passwords) {
   FI_SUPPRESS(mysql);
   FI_SUPPRESS(mysqlx);
 
@@ -497,7 +533,8 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
       mysqlshdk::ssh::current_ssh_manager()->create_tunnel(&ssh);
     }
 
-    if (!copy.has_password() && copy.has_user()) {
+    // TODO(alfredo) - password storage for MFA needs to be figured out
+    if (!copy.has_password() && copy.has_user() && enable_stored_passwords) {
       if (shcore::Credential_manager::get().get_password(&copy)) {
         try {
           return create_session(copy);
@@ -505,7 +542,10 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
           if (e.code() != ER_ACCESS_DENIED_ERROR) {
             throw;
           } else {
-            copy.clear_password();
+            // we don't which password was wrong, so assume all of them were
+            for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++)
+              copy.clear_mfa_password(f);
+
             shcore::Credential_manager::get().remove_password(copy);
             log_info(
                 "Connection to \"%s\" could not be established using the "
@@ -521,8 +561,17 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
     if (prompt_for_password) {
       do {
         bool prompted_for_password = false;
+        bool should_prompt = false;
+        for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++) {
+          if (copy.should_prompt_password(f)) {
+            should_prompt = true;
+            break;
+          }
+        }
 
-        if (!copy.has_password() && copy.has_user() &&
+        // TODO(alfredo) - kerberos/oci should disable password prompt in
+        // shell_options
+        if (should_prompt && copy.has_user() &&
             !copy.is_auth_method(mysqlshdk::db::kAuthMethodKerberos) &&
             !copy.is_auth_method(mysqlshdk::db::kAuthMethodOci)) {
           password_prompt(&copy);
@@ -579,7 +628,6 @@ Connection_options get_classic_connection_options(
   auto co = session->get_connection_options();
   // switch from X protocol to classic
   if (SessionType::Classic != co.get_session_type()) {
-    co.clear_scheme();
     co.set_scheme("mysql");
 
     if (co.has_port()) {
@@ -592,7 +640,6 @@ Connection_options get_classic_connection_options(
             "connection");
       }
 
-      co.clear_port();
       co.set_port(row->get_int(0));
 
       // if we're here, we clear up local port, so establish session will find
