@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -29,6 +31,7 @@
 
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_lexing.h"
+#include "mysqlshdk/libs/utils/utils_sqlstring.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlsh {
@@ -55,6 +58,7 @@ const std::set<std::string> k_mysqlaas_allowed_privileges = {
     "INSERT",
     "LOCK TABLES",
     "PROCESS",
+    "PROXY",  // this privilege is granted to the initial user account itself
     "REFERENCES",
     "REPLICATION CLIENT",
     "REPLICATION SLAVE",
@@ -74,15 +78,10 @@ const std::set<std::string> k_mysqlaas_allowed_privileges = {
     "FLUSH_USER_RESOURCES",
     "REPLICATION_APPLIER",
     "ROLE_ADMIN",
+    "SHOW_ROUTINE",
     "XA_RECOVER_ADMIN",
 };
 
-const std::set<std::string> k_mysqlaas_allowed_authentication_plugins = {
-    "caching_sha2_password",
-    "mysql_native_password",
-    "sha256_password",
-};
-
 const std::unordered_set<std::string> k_mds_users_with_system_user_priv = {
     "mysql.infoschema", "mysql.session", "mysql.sys",
     "ociadmin",         "ocidbm",        "ocirpl",
@@ -1105,24 +1104,27 @@ Deferred_statements check_create_table_for_indexes(
   return ret;
 }
 
-std::string check_create_user_for_authentication_plugin(
-    const std::string &create_user, const std::set<std::string> &plugins) {
+std::set<std::string> check_create_user_for_authentication_plugins(
+    std::string_view create_user) {
   SQL_iterator it(create_user, 0, false);
 
   create_user_parse_account(&it);
 
-  if (shcore::str_caseeq(it.next_token(), "IDENTIFIED") &&
-      shcore::str_caseeq(it.next_token(), "WITH")) {
-    std::string auth_plugin{it.next_token()};
+  std::set<std::string> result;
 
-    unquote_string(&auth_plugin);
+  while (it) {
+    if (it.consume_tokens("IDENTIFIED", "WITH")) {
+      std::string auth_plugin{it.next_token()};
 
-    if (plugins.end() == plugins.find(auth_plugin)) {
-      return auth_plugin;
+      unquote_string(&auth_plugin);
+
+      if (!auth_plugin.empty()) {
+        result.emplace(std::move(auth_plugin));
+      }
     }
   }
 
-  return "";
+  return result;
 }
 
 bool check_create_user_for_empty_password(const std::string &create_user) {
@@ -1539,8 +1541,8 @@ std::string convert_grant_to_create_user(
   }
 
   // move to the account name
-  while (it.valid() && !shcore::str_caseeq(it.next_token(), "TO"))
-    ;
+  while (it.valid() && !shcore::str_caseeq(it.next_token(), "TO")) {
+  }
 
   auto create_user = "CREATE USER " + get_account(&it);
   auto grant = statement.substr(0, it.position());
@@ -1651,45 +1653,146 @@ bool contains_sensitive_information(const std::string &statement) {
   return false;
 }
 
-std::string replace_quoted_strings(const std::string &statement,
-                                   std::string_view replacement,
-                                   std::vector<std::string> *replaced) {
+std::string hide_sensitive_information(
+    const std::string &statement, std::string_view replacement,
+    std::vector<std::string_view> *replaced) {
   assert(replaced);
-
   replaced->clear();
 
-  std::string rewritten;
-  SQL_iterator it(statement, 0, false);
   const auto starts_with_quote = [](std::string_view s) {
-    return '\'' == s[0] || '"' == s[0];
-  };
-  const auto needs_quotes = !starts_with_quote(replacement);
-
-  while (it) {
-    auto token = it.next_token();
-
-    if (starts_with_quote(token)) {
-      if (needs_quotes) {
-        rewritten += '"';
-      }
-
-      rewritten += replacement;
-
-      if (needs_quotes) {
-        rewritten += '"';
-      }
-
-      replaced->emplace_back(std::move(token));
-    } else {
-      rewritten += token;
+    if (s.empty()) {
+      return false;
     }
 
-    if (std::isspace(statement[it.position()])) {
-      rewritten += ' ';
+    return '\'' == s[0] || '"' == s[0];
+  };
+
+  Offsets offsets;
+  std::string_view token;
+  SQL_iterator it(statement, 0, false);
+
+  const auto advance = [&]() { token = it.next_token(); };
+  const auto maybe_hide_and_advance = [&]() {
+    if (!starts_with_quote(token)) {
+      return false;
+    }
+
+    offsets.emplace_back(it.position() - token.length(), it.position());
+    replaced->emplace_back(token);
+    advance();
+
+    return true;
+  };
+  const auto hide_and_advance = [&]() {
+    [[maybe_unused]] const auto result = maybe_hide_and_advance();
+    assert(result);
+  };
+
+  advance();
+
+  if (shcore::str_caseeq(token, "SET")) {
+    advance();
+
+    if (shcore::str_caseeq(token, "PASSWORD")) {
+      // replace all quoted strings
+      advance();
+
+      if (shcore::str_caseeq(token, "FOR")) {
+        // skip the account
+        get_account(&it);
+        advance();
+      }
+
+      do {
+        if (!maybe_hide_and_advance()) {
+          advance();
+        }
+      } while (!token.empty());
     }
   }
 
-  return rewritten;
+  do {
+    if (shcore::str_ibeginswith(token, "PASSWORD") ||
+        shcore::str_iendswith(token, "PASSWORD")) {
+      advance();
+
+      if ("=" == token || "(" == token) {
+        // assignment or function call
+        advance();
+        hide_and_advance();
+      } else {
+        // next item should be the one we hide, don't search further (this could
+        // be i.e. PASSWORD EXPIRE)
+        maybe_hide_and_advance();
+      }
+    } else if (shcore::str_caseeq(token, "IDENTIFIED")) {
+      advance();
+
+      // IDENTIFIED {VIA|WITH} authentication_rule [OR authentication_rule  ...]
+      bool mariadb = false;
+
+      do {
+        if ((!mariadb && shcore::str_caseeq(token, "WITH", "VIA")) ||
+            (mariadb && shcore::str_caseeq(token, "OR"))) {
+          // read authentication plugin
+          advance();
+          // read keyword
+          advance();
+        }
+
+        if (!mariadb && shcore::str_caseeq(token, "BY")) {
+          advance();
+
+          if (shcore::str_caseeq(token, "PASSWORD")) {
+            advance();
+          }
+
+          if (shcore::str_caseeq(token, "RANDOM")) {
+            advance();
+
+            if (shcore::str_caseeq(token, "PASSWORD")) {
+              advance();
+            }
+          } else {
+            hide_and_advance();
+          }
+
+          if (shcore::str_caseeq(token, "REPLACE")) {
+            advance();
+            hide_and_advance();
+          }
+        } else if (shcore::str_caseeq(token, "AS", "USING")) {
+          advance();
+
+          if (shcore::str_caseeq(token, "PASSWORD")) {
+            // read (
+            advance();
+            // read 'password'
+            advance();
+            // hide and read )
+            hide_and_advance();
+            // read next token
+            advance();
+          } else {
+            hide_and_advance();
+          }
+        }
+
+        mariadb = shcore::str_caseeq(token, "OR");
+      } while (mariadb);
+    } else {
+      advance();
+    }
+  } while (!token.empty());
+
+  if (offsets.empty()) {
+    return statement;
+  } else {
+    const auto target = starts_with_quote(replacement)
+                            ? std::string{replacement}
+                            : shcore::quote_sql_string(replacement);
+    return replace_at_offsets(statement, offsets, target);
+  }
 }
 
 bool parse_grant_statement(const std::string &statement,
@@ -1709,75 +1812,118 @@ bool parse_grant_statement(const std::string &statement,
   }
 
   bool object_is_routine = false;
+  bool is_role = false;
+  std::vector<std::string> privileges;
 
   {
     bool all_privileges_done = false;
     bool privilege_done = false;
 
     do {
-      auto privilege = shcore::str_upper(it.next_token());
+      std::string privilege{it.next_token()};
 
       do {
-        auto token = it.next_token();
-
-        if (shcore::str_caseeq(token, result.grant ? "TO" : "FROM")) {
-          // this is GRANT role, we're not interested in these
+        if (!it.valid()) {
           return false;
         }
 
-        if (shcore::str_caseeq(token, "(")) {
-          // column-level privilege, move past column_list
-          do {
-            token = it.next_token();
-          } while (!shcore::str_caseeq(token, ")"));
+        auto token = it.next_token();
 
-          // read next token (either , or ON)
-          token = it.next_token();
+        if (!is_role && shcore::str_caseeq(token, "@")) {
+          is_role = true;
         }
 
-        privilege_done = shcore::str_caseeq(token, ",");
-        all_privileges_done = shcore::str_caseeq(token, "ON");
+        if (is_role) {
+          if (shcore::str_caseeq(token, "@")) {
+            privilege += '@';
+            privilege += it.next_token();
 
-        if (!privilege_done && !all_privileges_done) {
-          privilege += ' ';
-          privilege += shcore::str_upper(token);
-        } else {
-          if (privilege == "EXECUTE" || privilege == "ALTER ROUTINE") {
-            object_is_routine = true;
+            token = it.next_token();
           }
 
-          result.privileges.emplace(std::move(privilege));
+          privilege_done = true;
+          all_privileges_done =
+              shcore::str_caseeq(token, result.grant ? "TO" : "FROM");
+        } else {
+          if (shcore::str_caseeq(token, "(")) {
+            // column-level privilege, move past column_list
+            do {
+              token = it.next_token();
+            } while (!shcore::str_caseeq(token, ")"));
+
+            // read next token (either , or ON)
+            token = it.next_token();
+          }
+
+          privilege_done = shcore::str_caseeq(token, ",");
+
+          if (shcore::str_caseeq(token, result.grant ? "TO" : "FROM")) {
+            // this is GRANT/REVOKE role
+            all_privileges_done = is_role = true;
+          } else {
+            all_privileges_done = shcore::str_caseeq(token, "ON");
+          }
+
+          if (!privilege_done && !all_privileges_done) {
+            privilege += ' ';
+            privilege += token;
+          } else {
+            if (shcore::str_caseeq(privilege, "EXECUTE") ||
+                shcore::str_caseeq(privilege, "ALTER ROUTINE")) {
+              object_is_routine = true;
+            }
+          }
+        }
+
+        if (privilege_done || all_privileges_done) {
+          privileges.emplace_back(std::move(privilege));
         }
       } while (!privilege_done && !all_privileges_done);
     } while (!all_privileges_done);
   }
 
-  if (!it.valid() || result.privileges.count("PROXY")) {
+  if (!it.valid()) {
     return false;
   }
 
-  auto priv_level = it.next_token();
+  if (is_role) {
+    result.level = Privilege_level_info::Level::ROLE;
+  } else {
+    for (auto &p : privileges) {
+      if (shcore::str_caseeq(p, "PROXY")) {
+        return false;
+      }
 
-  if (shcore::str_caseeq(priv_level, "TABLE")) {
-    object_is_routine = false;
-    // priv_level follows
-    priv_level = it.next_token();
-  } else if (shcore::str_caseeq(priv_level, "FUNCTION", "PROCEDURE")) {
-    object_is_routine = true;
-    // priv_level follows
-    priv_level = it.next_token();
+      p = shcore::str_upper(p);
+    }
+
+    auto priv_level = it.next_token();
+
+    if (shcore::str_caseeq(priv_level, "TABLE")) {
+      object_is_routine = false;
+      // priv_level follows
+      priv_level = it.next_token();
+    } else if (shcore::str_caseeq(priv_level, "FUNCTION", "PROCEDURE")) {
+      object_is_routine = true;
+      // priv_level follows
+      priv_level = it.next_token();
+    }
+
+    shcore::split_priv_level(std::string{priv_level}, &result.schema,
+                             &result.object);
+
+    if ("*" == result.schema) {
+      result.level = Privilege_level_info::Level::GLOBAL;
+    } else if ("*" == result.object) {
+      result.level = Privilege_level_info::Level::SCHEMA;
+    } else {
+      result.level = object_is_routine ? Privilege_level_info::Level::ROUTINE
+                                       : Privilege_level_info::Level::TABLE;
+    }
   }
 
-  shcore::split_priv_level(std::string{priv_level}, &result.schema,
-                           &result.object);
-
-  if ("*" == result.schema) {
-    result.level = Privilege_level_info::Level::GLOBAL;
-  } else if ("*" == result.object) {
-    result.level = Privilege_level_info::Level::SCHEMA;
-  } else {
-    result.level = object_is_routine ? Privilege_level_info::Level::ROUTINE
-                                     : Privilege_level_info::Level::TABLE;
+  for (auto &p : privileges) {
+    result.privileges.emplace(std::move(p));
   }
 
   *info = std::move(result);
