@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -162,12 +164,12 @@ class Load_data_worker final {
  public:
   Load_data_worker() = delete;
   Load_data_worker(const Import_table_options &opt, int64_t thread_id,
-                   std::atomic<size_t> *prog_sent_bytes,
+                   std::atomic<size_t> *prog_data_bytes,
                    std::atomic<size_t> *prog_file_bytes,
                    volatile bool *interrupt,
                    shcore::Synchronized_queue<File_import_info> *range_queue,
-                   std::vector<std::exception_ptr> *thread_exception,
-                   Stats *stats, const std::string &query_comment = "");
+                   std::exception_ptr *thread_exception, Stats *stats,
+                   const std::string &query_comment = "");
   Load_data_worker(const Load_data_worker &other) = default;
   Load_data_worker(Load_data_worker &&other) = default;
 
@@ -181,6 +183,12 @@ class Load_data_worker final {
                std::unique_ptr<mysqlshdk::storage::IFile> file,
                const Transaction_options &options = {});
 
+  static void init_session(
+      const std::shared_ptr<mysqlshdk::db::mysql::Session> &session,
+      const Import_table_options &options);
+
+  static std::string load_data_body(const Import_table_options &options);
+
  private:
   void handle_exception();
 
@@ -188,12 +196,12 @@ class Load_data_worker final {
 
   const Import_table_options &m_opt;
   int64_t m_thread_id;
-  std::atomic<size_t> *m_prog_sent_bytes;
+  std::atomic<size_t> *m_prog_data_bytes;
   std::atomic<size_t> *m_prog_file_bytes;
-  volatile bool &m_interrupt;
+  volatile bool *m_interrupt;
   shcore::Synchronized_queue<File_import_info> *m_range_queue;
-  std::vector<std::exception_ptr> &m_thread_exception;
-  Stats &m_stats;
+  std::exception_ptr *m_thread_exception;
+  Stats *m_stats;
   std::string m_query_comment;
   Thread_state m_state;
 };
