@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -26,6 +28,7 @@
 
 #include <atomic>
 #include <chrono>
+#include <functional>
 #include <limits>
 #include <list>
 #include <memory>
@@ -47,15 +50,19 @@
 #include "modules/util/load/load_dump_options.h"
 #include "modules/util/load/load_progress_log.h"
 
+#include "modules/util/import_table/import_stats.h"
+
 #include "mysqlshdk/libs/db/mysql/session.h"
 #include "mysqlshdk/libs/storage/ifile.h"
-#include "mysqlshdk/libs/utils/priority_queue.h"
+#include "mysqlshdk/libs/textui/text_progress.h"
 #include "mysqlshdk/libs/utils/synchronized_queue.h"
 
 namespace mysqlsh {
 
 class Dump_loader {
  public:
+  using Reconnect = std::function<void()>;
+
   Dump_loader() = delete;
   explicit Dump_loader(const Load_dump_options &options);
 
@@ -90,9 +97,7 @@ class Dump_loader {
             m_key(schema_object_key(schema, table)) {}
       virtual ~Task() {}
 
-      virtual bool execute(
-          const std::shared_ptr<mysqlshdk::db::mysql::Session> &, Worker *,
-          Dump_loader *) = 0;
+      virtual bool execute(Worker *, Dump_loader *) = 0;
 
       size_t id() const { return m_id; }
       const char *log_id() const { return m_log_id.c_str(); }
@@ -130,8 +135,7 @@ class Dump_loader {
             m_script(std::move(script)),
             m_resuming(resuming) {}
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
 
      private:
       std::string m_script;
@@ -149,8 +153,7 @@ class Dump_loader {
             m_status(status),
             m_exists(exists) {}
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
 
       std::unique_ptr<compatibility::Deferred_statements>
       steal_deferred_statements() {
@@ -162,19 +165,14 @@ class Dump_loader {
      private:
       void pre_process(Dump_loader *loader);
 
-      void load_ddl(
-          const std::shared_ptr<mysqlshdk::db::mysql::Session> &session,
-          Dump_loader *loader);
+      void load_ddl(Worker *worker, Dump_loader *loader);
 
-      void post_process(
-          const std::shared_ptr<mysqlshdk::db::mysql::Session> &session,
-          Dump_loader *loader);
+      void post_process(Worker *worker, Dump_loader *loader);
 
       void extract_deferred_statements(Dump_loader *loader);
 
-      void remove_duplicate_deferred_statements(
-          const std::shared_ptr<mysqlshdk::db::mysql::Session> &session,
-          Dump_loader *loader);
+      void remove_duplicate_deferred_statements(Worker *worker,
+                                                Dump_loader *loader);
 
      private:
       std::string m_script;
@@ -208,44 +206,87 @@ class Dump_loader {
       std::string m_partition;
     };
 
-    class Load_chunk_task : public Table_data_task {
+    class Load_data_task : public Table_data_task {
      public:
-      Load_chunk_task(std::string_view schema, std::string_view table,
-                      std::string_view partition, ssize_t chunk_index,
-                      std::unique_ptr<mysqlshdk::storage::IFile> file,
-                      shcore::Dictionary_t options, bool resume,
-                      uint64_t bytes_to_skip)
-          : Table_data_task(schema, table, partition, chunk_index),
-            m_file(std::move(file)),
-            m_options(options),
-            m_resume(resume),
-            m_bytes_to_skip(bytes_to_skip) {}
+      Load_data_task(Dump_reader::Table_chunk chunk, bool resume)
+          : Table_data_task(chunk.schema, chunk.table, chunk.partition,
+                            chunk.index),
+            m_chunk(std::move(chunk)),
+            m_resume(resume) {}
 
-      size_t bytes_loaded = 0;
-      size_t raw_bytes_loaded = 0;
-      size_t rows_loaded = 0;
+      import_table::Stats stats;
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
 
-      void load(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                Dump_loader *, Worker *);
+      const Dump_reader::Table_chunk &chunk() const { return m_chunk; }
+
+     protected:
+      bool resume() const { return m_resume; }
+
+      std::unique_ptr<mysqlshdk::storage::IFile> extract_file() {
+        return std::move(m_chunk.file);
+      }
 
      private:
-      std::unique_ptr<mysqlshdk::storage::IFile> m_file;
-      shcore::Dictionary_t m_options;
+      void load(Dump_loader *, Worker *);
+
+      virtual void on_load_start(Worker *, Dump_loader *) = 0;
+
+      virtual void do_load(Worker *, Dump_loader *) = 0;
+
+      virtual void on_load_end(Worker *, Dump_loader *) = 0;
+
+      Dump_reader::Table_chunk m_chunk;
       bool m_resume = false;
+    };
+
+    class Load_chunk_task : public Load_data_task {
+     public:
+      Load_chunk_task(Dump_reader::Table_chunk chunk, bool resume,
+                      uint64_t bytes_to_skip)
+          : Load_data_task(std::move(chunk), resume),
+            m_bytes_to_skip(bytes_to_skip) {}
+
+     private:
+      void on_load_start(Worker *, Dump_loader *) override;
+
+      void do_load(Worker *, Dump_loader *) override;
+
+      void on_load_end(Worker *, Dump_loader *) override;
+
       uint64_t m_bytes_to_skip = 0;
     };
 
+    class Bulk_load_task : public Load_data_task {
+     public:
+      Bulk_load_task(Dump_reader::Table_chunk chunk, bool resume,
+                     uint64_t weight)
+          : Load_data_task(std::move(chunk), resume),
+            m_target_table(this->chunk().table) {
+        set_weight(weight);
+      }
+
+     private:
+      void on_load_start(Worker *, Dump_loader *) override;
+
+      void do_load(Worker *, Dump_loader *) override;
+
+      void on_load_end(Worker *, Dump_loader *) override;
+
+      bool partitioned() const;
+
+      void bulk_load(Worker *, Dump_loader *);
+
+      std::string m_target_table;
+    };
+
     class Analyze_table_task : public Task {
      public:
       Analyze_table_task(std::string_view schema, std::string_view table,
                          const std::vector<Dump_reader::Histogram> &histograms)
           : Task(schema, table), m_histograms(histograms) {}
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
 
      private:
       std::vector<Dump_reader::Histogram> m_histograms;
@@ -261,8 +302,11 @@ class Dump_loader {
         set_weight(weight);
       }
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
+
+      const compatibility::Deferred_statements::Index_info *indexes() const {
+        return m_indexes;
+      }
 
      private:
       compatibility::Deferred_statements::Index_info *m_indexes;
@@ -278,8 +322,7 @@ class Dump_loader {
                             checksum->partition(), checksum->chunk()),
             m_checksum(checksum) {}
 
-      bool execute(const std::shared_ptr<mysqlshdk::db::mysql::Session> &,
-                   Worker *, Dump_loader *) override;
+      bool execute(Worker *, Dump_loader *) override;
 
       const dump::common::Checksums::Checksum_data *checksum_info()
           const noexcept {
@@ -294,6 +337,7 @@ class Dump_loader {
     };
 
     Worker(size_t id, Dump_loader *owner);
+
     size_t id() const { return m_id; }
 
     void schedule(std::unique_ptr<Task> task);
@@ -303,7 +347,18 @@ class Dump_loader {
     void run();
     void stop();
 
-    uint64_t get_connection_id() const { return m_connection_id; }
+    uint64_t connection_id() const noexcept { return m_connection_id; }
+
+    uint64_t thread_id() const noexcept { return m_thread_id; }
+
+    const std::shared_ptr<mysqlshdk::db::mysql::Session> &session()
+        const noexcept {
+      return m_session;
+    }
+
+    const Reconnect &reconnect_callback() const noexcept {
+      return m_reconnect_callback;
+    }
 
    private:
     void handle_current_exception(Dump_loader *loader,
@@ -317,11 +372,15 @@ class Dump_loader {
 
     void connect();
 
+    uint64_t current_thread_id() const;
+
     size_t m_id = 0;
     Dump_loader *m_owner;
 
     std::shared_ptr<mysqlshdk::db::mysql::Session> m_session;
-    uint64_t m_connection_id;
+    uint64_t m_connection_id = 0;
+    uint64_t m_thread_id = 0;
+    Reconnect m_reconnect_callback;
 
     std::unique_ptr<Task> m_task;
 
@@ -330,21 +389,9 @@ class Dump_loader {
 
   using Task_ptr = std::unique_ptr<Worker::Task>;
 
-  struct Task_comparator {
-    bool operator()(const Worker::Task &l, const Worker::Task &r) const {
-      return l.weight() < r.weight();
-    }
-
-    bool operator()(const Task_ptr &l, const Task_ptr &r) const {
-      return (*this)(*l, *r);
-    }
-  };
-
-  using Queue =
-      shcore::Priority_queue<Task_ptr, std::vector<Task_ptr>, Task_comparator>;
-
   struct Worker_event {
     enum Event {
+      CONNECTED,
       READY,
       FATAL_ERROR,
       SCHEMA_DDL_START,
@@ -362,6 +409,9 @@ class Dump_loader {
       LOAD_SUBCHUNK_END,
       CHECKSUM_START,
       CHECKSUM_END,
+      BULK_LOAD_START,
+      BULK_LOAD_PROGRESS,
+      BULK_LOAD_END,
     };
     Event event;
     Worker *worker = nullptr;
@@ -371,7 +421,7 @@ class Dump_loader {
   using Name_and_file =
       std::pair<std::string, std::unique_ptr<mysqlshdk::storage::IFile>>;
 
-  void execute_tasks();
+  void execute_tasks(bool testing = false);
   void execute_table_ddl_tasks();
   void execute_view_ddl_tasks();
 
@@ -389,15 +439,9 @@ class Dump_loader {
   bool handle_table_data();
   void handle_schema_post_scripts();
 
-  void switch_schema(const std::string &schema, bool load_done);
-
   bool should_fetch_table_ddl(bool placeholder) const;
 
-  bool schedule_table_chunk(const std::string &schema, const std::string &table,
-                            const std::string &partition, ssize_t chunk_index,
-                            std::unique_ptr<mysqlshdk::storage::IFile> file,
-                            size_t size, shcore::Dictionary_t options,
-                            bool resuming, uint64_t bytes_to_skip);
+  bool schedule_table_chunk(Dump_reader::Table_chunk chunk);
 
   bool schedule_next_task();
   size_t handle_worker_events(const std::function<bool()> &schedule_next);
@@ -422,35 +466,42 @@ class Dump_loader {
 
   void on_schema_end(const std::string &schema);
 
-  void on_schema_ddl_start(const std::string &schema);
-  void on_schema_ddl_end(const std::string &schema);
+  void on_schema_ddl_start(std::size_t worker_id,
+                           const Worker::Schema_ddl_task *task);
+  void on_schema_ddl_end(std::size_t worker_id,
+                         const Worker::Schema_ddl_task *task);
 
-  void on_table_ddl_start(const std::string &schema, const std::string &table,
-                          bool placeholder);
-  void on_table_ddl_end(
-      const std::string &schema, const std::string &table, bool placeholder,
-      std::unique_ptr<compatibility::Deferred_statements> deferred_indexes);
+  void on_table_ddl_start(std::size_t worker_id,
+                          const Worker::Table_ddl_task *task);
+  void on_table_ddl_end(std::size_t worker_id, Worker::Table_ddl_task *task);
 
-  void on_chunk_load_start(const std::string &schema, const std::string &table,
-                           const std::string &partition, ssize_t index);
-  void on_chunk_load_end(const std::string &schema, const std::string &table,
-                         const std::string &partition, ssize_t index,
-                         size_t bytes_loaded, size_t raw_bytes_loaded,
-                         size_t rows_loaded);
+  void on_index_start(std::size_t worker_id,
+                      const Worker::Index_recreation_task *task);
+  void on_index_end(std::size_t worker_id,
+                    const Worker::Index_recreation_task *task);
 
-  void on_subchunk_load_start(const std::string &schema,
-                              const std::string &table,
-                              const std::string &partition, ssize_t index,
-                              uint64_t subchunk);
-  void on_subchunk_load_end(const std::string &schema, const std::string &table,
-                            const std::string &partition, ssize_t index,
-                            uint64_t subchunk, uint64_t bytes);
+  void on_analyze_start(std::size_t worker_id,
+                        const Worker::Analyze_table_task *task);
+  void on_analyze_end(std::size_t worker_id,
+                      const Worker::Analyze_table_task *task);
 
-  void on_index_start(const std::string &schema, const std::string &table);
-  void on_index_end(const std::string &schema, const std::string &table);
+  void on_chunk_load_start(std::size_t worker_id,
+                           const Worker::Load_chunk_task *task);
+  void on_chunk_load_end(std::size_t worker_id,
+                         const Worker::Load_chunk_task *task);
 
-  void on_analyze_start(const std::string &schema, const std::string &table);
-  void on_analyze_end(const std::string &schema, const std::string &table);
+  void on_subchunk_load_start(std::size_t worker_id,
+                              const shcore::Dictionary_t &event,
+                              const Worker::Load_chunk_task *task);
+  void on_subchunk_load_end(std::size_t worker_id,
+                            const shcore::Dictionary_t &event,
+                            const Worker::Load_chunk_task *task);
+
+  void on_bulk_load_start(std::size_t worker_id,
+                          const Worker::Bulk_load_task *task);
+  void on_bulk_load_progress(const shcore::Dictionary_t &event);
+  void on_bulk_load_end(std::size_t worker_id,
+                        const Worker::Bulk_load_task *task);
 
   void on_checksum_start(
       const dump::common::Checksums::Checksum_data *checksum);
@@ -487,50 +538,15 @@ class Dump_loader {
 
   bool is_data_load_complete() const;
 
-  static inline std::shared_ptr<mysqlshdk::db::IResult> query(
-      const std::shared_ptr<mysqlshdk::db::ISession> &session,
-      std::string_view sql) {
-    return session->query(sql);
-  }
-
-  static inline void execute(
-      const std::shared_ptr<mysqlshdk::db::ISession> &session,
-      std::string_view sql) {
-    session->execute(sql);
-  }
-
-  template <typename... Args>
-  static inline void executef(
-      const std::shared_ptr<mysqlshdk::db::ISession> &session, const char *sql,
-      Args &&... args) {
-    session->executef(sql, std::forward<Args>(args)...);
-  }
-
-  inline std::shared_ptr<mysqlshdk::db::IResult> query(
-      std::string_view sql) const {
-    return query(m_session, sql);
-  }
-
-  inline void execute(std::string_view sql) const {
-    return execute(m_session, sql);
-  }
-
-  template <typename... Args>
-  inline void executef(const char *sql, Args &&... args) {
-    executef(m_session, sql, std::forward<Args>(args)...);
-  }
-
   void log_server_version() const;
 
   void push_pending_task(Task_ptr task);
 
-  Task_ptr load_chunk_file(const std::string &schema, const std::string &table,
-                           const std::string &partition,
-                           std::unique_ptr<mysqlshdk::storage::IFile> file,
-                           ssize_t chunk_index, size_t chunk_size,
-                           const shcore::Dictionary_t &options, bool resuming,
+  Task_ptr load_chunk_file(Dump_reader::Table_chunk chunk, bool resuming,
                            uint64_t bytes_to_skip) const;
 
+  Task_ptr bulk_load_table(Dump_reader::Table_chunk chunk, bool resuming) const;
+
   Task_ptr recreate_indexes(
       const std::string &schema, const std::string &table,
       compatibility::Deferred_statements::Index_info *indexes) const;
@@ -543,6 +559,22 @@ class Dump_loader {
 
   void load_users();
 
+  bool bulk_load_supported(const Dump_reader::Table_chunk &chunk) const;
+
+  bool schedule_bulk_load(Dump_reader::Table_chunk chunk);
+
+  bool is_table_included(const std::string &schema, const std::string &table);
+
+  void mark_table_as_in_progress(const Dump_reader::Table_chunk &chunk);
+
+  void setup_temp_tables();
+
+  std::string temp_table_name();
+
+  void update_rows_throughput(uint64_t rows);
+
+  uint64_t rows_throughput_rate();
+
  private:
 #ifdef FRIEND_TEST
   FRIEND_TEST(Load_dump, sql_transforms_strip_sql_mode);
@@ -595,17 +627,61 @@ class Dump_loader {
     std::list<std::function<void(std::string_view, std::string *)>> m_ops;
   };
 
+  /**
+   * Stable priority queue.
+   */
+  class Priority_queue final {
+   public:
+    inline void resize(std::size_t new_size) { m_tasks.resize(new_size); }
+
+    [[nodiscard]] inline bool empty() const noexcept { return 0 == m_size; }
+
+    [[nodiscard]] inline const Worker::Task *top() const noexcept {
+      assert(!empty());
+      return m_tasks[m_top_pos].front().get();
+    }
+
+    void emplace(Task_ptr task);
+
+    [[nodiscard]] Task_ptr pop_top() noexcept;
+
+   private:
+#ifdef _WIN32
+    // workaround for MSVC issue 37592
+    struct Container : public std::list<Task_ptr> {
+     public:
+      using Base = std::list<Task_ptr>;
+      using Base::Base;
+
+      Container() = default;
+      Container(Container &&) = default;
+
+      Container &operator=(Container &&) = default;
+    };
+#else   // !_WIN32
+    using Container = std::list<Task_ptr>;
+#endif  // !_WIN32
+
+    std::size_t m_size = 0;
+    uint64_t m_top_pos = 0;
+    std::vector<Container> m_tasks;
+  };
+
+  class Bulk_load_support;
+
+  class Monitoring;
+
   const Load_dump_options &m_options;
 
   std::unique_ptr<Dump_reader> m_dump;
   std::unique_ptr<Load_progress_log> m_load_log;
   bool m_resuming = false;
 
-  std::shared_ptr<mysqlshdk::db::ISession> m_session;
+  std::shared_ptr<mysqlshdk::db::mysql::Session> m_session;
 
   std::vector<std::thread> m_worker_threads;
   std::list<Worker> m_workers;
-  Queue m_pending_tasks;
+  Priority_queue m_pending_tasks;
   uint64_t m_current_weight = 0;
 
   std::mutex m_tables_being_loaded_mutex;
@@ -635,17 +711,18 @@ class Dump_loader {
   std::unordered_set<std::string> m_unique_tables_loaded;
   size_t m_total_tables_with_data = 0;
 
-  size_t m_num_bytes_previously_loaded = 0;
-  std::atomic<size_t> m_num_rows_loaded;
-  std::atomic<size_t> m_num_rows_deleted = 0;
-  std::atomic<size_t> m_num_bytes_loaded;
-  std::atomic<size_t> m_num_raw_bytes_loaded;
-  std::atomic<size_t> m_num_chunks_loaded;
-  std::atomic<size_t> m_num_warnings;
+  size_t m_data_bytes_previously_loaded = 0;
+  size_t m_rows_previously_loaded = 0;
+  import_table::Stats m_stats;
   std::atomic<size_t> m_num_errors;
+  mysqlshdk::textui::Throughput m_rows_throughput;
+  std::mutex m_rows_throughput_mutex;
 
   std::atomic<uint64_t> m_ddl_executed;
 
+  uint64_t m_total_ddl_executed = 0;
+  double m_total_ddl_execution_seconds = 0;
+
   std::atomic<uint64_t> m_indexes_recreated;
   uint64_t m_indexes_to_recreate = 0;
   bool m_index_count_is_known = false;
@@ -673,8 +750,19 @@ class Dump_loader {
   std::size_t m_loaded_accounts = 0;
   std::size_t m_dropped_accounts = 0;
   std::size_t m_ignored_grant_errors = 0;
+  std::size_t m_ignored_plugin_errors = 0;
 
   std::size_t m_checksum_errors = 0;
+
+  std::string m_temp_table_prefix;
+  std::atomic<uint64_t> m_temp_table_suffix{0};
+
+  std::unique_ptr<Monitoring> m_monitoring;
+
+  Reconnect m_reconnect_callback;
+
+  // BULK LOAD
+  std::unique_ptr<Bulk_load_support> m_bulk_load;
 };
 
 }  // namespace mysqlsh
