@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -43,7 +45,6 @@
 
 #include "mysqlshdk/include/mysqlshdk_export.h"
 #include "mysqlshdk/libs/utils/error.h"
-#include "mysqlshdk/libs/utils/nullable.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 // For error codes used by the shell
@@ -798,15 +799,6 @@ struct value_type_for_native<Value> {
   static Value extract(const Value &value) { return value; }
 };
 
-template <typename T>
-struct value_type_for_native<mysqlshdk::utils::nullable<T>> {
-  static const Value_type type = value_type_for_native<T>::type;
-
-  static T extract(const Value &value) {
-    return value_type_for_native<T>::extract(value);
-  }
-};
-
 template <typename T>
 struct value_type_for_native<std::optional<T>> {
   static const Value_type type = value_type_for_native<T>::type;
