@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -204,12 +206,13 @@ void Session_impl::connect(
   _mysql = mysql_init(nullptr);
 
   // A tracer plugin needs to be enabled as soon as the first instance of MYSQL
-  // is created in order to properly support FIDO authentication as it is the
-  // tracer who can identify when authentication_fido_plugin is being used so
-  // the print callback can be set.
+  // is created in order to properly support pluggable authentication as it is
+  // the tracer who can identify the authentication plugin is being used so
+  // plugin options can be defined.
   std::call_once(trace_register_flag, register_tracer_plugin, _mysql);
 
   _connection_options = connection_options;
+  _connection_options.set_default_data();
 
   auth::register_connection_options_for_mysql(_mysql, _connection_options);
   shcore::on_leave_scope unregister_conn_options(
@@ -278,7 +281,7 @@ void Session_impl::connect(
     if (auth == kAuthMethodClearPassword) {
       if (!connection_options.has_socket() && !connection_options.has_pipe()) {
         auto final_ssl_mode =
-            used_ssl_mode.get_safe(mysqlshdk::db::Ssl_mode::Disabled);
+            used_ssl_mode.value_or(mysqlshdk::db::Ssl_mode::Disabled);
 
         if (final_ssl_mode == mysqlshdk::db::Ssl_mode::Disabled) {
           throw std::runtime_error(
@@ -394,11 +397,10 @@ void Session_impl::connect(
 
   // If this fails Mfa_passwords definition has to be changed
   static_assert(MAX_AUTH_FACTORS == 3);
-  auto passwords = _connection_options.get_mfa_passwords();
-  for (unsigned int factor = 1; factor <= passwords.size(); factor++) {
-    if (passwords[factor - 1]) {
+  for (int factor = 1; factor <= 3; factor++) {
+    if (_connection_options.has_mfa_password(factor - 1)) {
       mysql_options4(_mysql, MYSQL_OPT_USER_PASSWORD, &factor,
-                     passwords[factor - 1]->c_str());
+                     _connection_options.get_mfa_password(factor - 1).c_str());
     }
   }
 
@@ -447,7 +449,7 @@ void Session_impl::connect(
       // If connection was not through TCP/IP it means either the default
       // socket path or windows named pipe was used
 #ifdef _WIN32
-      _connection_options.set_pipe("MySQL");
+      _connection_options.set_pipe(mysql_unix_port);
 #else
       _connection_options.set_socket(mysql_unix_port);
 #endif
@@ -455,11 +457,11 @@ void Session_impl::connect(
   }
 }
 
-mysqlshdk::utils::nullable<mysqlshdk::db::Ssl_mode> Session_impl::setup_ssl(
+std::optional<mysqlshdk::db::Ssl_mode> Session_impl::setup_ssl(
     const mysqlshdk::db::Ssl_options &ssl_options) const {
   int value;
 
-  mysqlshdk::utils::nullable<mysqlshdk::db::Ssl_mode> ssl_mode;
+  std::optional<mysqlshdk::db::Ssl_mode> ssl_mode;
   if (ssl_options.has_data()) {
     ssl_options.validate();
 
