@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -37,17 +39,13 @@
 #include <mysqld_error.h>
 
 #include "mysqlshdk/libs/config/config.h"
-#include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/mysql/plugin.h"
-#include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/logger.h"
-#include "mysqlshdk/libs/utils/trandom.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_sqlstring.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
-#include "mysqlshdk/libs/utils/uuid_gen.h"
 
 namespace mysqlshdk {
 namespace gr {
@@ -246,18 +244,16 @@ Member_state get_member_state(const mysqlshdk::mysql::IInstance &instance) {
   // replication_group_members will have a single row with member_id = '' and
   // member_state = OFFLINE in 5.7 if the server is started and GR doesn't
   // auto-start.
-  static const char *member_state_stmt =
+  const char *member_state_stmt =
       "SELECT member_state "
       "FROM performance_schema.replication_group_members "
       "WHERE member_id = @@server_uuid OR"
       " (member_id = '' AND member_state = 'OFFLINE')";
   auto resultset = instance.query(member_state_stmt);
   auto row = resultset->fetch_one();
-  if (row) {
-    return to_member_state(row->get_string(0));
-  } else {
-    return Member_state::MISSING;
-  }
+
+  if (row) return to_member_state(row->get_string(0));
+  return Member_state::MISSING;
 }
 
 /**
@@ -487,45 +483,43 @@ std::string get_group_primary_uuid(const mysqlshdk::mysql::IInstance &instance,
 
 mysqlshdk::utils::Version get_group_protocol_version(
     const mysqlshdk::mysql::IInstance &instance) {
-  // MySQL versions in the domain [5.7.14, 8.0.15] map to GCS protocol version
-  // 1 (5.7.14) so we can return it immediately and avoid an error when
-  // executing the UDF to obtain the protocol version since the UDF is only
-  // available for versions >= 8.0.16
-  if (instance.get_version() < mysqlshdk::utils::Version(8, 0, 16)) {
-    return mysqlshdk::utils::Version(5, 7, 14);
-  } else {
-    try {
-      const char *get_gr_protocol_version =
-          "SELECT group_replication_get_communication_protocol()";
+  // MySQL versions in the domain <= 8.0.15 map to GCS protocol version 1 so
+  // we can return it immediately and avoid an error when executing the UDF to
+  // obtain the protocol version since the UDF is only available for versions
+  // >= 8.0.16
+  if (instance.get_version() < mysqlshdk::utils::Version(8, 0, 16))
+    return mysqlshdk::utils::Version(8, 0, 15);
 
-      log_debug("Executing UDF: %s",
-                get_gr_protocol_version + sizeof("SELECT"));  // hide "SELECT "
+  try {
+    const char *get_gr_protocol_version =
+        "SELECT group_replication_get_communication_protocol()";
 
-      auto resultset = instance.query_udf(get_gr_protocol_version);
-      auto row = resultset->fetch_one();
+    log_debug("Executing UDF: %s",
+              get_gr_protocol_version + sizeof("SELECT "));  // hide "SELECT "
 
-      if (row) {
-        return (mysqlshdk::utils::Version(row->get_string(0)));
-      } else {
-        throw std::logic_error(
-            "No rows returned when querying the version of Group Replication "
-            "communication protocol.");
-      }
-    } catch (const mysqlshdk::db::Error &error) {
-      throw shcore::Exception::mysql_error_with_code_and_state(
-          error.what(), error.code(), error.sqlstate());
-    }
+    auto resultset = instance.query_udf(get_gr_protocol_version);
+    auto row = resultset->fetch_one();
+    if (!row)
+      throw std::logic_error(
+          "No rows returned when querying the version of Group Replication "
+          "communication protocol.");
+
+    return (mysqlshdk::utils::Version(row->get_string(0)));
+
+  } catch (const mysqlshdk::db::Error &error) {
+    throw shcore::Exception::mysql_error_with_code_and_state(
+        error.what(), error.code(), error.sqlstate());
   }
 }
 
 mysqlshdk::utils::Version get_max_supported_group_protocol_version(
     const mysqlshdk::utils::Version &server_version) {
-  if (server_version < mysqlshdk::utils::Version(8, 0, 16)) {
-    return mysqlshdk::utils::Version(5, 7, 14);
-  } else if (server_version < mysqlshdk::utils::Version(8, 0, 27)) {
-    // Protocol version for any server >= 8.0.16 && < 8.0.27 is 8.0.16
+  if (server_version < mysqlshdk::utils::Version(8, 0, 16))
+    return mysqlshdk::utils::Version(8, 0, 15);
+
+  // Protocol version for any server >= 8.0.16 && < 8.0.27 is 8.0.16
+  if (server_version < mysqlshdk::utils::Version(8, 0, 27))
     return mysqlshdk::utils::Version(8, 0, 16);
-  }
 
   // we have to assume protocol version for any server >= 8.0.27 is 8.0.27
   return mysqlshdk::utils::Version(8, 0, 27);
@@ -534,16 +528,18 @@ mysqlshdk::utils::Version get_max_supported_group_protocol_version(
 void set_group_protocol_version(const mysqlshdk::mysql::IInstance &instance,
                                 mysqlshdk::utils::Version version) {
   std::string query;
+  {
+    auto query_fmt =
+        "SELECT group_replication_set_communication_protocol(?)"_sql
+        << version.get_full();
+    query_fmt.done();
 
-  shcore::sqlstring query_fmt(
-      "SELECT group_replication_set_communication_protocol(?)", 0);
-  query_fmt << version.get_full();
-  query_fmt.done();
-  query = query_fmt.str();
+    query = query_fmt.str();
+  }
 
   try {
     log_debug("Executing UDF: %s",
-              query.c_str() + sizeof("SELECT"));  // hide "SELECT "
+              query.c_str() + sizeof("SELECT "));  // hide "SELECT "
 
     instance.query_udf(query);
   } catch (const mysqlshdk::db::Error &error) {
@@ -665,7 +661,7 @@ void start_group_replication(const mysqlshdk::mysql::IInstance &instance,
                         mysqlshdk::mysql::Var_qualifier::GLOBAL);
   try {
     instance.execute("START GROUP_REPLICATION");
-  } catch (const std::exception &err) {
+  } catch (const std::exception &) {
     // Try to set the group_replication_bootstrap_group to OFF if the
     // statement to start GR failed and only then throw the error.
     try {
@@ -735,13 +731,7 @@ mysqlshdk::mysql::Auth_options create_recovery_user(
   if (options.mysql_comm_stack_supported)
     user_options.grants.push_back({"GROUP_REPLICATION_STREAM", "*.*", false});
 
-  if (primary.get_version() >= utils::Version(8, 0, 0)) {
-    // Recovery accounts must have CONNECTION_ADMIN too, otherwise, if a group
-    // members has offline_mode enabled the member is evicted from the group
-    // since the recovery account connections are disconnected and blocked.
-    // This has greater impact when using "MySQL" communication stack
-    user_options.grants.push_back({"CONNECTION_ADMIN", "*.*", false});
-  }
+  user_options.grants.push_back({"CONNECTION_ADMIN", "*.*", false});
 
   mysqlshdk::mysql::Auth_options creds;
 
@@ -795,8 +785,7 @@ bool is_group_replication_delayed_starting(
     return instance
                .query(
                    "SELECT COUNT(*) FROM performance_schema.threads WHERE NAME "
-                   "= "
-                   "'thread/group_rpl/THD_delayed_initialization'")
+                   "= 'thread/group_rpl/THD_delayed_initialization'")
                ->fetch_one()
                ->get_uint(0) != 0;
   } catch (const std::exception &e) {
@@ -811,28 +800,23 @@ bool is_active_member(const mysqlshdk::mysql::IInstance &instance,
   shcore::sqlstring is_active_member_stmt;
 
   if (!host.empty() && port != 0) {
-    std::string is_active_member_stmt_fmt =
+    is_active_member_stmt =
         "SELECT count(*) "
         "FROM performance_schema.replication_group_members "
         "WHERE MEMBER_HOST = ? AND MEMBER_PORT = ? "
-        "AND MEMBER_STATE NOT IN ('OFFLINE', 'UNREACHABLE')";
-    is_active_member_stmt =
-        shcore::sqlstring(is_active_member_stmt_fmt.c_str(), 0);
-    is_active_member_stmt << host;
-    is_active_member_stmt << port;
-    is_active_member_stmt.done();
+        "AND MEMBER_STATE NOT IN ('OFFLINE', 'UNREACHABLE')"_sql;
+    is_active_member_stmt << host << port;
 
   } else {
-    std::string is_active_member_stmt_fmt =
+    is_active_member_stmt =
         "select count(*) "
         "FROM performance_schema.replication_group_members "
         "WHERE MEMBER_ID = @@server_uuid AND MEMBER_STATE NOT "
-        "IN ('OFFLINE', 'UNREACHABLE')";
-    is_active_member_stmt =
-        shcore::sqlstring(is_active_member_stmt_fmt.c_str(), 0);
-    is_active_member_stmt.done();
+        "IN ('OFFLINE', 'UNREACHABLE')"_sql;
   }
 
+  is_active_member_stmt.done();
+
   try {
     auto result = instance.query(is_active_member_stmt);
     auto row = result->fetch_one();
@@ -1018,14 +1002,16 @@ bool is_running_gr_auto_rejoin(const mysqlshdk::mysql::IInstance &instance) {
 void check_instance_version_compatibility(
     const mysqlshdk::mysql::IInstance &instance,
     mysqlshdk::utils::Version lowest_cluster_version) {
-  auto gr_allow_lower_version_join = instance.get_sysvar_bool(
-      "group_replication_allow_local_lower_version_join", false);
+  if (lowest_cluster_version < utils::Version(8, 4, 0)) {
+    auto gr_allow_lower_version_join = instance.get_sysvar_bool(
+        "group_replication_allow_local_lower_version_join", false);
 
-  // If gr_allow_lower_version_join is NULL then it means the variable is not
-  // available, e.g., if the GR plugin is not installed which happens by default
-  // on 5.7 servers. In that case, we apply the expected behaviour for the
-  // default variable value (false).
-  if (gr_allow_lower_version_join) return;
+    // If gr_allow_lower_version_join is NULL then it means the variable is not
+    // available, e.g., if the GR plugin is not installed which happens by
+    // default on 5.7 servers. In that case, we apply the expected behaviour for
+    // the default variable value (false).
+    if (gr_allow_lower_version_join) return;
+  }
 
   mysqlshdk::utils::Version target_version = instance.get_version();
 
@@ -1179,8 +1165,7 @@ bool is_endpoint_supported_by_gr(const std::string &endpoint,
   const bool supports_ipv6 = (version >= mysqlshdk::utils::Version(8, 0, 14));
   try {
     // split host from port, and make sure endpoint has both
-    mysqlshdk::db::Connection_options conn_opt =
-        shcore::get_connection_options(endpoint, false);
+    mysqlshdk::db::Connection_options conn_opt(endpoint);
 
     if (!conn_opt.has_host() || !conn_opt.has_port()) {
       throw shcore::Exception::argument_error(
@@ -1199,7 +1184,7 @@ bool is_endpoint_supported_by_gr(const std::string &endpoint,
     // no guarantee that name resolution is the same across cluster instances
     // and the instance where we are running the ngshell.
     return true;
-  } catch (const std::invalid_argument &error) {
+  } catch (const std::invalid_argument &) {
     throw shcore::Exception::argument_error(
         shcore::str_format("Invalid address format: '%s'", endpoint.c_str()));
   }
@@ -1233,7 +1218,7 @@ void execute_member_action_udf(const mysqlshdk::mysql::IInstance &instance,
   try {
     assert(shcore::str_ibeginswith(query, "select "));
     log_debug("Executing UDF: %s",
-              query.c_str() + sizeof("SELECT"));  // hide "SELECT "
+              query.c_str() + sizeof("SELECT "));  // hide "SELECT "
     instance.query_udf(query);
   } catch (const mysqlshdk::db::Error &error) {
     throw shcore::Exception::mysql_error_with_code_and_state(
