@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -21,23 +23,20 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include <mysqld_error.h>
+#include "mysqlshdk/libs/mysql/instance.h"
 
-#include <algorithm>
 #include <array>
 #include <map>
 #include <string_view>
-#include <utility>
 
-#include "mysqlshdk/libs/mysql/instance.h"
+#include <mysqld_error.h>
+
 #include "mysqlshdk/libs/utils/logger.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_sqlstring.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
-#include "scripting/types.h"
-
 namespace mysqlshdk {
 namespace mysql {
 
@@ -64,9 +63,6 @@ void Auth_options::set(mysqlshdk::db::Connection_options *copts) const {
   copts->set_ssl_options(ssl_options);
 }
 
-Instance::Instance(const std::shared_ptr<db::ISession> &session)
-    : _session(session) {}
-
 void Instance::register_warnings_callback(const Warnings_callback &callback) {
   m_warnings_callback = callback;
 }
@@ -624,8 +620,8 @@ bool Instance::is_read_only(bool super) const {
 }
 
 utils::Version Instance::get_version() const {
-  if (_version == utils::Version()) _version = _session->get_server_version();
-  return _version;
+  if (!m_version) m_version = m_session->get_server_version();
+  return m_version;
 }
 
 /**
@@ -718,7 +714,7 @@ std::optional<bool> Instance::is_set_persist_supported() const {
 }
 
 std::optional<std::string> Instance::get_persisted_value(
-    const std::string &variable_name) const {
+    std::string_view variable_name) const {
   auto result = queryf(
       "SELECT variable_value "
       "FROM performance_schema.persisted_variables "
@@ -732,8 +728,6 @@ std::optional<std::string> Instance::get_persisted_value(
 }
 
 std::vector<std::string> Instance::get_fence_sysvars() const {
-  std::vector<std::string> result;
-
   // Create the query to get the fence sysvars.
   std::string str_query = "SELECT";
   for (auto it = k_fence_sysvars.cbegin(); it != k_fence_sysvars.cend(); ++it) {
@@ -742,19 +736,22 @@ std::vector<std::string> Instance::get_fence_sysvars() const {
   }
 
   // Execute the query and add all the enabled sysvars to the result list.
-  auto resultset = _session->query(str_query);
+  auto resultset = m_session->query(str_query);
   auto row = resultset->fetch_one();
-  if (row) {
-    for (size_t i = 0; i < k_fence_sysvars.size(); ++i) {
-      if (row->get_int(i) != 0) {
-        result.push_back(std::string{k_fence_sysvars.at(i)});
-      }
-    }
-    return result;
-  } else {
+  if (!row)
     throw std::logic_error(
         "No result return from query for get_fence_sysvars()");
+
+  std::vector<std::string> result;
+
+  result.reserve(k_fence_sysvars.size());
+  for (size_t i = 0; i < k_fence_sysvars.size(); ++i) {
+    if (row->get_int(i) != 0) {
+      result.push_back(std::string{k_fence_sysvars.at(i)});
+    }
   }
+
+  return result;
 }
 
 void Instance::suppress_binary_log(bool flag) {
@@ -794,14 +791,13 @@ void Instance::execute(const std::string &sql) const {
   }
 }
 
-void Instance::process_result_warnings(const std::string &sql,
+void Instance::process_result_warnings(std::string_view sql,
                                        mysqlshdk::db::IResult &result) const {
-  // Call the Warnings_callback if registered
   if (!m_warnings_callback) return;
 
   // Get all the Warnings
   while (auto warning = result.fetch_one_warning()) {
-    std::string warning_level;
+    std::string_view warning_level;
 
     switch (warning->level) {
       case db::Warning::Level::Note:
@@ -816,17 +812,12 @@ void Instance::process_result_warnings(const std::string &sql,
     }
 
     m_warnings_callback(sql, warning->code, warning_level, warning->msg);
-
-    warning = result.fetch_one_warning();
   }
 }
 
 std::string Instance::generate_uuid() const {
-  // Generate a UUID on the MySQL server.
-  std::string get_uuid_stmt = "SELECT UUID()";
-  auto resultset = query(get_uuid_stmt);
+  auto resultset = query("SELECT UUID()");
   auto row = resultset->fetch_one();
-
   return row->get_string(0);
 }
 
