@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -25,6 +27,7 @@
 #define MYSQLSHDK_LIBS_MYSQL_INSTANCE_H_
 
 #include <cassert>
+#include <functional>
 #include <map>
 #include <memory>
 #include <optional>
@@ -40,8 +43,8 @@
 #include "mysqlshdk/libs/utils/version.h"
 
 using Warnings_callback =
-    std::function<void(const std::string &sql, int code,
-                       const std::string &level, const std::string &msg)>;
+    std::function<void(std::string_view sql, int code, std::string_view level,
+                       std::string_view msg)>;
 
 namespace mysqlshdk {
 namespace mysql {
@@ -63,9 +66,11 @@ struct Auth_options {
   db::Ssl_options ssl_options;
 
   Auth_options() = default;
-  Auth_options(const std::string &user_, const std::string &password_)
-      : user(user_), password(password_) {}
-  Auth_options(const mysqlshdk::db::Connection_options &copts) { get(copts); }
+  Auth_options(std::string user_, std::string password_) noexcept
+      : user(std::move(user_)), password(std::move(password_)) {}
+  explicit Auth_options(const mysqlshdk::db::Connection_options &copts) {
+    get(copts);
+  }
   void get(const mysqlshdk::db::Connection_options &copts);
   void set(mysqlshdk::db::Connection_options *copts) const;
 };
@@ -222,7 +227,7 @@ class IInstance {
       bool allow_skip_grants_user = false) const = 0;
   virtual std::optional<bool> is_set_persist_supported() const = 0;
   virtual std::optional<std::string> get_persisted_value(
-      const std::string &variable_name) const = 0;
+      std::string_view variable_name) const = 0;
 
   virtual std::vector<std::string> get_fence_sysvars() const = 0;
 
@@ -368,8 +373,9 @@ class Set_variable final {
  */
 class Instance : public IInstance {
  public:
-  Instance() = default;
-  explicit Instance(const std::shared_ptr<db::ISession> &session);
+  explicit Instance() = default;
+  explicit Instance(std::shared_ptr<db::ISession> session) noexcept
+      : m_session{std::move(session)} {}
 
   void register_warnings_callback(const Warnings_callback &callback) override;
 
@@ -420,10 +426,10 @@ class Instance : public IInstance {
   bool is_ssl_enabled() const override;
 
   std::shared_ptr<db::ISession> get_session() const override {
-    return _session;
+    return m_session;
   }
 
-  void close_session() const override { _session->close(); }
+  void close_session() const override { m_session->close(); }
 
   std::optional<std::string> get_system_variable(
       std::string_view name,
@@ -441,7 +447,7 @@ class Instance : public IInstance {
   void drop_user(const std::string &user, const std::string &host,
                  bool if_exists = false) const override;
   mysqlshdk::db::Connection_options get_connection_options() const override {
-    auto co = _session->get_connection_options();
+    auto co = m_session->get_connection_options();
 
     // we don't want to be using cached value of connect-timeout option
     co.clear_connect_timeout();
@@ -490,7 +496,7 @@ class Instance : public IInstance {
    *         variable, or null if no persisted value was found.
    */
   std::optional<std::string> get_persisted_value(
-      const std::string &variable_name) const override;
+      std::string_view variable_name) const override;
 
   std::vector<std::string> get_fence_sysvars() const override;
 
@@ -518,12 +524,12 @@ class Instance : public IInstance {
   void execute(const std::string &sql) const override;
 
  private:
-  void process_result_warnings(const std::string &sql,
+  void process_result_warnings(std::string_view sql,
                                mysqlshdk::db::IResult &result) const;
 
  private:
-  std::shared_ptr<db::ISession> _session;
-  mutable mysqlshdk::utils::Version _version;
+  std::shared_ptr<db::ISession> m_session;
+  mutable mysqlshdk::utils::Version m_version;
   mutable std::string m_version_compile_os;
   mutable std::string m_version_compile_machine;
   mutable std::string m_uuid;
@@ -534,7 +540,7 @@ class Instance : public IInstance {
   mutable std::optional<int> m_xport;
   mutable uint32_t m_server_id = 0;
   int m_sql_binlog_suppress_count = 0;
-  Warnings_callback m_warnings_callback = nullptr;
+  Warnings_callback m_warnings_callback;
 };
 
 }  // namespace mysql
