@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -28,6 +30,7 @@
 #include <optional>
 #include <string>
 #include <string_view>
+#include <vector>
 
 namespace mysqlshdk {
 namespace utils {
@@ -127,6 +130,22 @@ inline const Version k_shell_version = Version(MYSH_VERSION);
  */
 int major_version_difference(const Version &source, const Version &target);
 
+/**
+ * Returns all versions which were current when the given version was released,
+ * sorted in ascending order.
+ */
+std::vector<Version> corresponding_versions(Version version);
+
+/**
+ * Get first LTS version in the same major version as the given version
+ */
+Version get_first_lts_version(Version version);
+
+/**
+ * Get first innovation version in the same major version as the given version
+ */
+Version get_first_innovation_version(Version version);
+
 }  // namespace utils
 }  // namespace mysqlshdk
 
