@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -68,19 +70,19 @@ bool Shell_options::Storage::has_connection_data(
     return connection_data.has_user() || connection_data.has_host() ||
            connection_data.has_port() || connection_data.has_socket() ||
            connection_data.has_pipe() || connection_data.has_password() ||
-           prompt_password;
+           connection_data.has_needs_password(0) ||
+           connection_data.has_needs_password(1) ||
+           connection_data.has_needs_password(2);
   }
-
-  return connection_data.has_data() || prompt_password;
+  return connection_data.has_data() || connection_data.has_needs_password(0) ||
+         connection_data.has_needs_password(1) ||
+         connection_data.has_needs_password(2);
 }
 
 mysqlshdk::db::Connection_options Shell_options::Storage::connection_options()
     const {
   auto target_server = connection_data;
 
-  if (no_password && !target_server.has_password()) {
-    target_server.set_password("");
-  }
   if (!ssh.uri.empty()) {
     auto ssh_dict = shcore::make_dict();
     if (!ssh.identity_file.empty()) {
@@ -186,10 +188,8 @@ void Shell_options::Storage::set_uri(const std::string &uri) {
     connection_data.clear_schema();
     connection_data.clear_port();
     connection_data.clear_socket();
-    // don't set defaults to the parsed URI because we don't want to override
-    // options like user, pass and scheme that were specified before the URI
-    // with defaults
-    connection_data.override_with(shcore::get_connection_options(uri, false));
+
+    connection_data.override_with(Connection_options(uri));
   }
 }
 
@@ -290,9 +290,11 @@ Shell_options::Shell_options(
         "For more details execute '\\? cmdline' inside of the Shell.")
     (&storage.execute_statement, "", cmdline("-e", "--execute=<cmd>"),
         "Execute command and quit.")
+#ifdef HAVE_PYTHON
     (cmdline("-c", "--pyc=<cmd>"), "Execute Python command and quit. "
         "Any options specified after this are used as arguments of the "
         "processed command.")
+#endif
     (cmdline("-f", "--file=<file>"), "Specify a file to process in batch mode. "
         "Any options specified after this are used as arguments of the "
         "processed file.");
@@ -336,14 +338,14 @@ Shell_options::Shell_options(
 
 #ifdef _WIN32
   add_startup_options()
-    (cmdline("--plugin-authentication-kerberos-client-mode=<mode>"), 
+    (cmdline("--plugin-authentication-kerberos-client-mode=<mode>"),
       "Allows defining the kerberos client mode (SSPI, GSSAPI) when using "
       "kerberos authentication.",
       [this](const std::string&, const char* value){
         storage.connection_data.set_kerberos_auth_mode(value);
       });
 #endif
-  
+
   add_startup_options()
     (cmdline("--oci-config-file=<file>"),
       "Allows defining the OCI configuration file for OCI authentication.",
@@ -370,8 +372,6 @@ Shell_options::Shell_options(
     (cmdline("-P", "--port=<#>"),
         "Port number to use for connection.",
         [this](const std::string& option, const char* value) {
-          storage.connection_data.clear_socket();
-          storage.connection_data.clear_pipe();
           try {
                 storage.connection_data.set_port(shcore::opts::convert<int>(
             value, shcore::opts::Source::Command_line));
@@ -391,44 +391,29 @@ Shell_options::Shell_options(
         "Pipe name to use (only classic sessions).",
 #endif
         [this](const std::string&, const char* value) {
-          storage.connection_data.clear_port();
-          storage.connection_data.clear_pipe();
           if (value) {
 #ifdef _WIN32
             storage.connection_data.set_pipe(value);
 #else
             storage.connection_data.set_socket(value);
 #endif
-        } else {
-#ifdef _WIN32
-            storage.connection_data.set_transport_type(mysqlshdk::db::Transport_type::Pipe);
-#else
-            storage.connection_data.set_transport_type(mysqlshdk::db::Transport_type::Socket);
-#endif
+          } else {
+            // NOTE: this is not used on Windows, because this option requires a value there
+            storage.connection_data.set_transport_type(mysqlshdk::db::k_default_local_transport_type);
           }
         }
       )
     (cmdline("-u", "--user=<name>"),
         "User for the connection to the server.")
-    (cmdline("--dbuser=<name>"), deprecated(m_on_warning, "--user"))
     (cmdline("--password=[<pass>]"), "Password to use when connecting to server. "
       "If password is empty, connection will be made without using a password.")
-    (cmdline("--dbpassword[=<pass>]"), deprecated(m_on_warning, "--password"))
     (cmdline("-p", "--password"), "Request password prompt to set the password")
     (cmdline("--password1[=<pass>]"),
       "Password for first factor authentication plugin.")
     (cmdline("--password2[=<pass>]"),
-      "Password for second factor authentication plugin.",
-      [this](const std::string&, const char* value) {
-          storage.connection_data.set_mfa_password(
-            1, value == nullptr ? "" : value);
-      })
+      "Password for second factor authentication plugin.")
     (cmdline("--password3[=<pass>]"),
-      "Password for third factor authentication plugin.",
-      [this](const std::string&, const char* value) {
-          storage.connection_data.set_mfa_password(
-              2, value == nullptr ? "" : value);
-      })
+      "Password for third factor authentication plugin.")
     (cmdline("-C", "--compress[=<value>]"),
         "Use compression in client/server protocol. Valid values: 'REQUIRED', "
         "'PREFFERED', 'DISABLED', 'True', 'False', '1', and '0'. Boolean values"
@@ -465,18 +450,10 @@ Shell_options::Shell_options(
         });
 
   add_startup_options(!flags.is_set(Option_flags::CONNECTION_ONLY))
-    (cmdline("--import <file> <collection>", "--import <file> <table> <col>"),
-        "Import JSON documents from file to collection or table in MySQL"
-        " Server. Set file to - if you want to read the data from stdin."
-        " Requires a default schema on the connection options.")
     (cmdline("-D", "--schema=<name>", "--database=<name>"), "Schema to use.",
       [this](const std::string&, const char* value) {
           storage.connection_data.set_schema(value);
         })
-    (cmdline("--fido-register-factor=<name>"),deprecated(m_on_warning, "--register-factor",
-      [this](const std::string& , const char* value){
-          storage.register_factor.assign(value);
-        }))
     (&storage.register_factor, "",
         cmdline("--register-factor=<name>"),
         "Specifies authentication factor, for which registration needs to be "
@@ -491,11 +468,7 @@ Shell_options::Shell_options(
             storage.webauthn_client_preserve_privacy = shcore::opts::convert<bool>(value,
               shcore::opts::Source::Command_line);
           }
-        })
-    (cmdline("--recreate-schema"), "Drop and recreate the specified schema. "
-        "Schema will be deleted if it exists!", deprecated(m_on_warning, nullptr, [this](const std::string&, const char* ) {
-          storage.recreate_database = true;
-        }));
+        });
 
   add_startup_options(true)
     (cmdline("--mx", "--mysqlx"),
@@ -552,19 +525,15 @@ Shell_options::Shell_options(
         }
 #endif
     )
-    (cmdline("--py", "--python"), "Start in Python mode.",
 #ifdef HAVE_PYTHON
+    (cmdline("--py", "--python"), "Start in Python mode.",
         [this](const std::string&, const char*) {
           storage.initial_mode = shcore::IShell_core::Mode::Python;
         }
-#else
-        [](const std::string&, const char*) {
-          throw std::invalid_argument("Python is not supported.");
-        }
-#endif
     )
     (cmdline("--pym <module>"),
        "Run Python library module as a script. Remaining args are forwarded to it.")
+#endif
     (&storage.wrap_json, "off", cmdline("--json[=<format>]"),
         "Produce output in JSON format. Allowed values: raw, pretty, and off. "
         "If no format is specified pretty format is produced.",
@@ -821,8 +790,12 @@ Shell_options::Shell_options(
       })
     (cmdline("--nw", "--no-wizard"), "Disables wizard mode.",
         assign_value(&storage.wizards, false))
-    (&storage.no_password, false, cmdline("--no-password"),
-        "Sets empty password and disables prompt for password.")
+    (cmdline("--no-password"),
+        "Sets empty password and disables prompt for password.",
+        [this](const std::string&, const char*) {
+          storage.connection_data.set_needs_password(0, false);
+          storage.connection_data.set_password("");
+      })
     (cmdline("-V", "--version"),
         "Prints the version of MySQL Shell.", [this](const std::string&, const char*) {
         if (print_cmd_line_version) {
@@ -878,25 +851,11 @@ Shell_options::Shell_options(
   add_startup_options(!flags.is_set(Option_flags::CONNECTION_ONLY))
     (&storage.execute_dba_statement, "",
         cmdline("--dba=enableXProtocol"), "Enable the X protocol in the target "
-        "server. Requires a connection using classic session.")
-    (cmdline("--trace-proto"),
-        assign_value(&storage.trace_protocol, true));
-
-  add_startup_options()
-    (cmdline("--ssl[=<opt>]"), deprecated(m_on_warning, "--ssl-mode",
-      std::bind(&Shell_options::set_ssl_mode, this, _1, _2), "REQUIRED",
-     {
-       {"1", "REQUIRED"},
-       {"YES", "REQUIRED"},
-       {"0", "DISABLED"},
-       {"NO", "DISABLED"}
-     }))
-    (cmdline("--node"), deprecated(m_on_warning, "--mysqlx", std::bind(
-            &Shell_options::override_session_type, this, _1, _2)))
-    (cmdline("--classic"), deprecated(m_on_warning, "--mysql", std::bind(
-            &Shell_options::override_session_type, this, _1, _2)))
-    (cmdline("--sqln"), deprecated(m_on_warning, "--sqlx", std::bind(
-            &Shell_options::override_session_type, this, _1, _2)));
+        "server. Requires a connection using classic session. Deprecated.")
+#ifndef NDEBUG
+    (cmdline("--trace-proto"), assign_value(&storage.trace_protocol, true))
+#endif
+        ;
 
   add_startup_options(!flags.is_set(Option_flags::CONNECTION_ONLY))
     (
@@ -949,40 +908,44 @@ Shell_options::Shell_options(
 
     mycnf_connection_data = storage.connection_data;
     // temporarily clear passwords so we can detect if we got them from cmdline
-    storage.connection_data.clear_password();
-    storage.connection_data.clear_mfa_passwords();
-
+    for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++) {
+      storage.connection_data.clear_needs_password(f);
+      storage.connection_data.clear_mfa_password(f);
+    }
     handle_cmdline_options(
         argc, argv, false,
         std::bind(&Shell_options::custom_cmdline_handler, this, _1));
 
     if (storage.connection_data.has_password() ||
-        storage.connection_data.has_mfa_passwords()) {
+        storage.connection_data.has_mfa_password(1) ||
+        storage.connection_data.has_mfa_password(2)) {
       got_cmdline_password = true;
     } else {
       // if we didn't get any password in the cmdline, restore the ones we got
       // from my.cnf (if any)
-      if (mycnf_connection_data.has_password())
-        storage.connection_data.set_password(
-            mycnf_connection_data.get_password());
-      if (mycnf_connection_data.has_mfa_passwords())
-        storage.connection_data.set_mfa_passwords(
-            mycnf_connection_data.get_mfa_passwords());
+      for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++) {
+        if (!storage.connection_data.has_needs_password(f) ||
+            !storage.connection_data.needs_password(f)) {
+          if (mycnf_connection_data.has_mfa_password(f))
+            storage.connection_data.set_mfa_password(
+                f, mycnf_connection_data.get_mfa_password(f));
+        }
+      }
     }
 
-    // default to mysql:// if we got connection options from my.cnf but we still
-    // don't know what session type to use
     if (storage.has_connection_data() &&
         !storage.connection_data.has_scheme() &&
-        mycnf_connection_data.has_data())
+        mycnf_connection_data.has_data()) {
+      // default to mysql:// if we got connection options from my.cnf but we
+      // still don't know what session type to use
       storage.connection_data.set_scheme("mysql");
+    }
 
     check_password_conflicts();
     check_ssh_conflicts();
 
     if (!flags.is_set(Option_flags::CONNECTION_ONLY)) {
       check_file_execute_conflicts();
-      check_import_options();
       check_result_format();
     }
     check_connection_options();
@@ -1169,18 +1132,9 @@ bool Shell_options::custom_cmdline_handler(Iterator *iterator) {
     }
 
     iterator->next();
-  } else if ("--user" == option || "--dbuser" == option || "-u" == option) {
+  } else if ("--user" == option || "-u" == option) {
     handle_missing_value(iterator);
 
-    if ("--dbuser" == option) {
-      // Deprecated handler is not going to be invoked, need to inform the
-      // user that --dbuser should not longer be used.
-      // Console is not available at this time, need to use stdout.
-      m_on_warning(
-          "WARNING: The --dbuser option was deprecated, "
-          "please use --user instead.");
-    }
-
     storage.connection_data.set_user(iterator->value());
 
     iterator->next();
@@ -1198,7 +1152,14 @@ bool Shell_options::custom_cmdline_handler(Iterator *iterator) {
 
     iterator->next();
   } else if ("--password" == option || "-p" == option ||
-             "--dbpassword" == option || "--password1" == option) {
+             "--password1" == option || "--password2" == option ||
+             "--password3" == option) {
+    int mfa_password = 0;
+    if (option == "--password2")
+      mfa_password = 1;
+    else if (option == "--password3")
+      mfa_password = 2;
+
     // Note that in any connection attempt, password prompt will be done if
     // the password is missing.
     // The behavior of the password cmd line argument is as follows:
@@ -1213,98 +1174,28 @@ bool Shell_options::custom_cmdline_handler(Iterator *iterator) {
     // -p<value> sets the password to <value>
     // --password=<value> sets the password to <value>
 
-    if ("--dbpassword" == option) {
-      // Deprecated handler is not going to be invoked, need to inform the
-      // user that --dbpassword should not longer be used.
-      // Console is not available at this time, need to use stdout.
-      m_on_warning(
-          "WARNING: The --dbpassword option was deprecated, "
-          "please use --password instead.");
-    }
+    // --password1 is an alias for -p/--password
+    // --password2 and --password3 are MFA passwords and handled like -p
 
+    // if a password option is specified, it's needed
+    storage.connection_data.set_needs_password(mfa_password, true);
     if (shcore::Options::Iterator::Type::NO_VALUE == iterator->type()) {
-      storage.prompt_password = true;
+      storage.connection_data.clear_mfa_password(mfa_password);
       iterator->next_no_value();
+      storage.prompt_password = true;
     } else if (shcore::Options::Iterator::Type::SEPARATE_VALUE !=
                iterator->type()) {
       // --password=value || -pvalue
       const auto value = iterator->value();
-      storage.connection_data.set_mfa_password(0, value);
-
+      storage.connection_data.set_mfa_password(mfa_password, value);
       const std::string stars(strlen(value), '*');
 
       strncpy(const_cast<char *>(value), stars.c_str(), stars.length() + 1);
       iterator->next();
-      storage.prompt_password = false;
     } else {  // --password value (value is ignored)
-      storage.prompt_password = true;
+      storage.connection_data.clear_mfa_password(mfa_password);
       iterator->next_no_value();
     }
-  } else if ("--import" == option) {
-    m_on_warning(
-        "WARNING: The --import option was deprecated and will be removed in "
-        "a future version of the MySQL Shell. Please consider using the CLI "
-        "call for import-json instead.\nFor additional information: mysqlsh -- "
-        "util import-json --help");
-
-    const auto cmdline = iterator->iterator();
-
-    storage.import_args.push_back(cmdline->get());  // omit --import
-
-    // Gets the positional arguments for --import
-    // As they define the target database object for the data
-    while (cmdline->valid()) {
-      // We append --import arguments until next shell option in program
-      // argument list, i.e. -* or --*. Single char '-' is a --import argument.
-      const char *arg = cmdline->peek();
-      if (arg[0] == '-' && arg[1] != '\0') {
-        break;
-      }
-      storage.import_args.push_back(cmdline->get());
-    }
-
-    if (storage.import_args[1] == "-") {
-      // STDIN import will be handled directly in main
-      // Here we store the import options
-      while (cmdline->valid()) storage.import_opts.push_back(cmdline->get());
-    } else {
-      // Non STDIN import is handled as a CLI API call
-      if (m_shell_cli_operation)
-        throw std::invalid_argument(
-            "MySQL Shell can handle only one operation at a time");
-      m_shell_cli_operation =
-          std::make_unique<shcore::cli::Shell_cli_operation>();
-      m_shell_cli_operation->set_object_name("util");
-      m_shell_cli_operation->set_method_name("importJson");
-
-      m_shell_cli_operation->add_cmdline_argument(storage.import_args.at(1));
-
-      // Parses the positional arguments to set them on the CLI operation
-      switch (storage.import_args.size()) {
-        case 4: {
-          const std::string &target = storage.import_args.at(2);
-          const std::string &column = storage.import_args.at(3);
-          m_shell_cli_operation->add_cmdline_argument("--table=" + target);
-          m_shell_cli_operation->add_cmdline_argument("--tableColumn=" +
-                                                      column);
-          break;
-        }
-        case 3: {
-          const std::string &target = storage.import_args.at(2);
-          m_shell_cli_operation->add_cmdline_argument("--collection=" + target);
-          break;
-        }
-        case 2:
-          break;
-        default:
-          throw std::runtime_error(
-              "Usage: --import <filename> [<collection>|<table> <column>] "
-              "[options]");
-      }
-
-      // All of the options above are valid
-      m_shell_cli_operation->parse(cmdline);
-    }
   } else if ("-m" == option) {
     bool handled = false;
 
@@ -1341,9 +1232,20 @@ bool Shell_options::custom_cmdline_handler(Iterator *iterator) {
         "WARNING: The --dba-log-sql option was deprecated, "
         "please use --log-sql instead.");
     return false;
+  } else if ("--dba" == option) {
+    if (iterator->value()) {
+      const std::string value = iterator->value();
+      if ("enableXProtocol" == value) {
+        deprecated(m_on_warning, nullptr,
+                   std::bind(&Shell_options::override_session_type, this, _1,
+                             _2))(value, nullptr);
+      }
+    }
+    return false;
   } else {
     return false;
   }
+
   return true;
 }
 
@@ -1391,21 +1293,6 @@ void Shell_options::check_password_conflicts() {
       throw std::runtime_error(error);
     }
   }
-
-  if (storage.no_password && storage.prompt_password) {
-    const auto error =
-        "Conflicting options: --password and --no-password option cannot be "
-        "used together.";
-    throw std::runtime_error(error);
-  }
-
-  if (storage.no_password && storage.connection_data.has_password() &&
-      !storage.connection_data.get_password().empty()) {
-    const auto error =
-        "Conflicting options: --no-password cannot be used if password is "
-        "provided.";
-    throw std::runtime_error(error);
-  }
 }
 
 void Shell_options::check_file_execute_conflicts() {
@@ -1445,21 +1332,6 @@ void Shell_options::check_result_format() {
         storage.result_format.c_str(), storage.wrap_json.c_str()));
 }
 
-void Shell_options::check_import_options() {
-  bool is_schema_set = storage.connection_data.has_schema();
-  if (!storage.import_args.empty()) {
-    if (!storage.has_connection_data()) {
-      const auto error = "Error: --import requires an active session.";
-      throw std::runtime_error(error);
-    }
-    if (!is_schema_set) {
-      const auto error =
-          "Error: --import requires a default schema on the active session.";
-      throw std::runtime_error(error);
-    }
-  }
-}
-
 void Shell_options::check_connection_options() {
   std::vector<std::string> connection_dependent_options;
   if (!storage.register_factor.empty()) {
