@@ -507,7 +507,7 @@ void Command_line_shell::quiet_print() {
  * Used to temporarily enable printing when a global session is being created
  * from command line arguments.
  *
- * This is required because when using the FIDO
+ * This is required because when using the webauthn
  * authentication plugin, the instructions to use the FIDO device will be
  * printed by the authentication plugin, but at the connection time the printing
  * is disabled (or delayed), using this function it can be enabled properly so
@@ -622,7 +622,7 @@ void Command_line_shell::load_state(shcore::Shell_core::Mode mode) {
     if (shcore::is_file(old_hist_file)) {
       shcore::copy_file(old_hist_file,
                         history_file(shcore::IShell_core::Mode::SQL));
-#ifdef HAVE_JS
+#ifdef HAVE_V8
       shcore::copy_file(old_hist_file,
                         history_file(shcore::IShell_core::Mode::JavaScript));
 #endif
@@ -916,11 +916,6 @@ char *Command_line_shell::readline(const char *prompt) {
     console->enable_global_pager();
   }
 
-  if (3 == linenoiseKeyType()) {
-    // reading was interrupted
-    return nullptr;
-  }
-
   if (!tmp) {
     switch (linenoiseKeyType()) {
       case 1:  // ^C
@@ -1072,7 +1067,7 @@ void Command_line_shell::command_loop() {
 
     switch (_shell->interactive_mode()) {
       case shcore::Shell_core::Mode::SQL:
-#ifdef HAVE_JS
+#ifdef HAVE_V8
         message =
             "Currently in SQL mode. Use \\js or \\py to switch the shell to "
             "a scripting language.";
@@ -1193,7 +1188,6 @@ void Command_line_shell::print_cmd_line_helper() {
   println("       mysqlsh [OPTIONS] [URI] --cluster|--replicaset");
   println("       mysqlsh [OPTIONS] [URI] -- <object> <method> [<method-args>...]");
   println("       mysqlsh [OPTIONS] [URI] --dba enableXProtocol");
-  println("       mysqlsh [OPTIONS] [URI] --import {<file>|-} [<collection>|<table> <column>]");
   println("");
   // clang-format on
   std::vector<std::string> details = Shell_options(0, nullptr).get_details();
