@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -21,8 +23,6 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "modules/mod_utils.h"
-#include "modules/util/json_importer.h"
 #include "mysqlsh/cmdline_shell.h"
 #include "mysqlsh/json_shell.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
@@ -31,12 +31,10 @@
 #include "mysqlshdk/libs/db/mysql/auth_plugins/fido.h"
 #include "mysqlshdk/libs/textui/textui.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/document_parser.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
-#include "mysqlshdk/shellcore/shell_cli_mapper.h"
 #ifdef HAVE_PYTHON
 #include "mysqlshdk/include/scripting/python_context.h"
 #endif
@@ -66,6 +64,13 @@ static int enable_x_protocol(
     std::shared_ptr<mysqlsh::Command_line_shell> shell) {
   auto shell_session = shell->shell_context()->get_dev_session();
 
+  if (!shell_session) {
+    mysqlsh::current_console()->print_error(
+        "A session to the target instance is required to execute "
+        "the enableXProtocol command.\n");
+    return 1;
+  }
+
   mysqlshdk::db::Connection_options connection_options =
       shell_session->get_connection_options();
 
@@ -76,6 +81,7 @@ static int enable_x_protocol(
   std::string temp_uri =
       connection_options.as_uri(mysqlshdk::db::uri::formats::full());
 
+  shell->switch_shell_mode(shcore::Shell_core::Mode::JavaScript, {});
   shell->process_line("var uri_template = '" + temp_uri + "'");
 
   // clang-format off
@@ -224,115 +230,10 @@ int execute_dba_command(std::shared_ptr<mysqlsh::Command_line_shell> shell,
   return enable_x_protocol(shell);
 }
 
-int execute_import_command(mysqlsh::Command_line_shell *shell,
-                           const std::vector<std::string> &import_args,
-                           const std::vector<std::string> &import_opts) {
-  auto shell_session = shell->shell_context()->get_dev_session();
-
-  if (!shell_session) {
-    throw shcore::Exception::runtime_error(
-        "Please connect the shell to the MySQL server.");
-  }
-
-  auto node_type = shell_session->get_node_type();
-  if (node_type.compare("X") != 0) {
-    throw shcore::Exception::runtime_error(
-        "An X Protocol session is required for JSON import.");
-  }
-
-  mysqlshdk::db::Connection_options connection_options =
-      shell_session->get_connection_options();
-
-  std::shared_ptr<mysqlshdk::db::mysqlx::Session> xsession =
-      mysqlshdk::db::mysqlx::Session::create();
-
-  if (mysqlsh::current_shell_options()->get().trace_protocol) {
-    xsession->enable_protocol_trace(true);
-  }
-
-  xsession->connect(connection_options);
-
-  mysqlsh::Prepare_json_import prepare{xsession};
-  const std::string &schema = shell_session->get_current_schema();
-  prepare.schema(schema);
-  prepare.use_stdin();
-
-  switch (import_args.size()) {
-    case 2:
-      mysqlsh::current_console()->raw_print(
-          "Target collection or table must be set if filename is a STDIN\n"
-          "Usage: --import filename [collection] | [table [column]]\n",
-          mysqlsh::Output_stream::STDERR);
-      return 1;
-    case 3: {
-      const std::string &target_table = import_args.at(2);
-      std::string type;
-      try {
-        shell_session->db_object_exists(type, target_table, schema);
-      } catch (const mysqlshdk::db::Error &e) {
-        // ignore errors generated by this call
-      }
-      if (type == "VIEW") {
-        throw std::runtime_error(
-            "'" + schema + "'.'" + target_table +
-            "' is a view. Target must be table or collection.");
-      } else if (type == "TABLE") {
-        prepare.table(target_table);
-      } else {
-        prepare.collection(target_table);
-      }
-      break;
-    }
-    case 4: {
-      prepare.table(import_args.at(2));
-      prepare.column(import_args.at(3));
-      break;
-    }
-    default:
-      mysqlsh::current_console()->raw_print(
-          "Usage: --import filename [collection] | [table [column]]\n",
-          mysqlsh::Output_stream::STDERR);
-      return 1;
-  }
-
-  auto importer = prepare.build();
-  mysqlsh::current_console()->print_info(
-      prepare.to_string() + " in MySQL Server at " +
-      connection_options.as_uri(mysqlshdk::db::uri::formats::only_transport()) +
-      "\n");
-  importer.set_print_callback([](const std::string &msg) -> void {
-    mysqlsh::current_console()->print(msg);
-  });
-
-  try {
-    shcore::cli::Shell_cli_mapper mapper;
-    for (auto &option : import_opts) {
-      mapper.add_cmdline_argument(option);
-    }
-
-    shcore::Dictionary_t options = shcore::make_dict();
-    for (const auto &arg : mapper.get_cmdline_args()) {
-      options->set(arg.option, arg.value);
-    }
-
-    shcore::Document_reader_options roptions;
-    shcore::Document_reader_options::options().unpack(options, &roptions);
-
-    importer.load_from(roptions);
-  } catch (...) {
-    importer.print_stats();
-    throw;
-  }
-
-  importer.print_stats();
-  return 0;
-}
-
 // Detects whether the shell will be running in interactive mode or not
 // Non interactive mode is used when:
 // - A file is processed using the --file option
 // - A file is processed through the OS redirection mechanism
-// - It is an --import operation
 // - It is a API CLI operation
 // - stdin is not a tty
 //
@@ -360,7 +261,6 @@ void detect_interactive(mysqlsh::Shell_options *options, bool *stdin_is_tty,
                      options->get().run_module.empty() &&
                      options->get().execute_statement.empty() &&
                      options->get().execute_dba_statement.empty() &&
-                     options->get().import_args.empty() &&
                      !options->get_shell_cli_operation();
 
   // The --interactive option forces the shell to work emulating the
@@ -873,8 +773,8 @@ int main(int argc, char **argv) {
           }
 
           // Connect to the requested instance
-          shell->connect(target, options.recreate_database, true,
-                         std::move(extra_init));
+          shell->connect(target, true, std::move(extra_init),
+                         !options.prompt_password);
 
           // If redirect is requested, then reconnect to the right instance
           handle_redirect(shell, options.redirect_session);
@@ -954,9 +854,6 @@ int main(int argc, char **argv) {
         ret_val = shell->process_file(options.run_file, options.script_argv);
       } else if (!options.run_module.empty()) {
         ret_val = shell->run_module(options.run_module, options.script_argv);
-      } else if (!options.import_args.empty()) {
-        ret_val = execute_import_command(shell.get(), options.import_args,
-                                         options.import_opts);
       } else if (options.interactive) {
         shell->load_state();
 
