@@ -23,6 +23,8 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#ifdef USE_MYSQLX_FULL_PROTO
+
 #include <gtest/gtest_prod.h>
 #include <cstdio>
 #include "src/mysqlsh/cmdline_shell.h"
@@ -34,7 +36,7 @@
 namespace tests {
 class Collection_find : public Shell_core_test_wrapper {
  protected:
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   const std::string start_txn_stmt = "session.startTransaction();";
   const std::string lock_shared_fn = "lockShared";
   const std::string lock_exclusive_fn = "lockExclusive";
@@ -60,7 +62,7 @@ class Collection_find : public Shell_core_test_wrapper {
     // Connects the two shell instances to be used on these tests
     execute("\\connect --mx " + _uri);
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     execute("var schema = session.getSchema('test_locking');");
     execute("var col = schema.getCollection('test');");
 #else
@@ -84,14 +86,17 @@ class Collection_find : public Shell_core_test_wrapper {
   static void SetUpTestCase() {
     tests::Shell_test_wrapper global_shell;
     global_shell.execute("\\connect --mx " + shell_test_server_uri('x'));
+    global_shell.execute("\\js");
 
     // preparation
     global_shell.execute(
         "session.sql('drop schema if exists test_locking').execute();");
-#ifdef HAVE_JS
+#ifdef HAVE_V8
+    global_shell.execute("\\js");
     global_shell.execute("var schema = session.createSchema('test_locking');");
     global_shell.execute("var col = schema.createCollection('test');");
 #else
+    global_shell.execute("\\py");
     global_shell.execute("schema = session.create_schema('test_locking');");
     global_shell.execute("col = schema.create_collection('test');");
 #endif
@@ -109,9 +114,11 @@ class Collection_find : public Shell_core_test_wrapper {
     tests::Shell_test_wrapper global_shell;
     global_shell.execute("\\connect --mx " + shell_test_server_uri('x'));
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
+    global_shell.execute("\\js");
     global_shell.execute("session.dropSchema('test_locking');");
 #else
+    global_shell.execute("\\py");
     global_shell.execute("session.drop_schema('test_locking');");
 #endif
     global_shell.execute("session.close();");
@@ -617,3 +624,5 @@ TEST_F(Collection_find, lock_exclusive_skip_lock_constant) {
   _cout.str("");
 }
 }  // namespace tests
+
+#endif
