@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -33,6 +35,7 @@
 #include "mysqlshdk/libs/db/mysql/session.h"
 #include "mysqlshdk/libs/storage/backend/memory_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
+#include "mysqlshdk/libs/utils/utils_string.h"
 
 #include "unittest/gtest_clean.h"
 #include "unittest/modules/dummy_dumpdir.h"
@@ -429,6 +432,8 @@ class Load_dump_mocked : public Shell_core_test_wrapper {
           EXPECT_CALL(*mock, get_connection_id())
               .WillRepeatedly(Return(m_session_count));
           EXPECT_CALL(*mock, is_open()).WillRepeatedly(Return(false));
+          EXPECT_CALL(*mock, get_server_version())
+              .WillRepeatedly(Return(Version(m_version)));
 
           if (m_auto_generate_pk_value &&
               *m_auto_generate_pk_value != m_create_invisible_pks) {
@@ -490,6 +495,27 @@ class Load_dump_mocked : public Shell_core_test_wrapper {
                   EXPECT_CALL(*r, get_warning_count())
                       .WillRepeatedly(Return(0));
                   return r;
+                } else if ("SELECT PS_CURRENT_THREAD_ID()" == sql ||
+                           shcore::str_beginswith(
+                               sql,
+                               "SELECT THREAD_ID FROM "
+                               "performance_schema.threads ")) {
+                  auto r = std::make_shared<testing::Mock_result>();
+                  r->add_result({"THREAD_ID"},
+                                std::vector<mysqlshdk::db::Type>(
+                                    1, mysqlshdk::db::Type::String))
+                      .add_row({"1"});
+                  return r;
+                } else if (shcore::str_beginswith(
+                               sql,
+                               "SELECT CAST(VARIABLE_VALUE AS UNSIGNED) "
+                               "FROM performance_schema.global_status ")) {
+                  auto r = std::make_shared<testing::Mock_result>();
+                  r->add_result({"VARIABLE_VALUE"},
+                                std::vector<mysqlshdk::db::Type>(
+                                    1, mysqlshdk::db::Type::String))
+                      .add_row({"0"});
+                  return r;
                 }
                 return {};
               });
@@ -612,7 +638,7 @@ class Load_dump_mocked : public Shell_core_test_wrapper {
         loader.m_progress_thread.finish();
       });
 
-      loader.execute_tasks();
+      loader.execute_tasks(true);
     }
   }
 
@@ -628,7 +654,7 @@ class Load_dump_mocked : public Shell_core_test_wrapper {
   std::function<void(const std::string &)> m_on_load_data;
 
   std::string m_version = "8.0.20";
-  mysqlshdk::null_bool m_auto_generate_pk_value;
+  std::optional<bool> m_auto_generate_pk_value;
   bool m_create_invisible_pks = false;
 };
 
@@ -681,7 +707,7 @@ TEST_F(Load_dump_mocked, filter_user_script_for_mds) {
 
   Dump_loader loader(options);
 
-  loader.m_session = options.base_session();
+  loader.m_session = mock_main_session;
 
   shcore::iterdir(
       shcore::path::join_path(g_test_home,
