@@ -1,15 +1,17 @@
-/* Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -49,7 +51,7 @@ using ::testing::AnyOf;
 using ::testing::HasSubstr;
 using ::testing::Not;
 
-using common::Filtering_options;
+using mysqlshdk::db::Filtering_options;
 using User_filters = Filtering_options::User_filters;
 
 std::string to_string(Schema_dumper::Issue::Status s) {
@@ -172,7 +174,7 @@ class Schema_dumper_test : public Shell_core_test_wrapper {
 
   static std::shared_ptr<mysqlshdk::db::ISession> connect_session() {
     auto session = mysqlshdk::db::mysql::Session::create();
-    session->connect(shcore::get_connection_options(_mysql_uri));
+    session->connect(mysqlshdk::db::Connection_options(_mysql_uri));
     return session;
   }
 
@@ -206,13 +208,14 @@ class Schema_dumper_test : public Shell_core_test_wrapper {
   std::shared_ptr<mysqlshdk::db::ISession> session;
   std::string file_path;
   std::unique_ptr<IFile> file;
-  bool run_directory_tests = false;
+  static bool run_directory_tests;
   static bool initialized;
   static constexpr auto db_name = "mysqldump_test_db";
   static constexpr auto compat_db_name = "mysqlaas_compat";
   static constexpr auto crazy_names_db = "crazy_names_db";
 };
 
+bool Schema_dumper_test::run_directory_tests = false;
 bool Schema_dumper_test::initialized = false;
 
 TEST_F(Schema_dumper_test, dump_table) {
@@ -791,6 +794,7 @@ TEST_F(Schema_dumper_test, dump_filtered_grants) {
       "CREATE USER IF NOT EXISTS 'dumptestuser'@'localhost' IDENTIFIED BY "
       "'pwd';");
   session->execute("GRANT SELECT ON * . * TO 'dumptestuser'@'localhost';");
+
   std::string partial_revoke = "ON";
   if (_target_server_version >= mysqlshdk::utils::Version(8, 0, 20)) {
     partial_revoke = session->query("show variables like 'partial_revokes';")
@@ -902,7 +906,10 @@ TEST_F(Schema_dumper_test, dump_filtered_grants) {
   testutil->call_mysqlsh_c({_mysql_uri, "--sql", "-f", file_path});
   EXPECT_TRUE(output_handler.std_err.empty());
 
+  session->execute("drop user 'admin'@'localhost';");
+  session->execute("drop user 'admin2'@'localhost';");
   session->execute("drop user 'dumptestuser'@'localhost';");
+
   if (_target_server_version >= mysqlshdk::utils::Version(8, 0, 20)) {
     session->execute("DROP ROLE da_dumper");
     session->execute("DROP USER `dave`@`%`");
@@ -1132,8 +1139,7 @@ TEST_F(Schema_dumper_test, opt_mysqlaas) {
   filters.users().exclude(std::array{"mysql", "root"});
   EXPECT_NO_THROW(iss = sd.dump_grants(file.get(), filters));
 
-  auto expected_issues =
-      _target_server_version < mysqlshdk::utils::Version(8, 0, 0) ?
+  auto expected_issues = run_directory_tests ?
       std::set<std::string>{
       "User 'testusr1'@'localhost' is granted restricted privileges: FILE, "
       "RELOAD, SUPER",
@@ -1147,11 +1153,9 @@ TEST_F(Schema_dumper_test, opt_mysqlaas) {
       " `mysql`.`abradabra`"} :
       std::set<std::string>{
         "User 'testusr1'@'localhost' is granted restricted privileges: "
-        "BINLOG_ADMIN, FILE, RELOAD, SUPER",
-        "User 'testusr2'@'localhost' is granted restricted privilege: SUPER",
+        "BINLOG_ADMIN, FILE, RELOAD",
         "User 'testusr3'@'localhost' is granted restricted privileges: "
         "BINLOG_ADMIN, FILE, RELOAD",
-        "User 'testusr4'@'localhost' is granted restricted privilege: SUPER",
         "User 'testusr5'@'localhost' is granted restricted privilege: FILE",
         "User 'testusr6'@'localhost' is granted restricted privilege: FILE",
         "User 'testusr6'@'localhost' has explicit grants on mysql "
@@ -1303,7 +1307,7 @@ TEST_F(Schema_dumper_test, compat_ddl) {
                  "  PRIMARY KEY (`pk`)\n"
                  ") ENGINE=InnoDB DEFAULT CHARSET=latin1 /* DATA "
                  "DIRECTORY='" +
-                     shcore::path::tmpdir() + "/'*/ ;");
+                     shcore::path::tmpdir() + "/'*/;");
 
     EXPECT_TABLE("path_tbl2",
                  {"Table `mysqlaas_compat`.`path_tbl2` had {DATA|INDEX} "
@@ -1316,7 +1320,7 @@ TEST_F(Schema_dumper_test, compat_ddl) {
                  ") ENGINE=InnoDB DEFAULT CHARSET=latin1 /* DATA "
                  "DIRECTORY='" +
                      shcore::path::tmpdir() + "/' INDEX DIRECTORY='" +
-                     shcore::path::tmpdir() + "/'*/ ;");
+                     shcore::path::tmpdir() + "/'*/;");
 
     EXPECT_TABLE("path_tbl3",
                  {"Table `mysqlaas_compat`.`path_tbl3` had {DATA|INDEX} "
@@ -1327,7 +1331,7 @@ TEST_F(Schema_dumper_test, compat_ddl) {
                  "  `pk` int(11) NOT NULL,\n  PRIMARY KEY (`pk`)\n"
                  ") ENGINE=InnoDB DEFAULT CHARSET=latin1 /* INDEX "
                  "DIRECTORY='" +
-                     shcore::path::tmpdir() + "/'*/ ;");
+                     shcore::path::tmpdir() + "/'*/;");
 
     EXPECT_TABLE("part_tbl2",
                  {"Table `mysqlaas_compat`.`part_tbl2` had {DATA|INDEX} "
