@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -73,7 +75,8 @@ class Mysqlsh_extension_test : public Command_line_test {
   void run(const std::vector<std::string> &extra = {}) {
     shcore::create_file(k_file, shcore::str_join(m_test_input, "\n"));
 
-    std::vector<const char *> args = {_mysqlsh, _uri.c_str(), "--interactive"};
+    std::vector<const char *> args = {_mysqlsh, _uri.c_str(), "--interactive",
+                                      "--js"};
 
     for (const auto &e : extra) {
       args.emplace_back(e.c_str());
@@ -1067,24 +1070,27 @@ shell.register_global('errtest', obj)
   add_js_test("errtest.connect('raaat:r@127.0.0.1:" + _mysql_port + "')");
 
   run();
+  // The produced error is inconsistent after mysql_native_password was disabled
+  // by default, posibilities include:
+  // - errtest.connect: mysql.get_session: Access denied for user
+  // 'raaat'@'localhost' (using password: YES) (MySQL Error 1045)
+  // - errtest.connect: mysql.get_session: Plugin 'mysql_native_password' is not
+  // loaded (MySQL Error 1524)
+  // For that reason, only the common part on the errors is verified
+
   MY_EXPECT_CMD_OUTPUT_NOT_CONTAINS("WARNING: Found errors loading plugins");
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "RuntimeError: errtest.throw_error: py error got thrown");
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "mysqlsh.Error: Shell Error (99999): errtest.throw_error: py another "
       "error got thrown");
-  MY_EXPECT_CMD_OUTPUT_CONTAINS(
-      "mysqlsh.DBError: MySQL Error (1045): errtest.connect: "
-      "mysql.get_session: Access denied for user 'rooot'@'localhost' (using "
-      "password: YES)");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("errtest.connect: mysql.get_session:");
 
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "errtest.throwError: js error got thrown (RuntimeError)");
   MY_EXPECT_CMD_OUTPUT_CONTAINS(
       "errtest.throwError: js another error got thrown (MYSQLSH 99998)");
-  MY_EXPECT_CMD_OUTPUT_CONTAINS(
-      "errtest.connect: mysql.get_session: Access denied for user "
-      "'raaat'@'localhost' (using password: YES) (MySQL Error 1045)");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("errtest.connect: mysql.get_session: ");
 
   wipe_out();
   delete_user_plugin("error-reporting");
