@@ -1,15 +1,17 @@
-/* Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2017, 2024, Oracle and/or its affiliates.
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.
 
- This program is also distributed with certain software (including
- but not limited to OpenSSL) that is licensed under separate terms, as
- designated in a particular file or component or in included license
+ This program is designed to work with certain software (including
+ but not limited to OpenSSL) that is licensed under separate terms,
+ as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
- separately licensed software that they have included with MySQL.
+ separately licensed software that they have either included with
+ the program or referenced in the documentation.
+
  This program is distributed in the hope that it will be useful,  but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -44,6 +46,24 @@ using mysqlshdk::db::uri_connection_attributes;
 using mysqlshdk::utils::nullable_options::Comparison_mode;
 namespace testing {
 
+namespace {
+
+void EXPECT_TRANSPORT_TYPE(const mysqlshdk::db::Connection_options &d) {
+  SCOPED_TRACE(d.as_uri(mysqlshdk::db::uri::formats::full()));
+
+  ASSERT_TRUE(d.has_transport_type());
+
+#ifdef _WIN32
+  // on Windows, pipe is only used when host is not set, or is set to '.'
+  EXPECT_EQ(Transport_type::Tcp, d.get_transport_type());
+#else
+  EXPECT_EQ(mysqlshdk::db::k_default_local_transport_type,
+            d.get_transport_type());
+#endif
+}
+
+}  // namespace
+
 TEST(Connection_options, default_initialization) {
   Connection_options options;
 
@@ -542,21 +562,33 @@ TEST(Connection_options, compression_level) {
 }
 
 TEST(Connection_options, set_host) {
-  // localhost does not determine the session type
+  // localhost defaults to socket for mysql, tcp for mysqlx
+  // NOTE: mysqlx is default now, but it should be changed to mysql
   {
     mysqlshdk::db::Connection_options data;
     data.set_host("localhost");
 
     EXPECT_TRUE(data.has_host());
     EXPECT_STREQ("localhost", data.get_host().c_str());
-    EXPECT_FALSE(data.has_transport_type());
+    data.set_default_data();
+    EXPECT_TRUE(data.has_transport_type());
+    EXPECT_EQ(Transport_type::Tcp, data.get_transport_type());
+  }
+
+  {
+    mysqlshdk::db::Connection_options data;
+    data.set_host("localhost");
+    data.set_scheme("mysql");
+    data.set_default_data();
+
+    EXPECT_TRANSPORT_TYPE(data);
   }
 
   // Any other host would set the connection type to tcp
   {
     mysqlshdk::db::Connection_options data;
     data.set_host("127.0.0.1");
-
+    data.set_default_data();
     EXPECT_TRUE(data.has_host());
     EXPECT_TRUE(data.has_transport_type());
     EXPECT_STREQ("127.0.0.1", data.get_host().c_str());
@@ -568,7 +600,7 @@ TEST(Connection_options, set_host) {
     mysqlshdk::db::Connection_options data;
     data.set_port(3306);
     data.set_host("localhost");
-
+    data.set_default_data();
     EXPECT_TRUE(data.has_host());
     EXPECT_STREQ("localhost", data.get_host().c_str());
     EXPECT_EQ(Transport_type::Tcp, data.get_transport_type());
@@ -586,12 +618,17 @@ TEST(Connection_options, set_host) {
 TEST(Connection_options, set_socket) {
   {
     mysqlshdk::db::Connection_options data;
+#ifdef _WIN32
+    data.set_pipe("/Path/To/Socket");
+#else
     data.set_socket("/Path/To/Socket");
-
+#endif
+    data.set_default_data();
     EXPECT_TRUE(data.has_socket());
     EXPECT_STREQ("/Path/To/Socket", data.get_socket().c_str());
     EXPECT_TRUE(data.has_transport_type());
-    EXPECT_EQ(Transport_type::Socket, data.get_transport_type());
+    EXPECT_EQ(mysqlshdk::db::k_default_local_transport_type,
+              data.get_transport_type());
   }
 
   // Using socket is allowed for localhost
@@ -599,14 +636,13 @@ TEST(Connection_options, set_socket) {
     mysqlshdk::db::Connection_options data;
     data.set_host("localhost");
     EXPECT_NO_THROW(data.set_socket("/Path/To/Socket"));
-
+    data.set_default_data();
     EXPECT_TRUE(data.has_host());
     EXPECT_TRUE(data.has_socket());
-    EXPECT_TRUE(data.has_transport_type());
 
     EXPECT_STREQ("localhost", data.get_host().c_str());
     EXPECT_STREQ("/Path/To/Socket", data.get_socket().c_str());
-    EXPECT_EQ(Transport_type::Socket, data.get_transport_type());
+    EXPECT_TRANSPORT_TYPE(data);
   }
 
   // Using socket is now allowed for localhost if port was defined
@@ -614,26 +650,41 @@ TEST(Connection_options, set_socket) {
     mysqlshdk::db::Connection_options data;
     data.set_host("localhost");
     data.set_port(3307);
-
+    data.set_default_data();
     EXPECT_EQ(Transport_type::Tcp, data.get_transport_type());
-
-    EXPECT_NO_THROW(data.set_socket("/Path/To/Socket"));
-
-    EXPECT_EQ(Transport_type::Socket, data.get_transport_type());
   }
 
-  // Using socket is now allowed for 127.0.0.1
+  {
+    mysqlshdk::db::Connection_options data;
+    data.set_host("localhost");
+    data.set_port(3307);
+    EXPECT_NO_THROW(data.set_socket("/Path/To/Socket"));
+    data.set_default_data();
+    EXPECT_TRANSPORT_TYPE(data);
+  }
+
+  // Setting socket is allowed if host is 127.0.0.1, but socket is only used if
+  // host is localhost
   {
     mysqlshdk::db::Connection_options data;
     data.set_host("127.0.0.1");
     EXPECT_NO_THROW(data.set_socket("/Path/To/Socket"));
+    data.set_default_data();
 
     EXPECT_TRUE(data.has_host());
     EXPECT_TRUE(data.has_socket());
     EXPECT_TRUE(data.has_transport_type());
-
     EXPECT_STREQ("127.0.0.1", data.get_host().c_str());
-    EXPECT_EQ(Transport_type::Socket, data.get_transport_type());
+    EXPECT_EQ(Transport_type::Tcp, data.get_transport_type());
+  }
+  {
+    mysqlshdk::db::Connection_options data;
+    data.set_host("127.0.0.1");
+    EXPECT_NO_THROW(data.set_socket("/Path/To/Socket"));
+    data.set_host("localhost");
+    data.set_default_data();
+
+    EXPECT_TRANSPORT_TYPE(data);
   }
 
   // Using socket is now allowed for 127.0.0.1 if port was defined
