@@ -41,6 +41,7 @@
 #include "modules/mod_mysql_session.h"
 #include "shellcore/base_session.h"
 #include "shellcore/shell_core.h"
+#include "shellcore/shell_jscript.h"
 #include "shellcore/shell_python.h"
 #include "shellcore/shell_sql.h"
 #include "utils/utils_general.h"
@@ -234,7 +235,7 @@ class Interrupt_mysql : public Shell_core_test_wrapper {
       const std::string & /* uri */, const std::string & /* password */) {
     std::shared_ptr<mysqlsh::ShellBaseSession> session(
         new mysqlsh::mysql::ClassicSession());
-    auto connection_options = shcore::get_connection_options(_mysql_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_mysql_uri);
     session->connect(connection_options);
     return session;
   }
@@ -244,7 +245,7 @@ class Interrupt_mysql : public Shell_core_test_wrapper {
     std::shared_ptr<mysqlsh::ShellBaseSession> session(
         new mysqlsh::mysqlx::Session());
     shcore::Argument_list args;
-    auto connection_options = shcore::get_connection_options(_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_uri);
     session->connect(connection_options);
     return session;
   }
@@ -265,7 +266,7 @@ class Interrupt_mysql : public Shell_core_test_wrapper {
   static const int k_processlist_command_column = 4;
   static void session_wait(uint64_t sid, int timeout, const char *str,
                            int column = 7) {
-    auto connection_options = shcore::get_connection_options(_mysql_uri);
+    auto connection_options = mysqlshdk::db::Connection_options(_mysql_uri);
     auto conn = mysqlshdk::db::mysql::Session::create();
     conn->connect(connection_options);
     timeout *= 1000;
@@ -345,7 +346,7 @@ TEST_F(Interrupt_mysql, sql_classic) {
     thd.join();
   }
 }
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Interrupt_mysql, sql_classic_javascript) {
   mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
   // Test case for FR5-a
@@ -479,7 +480,7 @@ TEST_F(Interrupt_mysqlx, sql_x_err) {
   }
 }
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 // Test that JS code running SQL gets interrupted
 TEST_F(Interrupt_mysqlx, db_javascript_sql) {
   mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
@@ -937,7 +938,7 @@ TEST_F(Interrupt_mysqlx, db_python_crud_collection2) {
   }
 }
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Interrupt_mysqlx, db_javascript_drop) {
   mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
   // Test case for FR5 b
@@ -1067,7 +1068,7 @@ TEST_F(Interrupt_mysqlx, db_python_drop) {
 }
 
 // Test that native JavaScript code gets interrupted
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Interrupt_mysql, javascript) {
   mysqlsh::Scoped_interrupt interrupt_handler(m_current_interrupt);
   // Test case for FR4 JS
