@@ -24,12 +24,6 @@ FUNCTIONS
       addReplicaInstance(instance[, options])
             Adds a Read Replica Instance to the Cluster.
 
-      checkInstanceState(instance)
-            Verifies the instance gtid state in relation to the cluster.
-
-            ATTENTION: This function is deprecated and will be removed in a
-                       future release of MySQL Shell.
-
       createClusterSet(domainName[, options])
             Creates a MySQL InnoDB ClusterSet from an existing standalone
             InnoDB Cluster.
@@ -49,7 +43,7 @@ FUNCTIONS
       fenceWrites()
             Fences a Cluster from Write Traffic.
 
-      forceQuorumUsingPartitionOf(instance[, password])
+      forceQuorumUsingPartitionOf(instance)
             Restores the cluster from quorum loss.
 
       getClusterSet()
@@ -83,9 +77,16 @@ FUNCTIONS
             Resets the password of the recovery and replication accounts of the
             Cluster.
 
+      routerOptions(options)
+            Lists the configuration options of the Cluster's Routers.
+
       routingOptions([router])
             Lists the Cluster Routers configuration options.
 
+            ATTENTION: This function is deprecated and will be removed in a
+                       future release of MySQL Shell. Use
+                       Cluster.routerOptions() instead.
+
       setInstanceOption(instance, option, value)
             Changes the value of an option in a Cluster member.
 
@@ -152,25 +153,12 @@ DESCRIPTION
       - label: an identifier for the instance being added
       - recoveryMethod: Preferred method of state recovery. May be auto, clone
         or incremental. Default is auto.
-      - waitRecovery: Integer value to indicate if the command shall wait for
-        the recovery process to finish and its verbosity level. Deprecated.
       - recoveryProgress: Integer value to indicate the recovery process
         verbosity level.
-      - password: the instance connection password. Deprecated.
-      - memberSslMode: SSL mode used on the instance
-      - ipWhitelist: The list of hosts allowed to connect to the instance for
-        group replication. Deprecated.
       - ipAllowlist: The list of hosts allowed to connect to the instance for
         group replication. Only valid if communicationStack=XCOM.
       - localAddress: string value with the Group Replication local address to
         be used instead of the automatically generated one.
-      - groupSeeds: string value with a comma-separated list of the Group
-        Replication peer addresses to be used instead of the automatically
-        generated one. Deprecated and ignored.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - exitStateAction: string value indicating the group replication exit
         state action.
       - memberWeight: integer value with a percentage weight for automatic
@@ -178,15 +166,12 @@ DESCRIPTION
       - autoRejoinTries: integer value to define the number of times an
         instance will attempt to rejoin the cluster after being expelled.
       - certSubject: instance's certificate subject to use when
-        'memberAuthType' contains "CERT_SUBJECT".
+        'memberAuthType' contains "CERT_SUBJECT" or "CERT_SUBJECT_PASSWORD".
 
       The label must be non-empty and no greater than 256 characters long. It
       must be unique within the Cluster and can only contain alphanumeric, _
       (underscore), . (period), - (hyphen), or : (colon) characters.
 
-      The password may be contained on the instance definition, however, it can
-      be overwritten if it is specified on the options.
-
       The recoveryMethod option supports the following values:
 
       - incremental: uses distributed state recovery, which applies missing
@@ -203,26 +188,12 @@ DESCRIPTION
         forward. If interaction is disabled, the operation will be canceled
         instead.
 
-      The waitRecovery option supports the following values:
-
-      - 0: do not wait and let the recovery process to finish in the
-        background.
-      - 1: block until the recovery process to finishes.
-      - 2: block until the recovery process finishes and show progress
-        information.
-      - 3: block until the recovery process finishes and show progress using
-        progress bars.
-
       The recoveryProgress option supports the following values:
 
       - 0: do not show any progress information.
       - 1: show detailed static progress information.
       - 2: show detailed dynamic progress information using progress bars.
 
-      By default, if the standard output on which the Shell is running refers
-      to a terminal, the waitRecovery option has the value of 3. Otherwise, it
-      has the value of 2.
-
       The exitStateAction option supports the following values:
 
       - ABORT_SERVER: if used, the instance shuts itself down if it leaves the
@@ -234,7 +205,8 @@ DESCRIPTION
         it leaves the cluster unintentionally or exhausts its auto-rejoin
         attempts. Requires MySQL 8.0.18 or newer.
 
-      If exitStateAction is not specified READ_ONLY will be used by default.
+      If exitStateAction is not specified, it defaults to OFFLINE_MODE for
+      server versions 8.4.0 or newer, and READ_ONLY otherwise.
 
       The ipAllowlist format is a comma separated list of IP addresses or
       subnet CIDR notation, for example: 192.168.1.0/24,10.0.0.1. By default
@@ -260,10 +232,6 @@ DESCRIPTION
       stack is 'XCOM'. In case the automatically determined  default port value
       is invalid (> 65535) then an error is thrown.
 
-      The groupSeeds option is deprecated as of MySQL Shell 8.0.28 and is
-      ignored. 'group_replication_group_seeds' is automatically set based on
-      the current topology.
-
       The value for exitStateAction is used to configure how Group Replication
       behaves when a server instance leaves the group unintentionally (for
       example after encountering an applier error) or exhausts its auto-rejoin
@@ -276,7 +244,8 @@ DESCRIPTION
       option accepts case-insensitive string values, being the accepted values:
       OFFLINE_MODE (or 2), ABORT_SERVER (or 1) and READ_ONLY (or 0).
 
-      The default value is READ_ONLY.
+      The default value is OFFLINE_MODE for server versions 8.4.0 or newer, and
+      READ_ONLY otherwise.
 
       The value for memberWeight is used to set the Group Replication system
       variable 'group_replication_member_weight'. The memberWeight option
@@ -293,65 +262,6 @@ DESCRIPTION
       the expelled node back to the group. The autoRejoinTries option accepts
       positive integer values and, since 8.0.21, defaults to 3.
 
-      ATTENTION: The memberSslMode option will be removed in a future release.
-
-      ATTENTION: The ipWhitelist option will be removed in a future release.
-                 Please use the ipAllowlist option instead.
-
-      ATTENTION: The groupSeeds option will be removed in a future release.
-
-      ATTENTION: The waitRecovery option will be removed in a future release.
-                 Please use the recoveryProgress option instead.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
-//@<OUT> Check Instance State
-NAME
-      checkInstanceState - Verifies the instance gtid state in relation to the
-                           cluster.
-
-SYNTAX
-      <Cluster>.checkInstanceState(instance)
-
-WHERE
-      instance: An instance definition.
-
-RETURNS
-      resultset A JSON object with the status.
-
-DESCRIPTION
-      ATTENTION: This function is deprecated and will be removed in a future
-                 release of MySQL Shell.
-
-      Analyzes the instance executed GTIDs with the executed/purged GTIDs on
-      the cluster to determine if the instance is valid for the cluster.
-
-      The instance definition is the connection data for the instance.
-
-      For additional information on connection data use \? connection.
-
-      The returned JSON object contains the following attributes:
-
-      - state: the state of the instance
-      - reason: the reason for the state reported
-
-      The state of the instance can be one of the following:
-
-      - ok: if the instance transaction state is valid for the cluster
-      - error: if the instance transaction state is not valid for the cluster
-
-      The reason for the state reported can be one of the following:
-
-      - new: if the instance doesn't have any transactions
-      - recoverable:  if the instance executed GTIDs are not conflicting with
-        the executed GTIDs of the cluster instances
-      - diverged: if the instance executed GTIDs diverged with the executed
-        GTIDs of the cluster instances
-      - lost_transactions: if the instance has more executed GTIDs than the
-        executed GTIDs of the cluster instances
-
 //@<OUT> Describe
 NAME
       describe - Describe the structure of the Cluster.
@@ -424,10 +334,6 @@ DESCRIPTION
         be executed, even if some members of the cluster cannot be reached or
         the timeout was reached when waiting for members to catch up with
         replication changes. By default, set to false.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
 
       The force option (set to true) must only be used to dissolve a cluster
       with instances that are permanently not available (no longer reachable)
@@ -437,18 +343,15 @@ DESCRIPTION
       and the cluster dissolved without the force option to avoid errors trying
       to reuse the instances and add them back to a cluster.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> Force Quorum Using Partition Of
 NAME
       forceQuorumUsingPartitionOf - Restores the cluster from quorum loss.
 
 SYNTAX
-      <Cluster>.forceQuorumUsingPartitionOf(instance[, password])
+      <Cluster>.forceQuorumUsingPartitionOf(instance)
 
 WHERE
       instance: An instance definition to derive the forced group from.
-      password: String with the password for the connection. Deprecated.
 
 RETURNS
       Nothing.
@@ -471,8 +374,6 @@ DESCRIPTION
       point of view of the given instance definition will be added to the
       group.
 
-      ATTENTION: The password option will be removed in a future release.
-
 //@<OUT> Get Name
 NAME
       getName - Retrieves the name of the cluster.
@@ -600,18 +501,10 @@ DESCRIPTION
 
       The options dictionary may contain the following attributes:
 
-      - password: the instance connection password. Deprecated.
       - recoveryMethod: Preferred method of state recovery. May be auto, clone
         or incremental. Default is auto.
       - recoveryProgress: Integer value to indicate the recovery process
         verbosity level. recovery process to finish and its verbosity level.
-      - memberSslMode: SSL mode used on the instance
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
-      - ipWhitelist: The list of hosts allowed to connect to the instance for
-        group replication. Deprecated.
       - ipAllowlist: The list of hosts allowed to connect to the instance for
         group replication. Only valid if communicationStack=XCOM.
       - localAddress: string value with the Group Replication local address to
@@ -625,9 +518,6 @@ DESCRIPTION
         established. If reached, the operation is rolled-back. Default is 0 (no
         timeout). Available only for Read Replicas.
 
-      The password may be contained on the instance definition, however, it can
-      be overwritten if it is specified on the options.
-
       The recoveryMethod option supports the following values:
 
       - incremental: uses distributed state recovery, which applies missing
@@ -680,15 +570,6 @@ DESCRIPTION
       stack is 'XCOM'. In case the automatically determined  default port value
       is invalid (> 65535) then an error is thrown.
 
-      ATTENTION: The memberSslMode option will be removed in a future release.
-
-      ATTENTION: The ipWhitelist option will be removed in a future release.
-                 Please use the ipAllowlist option instead.
-
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
 //@<OUT> Remove Instance
 NAME
       removeInstance - Removes an Instance from the cluster.
@@ -712,14 +593,9 @@ DESCRIPTION
 
       The options dictionary may contain the following attributes:
 
-      - password: the instance connection password. Deprecated.
       - force: boolean, indicating if the instance must be removed (even if
         only from metadata) in case it cannot be reached. By default, set to
         false.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - dryRun: boolean if true, all validations and steps for removing the
         instance are executed, but no changes are actually made. An exception
         will be thrown when finished.
@@ -727,9 +603,6 @@ DESCRIPTION
         with the PRIMARY. If reached, the operation is rolled-back. Default is
         0 (no timeout).
 
-      The password may be contained in the instance definition, however, it can
-      be overwritten if it is specified on the options.
-
       The force option (set to true) must only be used to remove instances that
       are permanently not available (no longer reachable) or never to be reused
       again in a cluster. This allows to remove from the metadata an instance
@@ -737,10 +610,6 @@ DESCRIPTION
       back ONLINE and removed without the force option to avoid errors trying
       to add it back to a cluster.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
-      ATTENTION: The password option will be removed in a future release.
-
 //@<OUT> SetInstanceOption
 NAME
       setInstanceOption - Changes the value of an option in a Cluster member.
@@ -789,7 +658,8 @@ DESCRIPTION
         it leaves the cluster unintentionally or exhausts its auto-rejoin
         attempts. Requires MySQL 8.0.18 or newer.
 
-      If exitStateAction is not specified READ_ONLY will be used by default.
+      If exitStateAction is not specified, it defaults to OFFLINE_MODE for
+      server versions 8.4.0 or newer, and READ_ONLY otherwise.
 
       The value for exitStateAction is used to configure how Group Replication
       behaves when a server instance leaves the group unintentionally (for
@@ -803,7 +673,8 @@ DESCRIPTION
       option accepts case-insensitive string values, being the accepted values:
       OFFLINE_MODE (or 2), ABORT_SERVER (or 1) and READ_ONLY (or 0).
 
-      The default value is READ_ONLY.
+      The default value is OFFLINE_MODE for server versions 8.4.0 or newer, and
+      READ_ONLY otherwise.
 
       The value for memberWeight is used to set the Group Replication system
       variable 'group_replication_member_weight'. The memberWeight option
@@ -892,8 +763,6 @@ DESCRIPTION
         state action.
       - memberWeight: integer value with a percentage weight for automatic
         primary election on failover.
-      - failoverConsistency: string value indicating the consistency guarantees
-        that the cluster provides.
       - consistency: string value indicating the consistency guarantees that
         the cluster provides.
       - expelTimeout: integer value to define the time period in seconds that
@@ -937,9 +806,6 @@ DESCRIPTION
       and can only contain alphanumeric, _ ( underscore), . (period), or -
       (hyphen) characters.
 
-      ATTENTION: The failoverConsistency option will be removed in a future
-                 release. Please use the consistency option instead.
-
       ATTENTION: The transactionSizeLimit option is not supported on Replica
                  Clusters of InnoDB ClusterSets.
 
@@ -966,7 +832,8 @@ DESCRIPTION
         it leaves the cluster unintentionally or exhausts its auto-rejoin
         attempts. Requires MySQL 8.0.18 or newer.
 
-      If exitStateAction is not specified READ_ONLY will be used by default.
+      If exitStateAction is not specified, it defaults to OFFLINE_MODE for
+      server versions 8.4.0 or newer, and READ_ONLY otherwise.
 
       The consistency option supports the following values:
 
@@ -976,7 +843,9 @@ DESCRIPTION
       - EVENTUAL: if used, read queries to the new primary are allowed even if
         the backlog isn't applied.
 
-      If consistency is not specified, EVENTUAL will be used by default.
+      If consistency is not specified, it defaults to
+      BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or newer, and
+      EVENTUAL otherwise.
 
       The value for exitStateAction is used to configure how Group Replication
       behaves when a server instance leaves the group unintentionally (for
@@ -990,7 +859,8 @@ DESCRIPTION
       option accepts case-insensitive string values, being the accepted values:
       OFFLINE_MODE (or 2), ABORT_SERVER (or 1) and READ_ONLY (or 0).
 
-      The default value is READ_ONLY.
+      The default value is OFFLINE_MODE for server versions 8.4.0 or newer, and
+      READ_ONLY otherwise.
 
       The value for memberWeight is used to set the Group Replication system
       variable 'group_replication_member_weight'. The memberWeight option
@@ -1006,10 +876,20 @@ DESCRIPTION
       When set to BEFORE_ON_PRIMARY_FAILOVER, whenever a primary failover
       happens in single-primary mode (default), new queries (read or write) to
       the newly elected primary that is applying backlog from the old primary,
-      will be hold before execution until the backlog is applied. When set to
-      EVENTUAL, read queries to the new primary are allowed even if the backlog
-      isn't applied but writes will fail (if the backlog isn't applied) due to
-      super-read-only mode being enabled. The client may return old values.
+      will be hold before execution until the backlog is applied. Special care
+      is needed if LOCK / UNLOCK queries are used in a secondary, because the
+      UNLOCK statement can be held. This means that, if the secondary is
+      promoted, and transactions from the primary are being applied that target
+      locked tables, they won't be applied and an explicit UNLOCK will also
+      hold because the secondary needs to finish applying the transactions from
+      the previous primary. See
+      https://dev.mysql.com/doc/refman/en/group-replication-system-variables.html#sysvar_group_replication_consistency
+      for more details.
+
+      When set to EVENTUAL, read queries to the new primary are allowed even if
+      the backlog isn't applied but writes will fail (if the backlog isn't
+      applied) due to super-read-only mode being enabled. The client may return
+      old values.
 
       When set to BEFORE, each transaction (RW or RO) waits until all preceding
       transactions are complete before starting its execution. This ensures
@@ -1040,7 +920,8 @@ DESCRIPTION
       accepted values: EVENTUAL (or 0), BEFORE_ON_PRIMARY_FAILOVER (or 1),
       BEFORE (or 2), AFTER (or 3), and BEFORE_AND_AFTER (or 4).
 
-      The default value is EVENTUAL.
+      It defaults to BEFORE_ON_PRIMARY_FAILOVER for server versions 8.4.0 or
+      newer, and EVENTUAL otherwise.
 
       The value for expelTimeout is used to set the Group Replication system
       variable 'group_replication_member_expel_timeout' and configure how long
@@ -1121,10 +1002,6 @@ DESCRIPTION
       - requireCertSubject: Optional SSL certificate subject for the account.
       - dryRun: boolean value used to enable a dry run of the account setup
         process. Default value is False.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1138,16 +1015,11 @@ DESCRIPTION
       permissions to be granted to `user` account without actually creating
       and/or performing any changes to it.
 
-      The interactive option can be used to explicitly enable or disable the
-      interactive prompts that help the user through the account setup process.
-
       To change authentication options for an existing account, set `update` to
       `true`. It is possible to change password without affecting certificate
       options or vice-versa but certificate options can only be changed
       together.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> setupRouterAccount
 NAME
       setupRouterAccount - Create or upgrade a MySQL account to use with MySQL
@@ -1186,10 +1058,6 @@ DESCRIPTION
       - requireCertSubject: Optional SSL certificate subject for the account.
       - dryRun: boolean value used to enable a dry run of the account setup
         process. Default value is False.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1203,16 +1071,11 @@ DESCRIPTION
       permissions to be granted to `user` account without actually creating
       and/or performing any changes to it.
 
-      The interactive option can be used to explicitly enable or disable the
-      interactive prompts that help the user through the account setup process.
-
       To change authentication options for an existing account, set `update` to
       `true`. It is possible to change password without affecting certificate
       options or vice-versa but certificate options can only be changed
       together.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> Rescan
 NAME
       rescan - Rescans the cluster.
@@ -1236,17 +1099,9 @@ DESCRIPTION
       - addInstances: List with the connection data of the new active instances
         to add to the metadata, or "auto" to automatically add missing
         instances to the metadata. Deprecated.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
       - removeInstances: List with the connection data of the obsolete
         instances to remove from the metadata, or "auto" to automatically
         remove obsolete instances from the metadata. Deprecated.
-      - updateTopologyMode: boolean value used to indicate if the topology mode
-        (single-primary or multi-primary) in the metadata should be updated
-        (true) or not (false) to match the one being used by the cluster. By
-        default, the metadata is not updated (false). Deprecated.
       - upgradeCommProtocol: boolean. Set to true to upgrade the Group
         Replication communication protocol to the highest version possible.
       - updateViewChangeUuid: boolean value used to indicate if the command
@@ -1259,6 +1114,8 @@ DESCRIPTION
       - removeObsolete: set to true to automatically remove all obsolete
         instances, i.e. no longer part of the replication topology, from the
         metadata. Defaults to false.
+      - repairMetadata: boolean. Set to true to repair the Metadata if detected
+        to be inconsistent.
 
       The value for addInstances and removeInstances is used to specify which
       instances to add or remove from the metadata, respectively. Both options
@@ -1266,10 +1123,10 @@ DESCRIPTION
       for both options in order to automatically add or remove the instances in
       the metadata, without having to explicitly specify them.
 
-      ATTENTION: The updateTopologyMode option will be removed in a future
-                 release.
-
-      ATTENTION: The interactive option will be removed in a future release.
+      'repairMetadata' is used to eliminate any inconsistencies detected in the
+      Metadata. These inconsistencies may arise from a few scenarios, such as
+      the failure of one or more commands. Clusters detected in the ClusterSet
+      Metadata that do not qualify as valid members will be removed.
 
       ATTENTION: The addInstances and removeInstances options will be removed
                  in a future release. Use addUnmanaged and removeObsolete
@@ -1294,11 +1151,6 @@ DESCRIPTION
       gathered and returned.
 
       - extended: verbosity level of the command output.
-      - queryMembers: if true, connect to each Instance of the Cluster to query
-        for more detailed stats about the replication machinery.
-
-      ATTENTION: The queryMembers option will be removed in a future release.
-                 Please use the extended option instead.
 
       The extended option supports Integer or Boolean values:
 
@@ -1415,10 +1267,6 @@ DESCRIPTION
         error occurs when trying to reset the passwords on any of the
         instances, for example if any of them is not online. By default, set to
         false.
-      - interactive: boolean value used to disable/enable the wizards in the
-        command execution, i.e. prompts and confirmations will be provided or
-        not according to the value set. The default value is equal to MySQL
-        Shell wizard mode. Deprecated.
 
       The use of the force option (set to true) is not recommended. Use it only
       if really needed when instances are permanently not available (no longer
@@ -1426,8 +1274,6 @@ DESCRIPTION
       bring the non available instances back ONLINE or remove them from the
       cluster if they will no longer be used.
 
-      ATTENTION: The interactive option will be removed in a future release.
-
 //@<OUT> createClusterSet
 NAME
       createClusterSet - Creates a MySQL InnoDB ClusterSet from an existing
@@ -1661,6 +1507,8 @@ DESCRIPTION
         timeout).
       - cloneDonor: The Cluster member to be used as donor when performing
         clone-based recovery.
+      - certSubject: instance's certificate subject to use when
+        'memberAuthType' contains "CERT_SUBJECT" or "CERT_SUBJECT_PASSWORD".
 
       The label must be non-empty and no greater than 256 characters long. It
       must be unique within the Cluster and can only contain alphanumeric, _
@@ -1718,9 +1566,45 @@ RETURNS
       instances of the Cluster and its global options or just the given Router.
 
 DESCRIPTION
+      ATTENTION: This function is deprecated and will be removed in a future
+                 release of MySQL Shell. Use Cluster.routerOptions() instead.
+
       This function lists the Router configuration options of all Routers of
       the Cluster or the target Router.
 
+//@<OUT> routerOptions
+NAME
+      routerOptions - Lists the configuration options of the Cluster's Routers.
+
+SYNTAX
+      <Cluster>.routerOptions(options)
+
+WHERE
+      options: Dictionary with options for the operation.
+
+RETURNS
+      A JSON object with the list of Router configuration options.
+
+DESCRIPTION
+      This function lists the Router configuration options of the Cluster
+      (global), and the Router instances. By default, only the options that can
+      be changed from Shell (dynamic options) are displayed. Router instances
+      with different configurations than the global ones will include the
+      differences under their dedicated description.
+
+      The options dictionary may contain the following attributes:
+
+      - extended: Verbosity level of the command output.
+      - router: Identifier of the Router instance to be displayed.
+
+      The extended option supports Integer or Boolean values:
+
+      - 0: Includes only options that can be changed from Shell (default);
+      - 1: Includes all Cluster global options and, per Router, only the
+        options that have a different value than the corresponding global one.
+      - 2: Includes all Cluster and Router options.
+      - Boolean: equivalent to assign either 0 (false) or 1 (true).
+
 //@<OUT> setRoutingOption
 NAME
       setRoutingOption - Changes the value of either a global Cluster Routing
