@@ -724,15 +724,15 @@ session.runSql(`create table init_test.init_test (a int)`);
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {sessionInitSql:["set @cid=connection_id()", `insert into init_test.init_test values (@cid)`] });
 
-// ensure sessionInitSql was executed (4 threads + 1 main thread)
-EXPECT_EQ(5, session.runSql(`select * from init_test.init_test`).fetchAll().length);
+// ensure sessionInitSql was executed (4 threads + 1 main thread at least)
+EXPECT_GE(session.runSql(`select * from init_test.init_test`).fetchAll().length, 5);
 
 session.runSql("truncate init_test.init_test");
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {sessionInitSql:["set @cid=connection_id()", `insert into init_test.init_test values (@cid)`] });
 
 // ensure sessionInitSql was executed even if no data loaded (4 threads + 1 main thread)
-EXPECT_EQ(5, session.runSql(`select * from init_test.init_test`).fetchAll().length);
+EXPECT_GE(session.runSql(`select * from init_test.init_test`).fetchAll().length, 5);
 
 
 wipe_instance(session);
@@ -772,7 +772,7 @@ wipe_instance(session);
 //@<> try to load using an account with missing privs
 var grants_and_errors = [];
 
-grants_and_errors.push({ schema: "sakila", grant: "grant all on sakila.* to user@localhost with grant option", error: "ERROR: Error processing schema `sakila`: Access denied; you need (at least one of) the SUPER" });
+grants_and_errors.push({ schema: "sakila", grant: "grant all on sakila.* to user@localhost with grant option", error: "ERROR: Error processing schema `sakila`: Access denied; you need (at least one of) the " });
 grants_and_errors.push({ schema: "xtest", grant: "grant select,insert,update on xtest.* to user@localhost with grant option", error: "ERROR: Error processing schema `xtest`: Access denied for user 'user'@'localhost' to database 'xtest'" });
 grants_and_errors.push({ schema: "mysqlaas_compat", grant: "grant create,insert on mysqlaas_compat.* to user@localhost with grant option", error: "Error processing schema `mysqlaas_compat`: Access denied for user 'user'@'localhost' to database 'mysqlaas_compat'" });
 
@@ -1050,6 +1050,9 @@ session.runSql("ANALYZE TABLE sakila.payment UPDATE HISTOGRAM ON rental_id, cust
 util.dumpSchemas(["sakila"], __tmp_dir+"/ldtest/dump-sakila");
 wipe_instance(session);
 
+//@<> BUG#36197620 - summary should contain more details regarding all executed stages
+analyze_tables_summary = "tables were analyzed in ";
+
 //@<> Load everything with no analyze, indexes deferred
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {analyzeTables: "off", deferTableIndexes:"all"});
@@ -1058,6 +1061,8 @@ EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for `sakila`.`store`");
 EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for `sakila`.`inventory`");
 EXPECT_SHELL_LOG_CONTAINS("Recreating FOREIGN KEY constraints for schema `sakila`");
 
+EXPECT_OUTPUT_NOT_CONTAINS(analyze_tables_summary);
+
 //@<> Analyze only
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {analyzeTables: "on", deferTableIndexes:"off", loadData: false, loadDdl: false});
@@ -1082,6 +1087,8 @@ if(__version_num>80000) {
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`film`");
 }
 
+EXPECT_OUTPUT_CONTAINS(`16 ${analyze_tables_summary}`);
+
 //@<> Load everything without deferring indexes and analyze only for histograms
 wipe_instance(session);
 testutil.rmfile(__tmp_dir+"/ldtest/dump-sakila/load-progress*");
@@ -1096,8 +1103,12 @@ if(__version_num>80000) {
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`film`");
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`rental`");
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`payment`");
+
+  EXPECT_OUTPUT_CONTAINS(`3 ${analyze_tables_summary}`);
 } else {
   EXPECT_OUTPUT_CONTAINS("WARNING: Histogram creation enabled but MySQL Server "+__version+" does not support it.");
+
+  EXPECT_OUTPUT_NOT_CONTAINS(analyze_tables_summary);
 }
 
 //@<> Load everything with fulltext index deferment (the default)
@@ -1273,7 +1284,7 @@ check_worker_distribution(16, ntables, __tmp_dir+"/ldtest/dump2/load-progress."+
 testutil.rmfile(__tmp_dir+"/ldtest/dump2/load-progress*");
 wipe_instance(session);
 
-//@<> Load dump with GR running
+//@<> Load dump with GR running {VER(>=8.0.0)}
 
 testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
 wipe_instance(session);
@@ -1310,6 +1321,8 @@ wipe_instance(session);
 
 //@<> Try to load via xproto (should auto-switch to classic and work)
 
+testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
+
 shell.connect("mysqlx://root:root@127.0.0.1:"+__mysql_sandbox_x_port1);
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {dryRun: 1});
