@@ -212,11 +212,22 @@ OPTIONS
             Value can be either TEXT (default) or JSON.
 
 --targetVersion=<str>
-            Version to which upgrade will be checked (default=<<<__mysh_version>>>)
+            Version to which upgrade will be checked.
 
 --configPath=<str>
             Full path to MySQL server configuration file.
 
+--include=<str list>
+            Comma separated list containing the check identifiers to be
+            included in the operation.
+
+--exclude=<str list>
+            Comma separated list containing the check identifiers to be
+            excluded from the operation.
+
+--list=<bool>
+            Bool value to indicate the operation should only list the checks.
+
 //@<OUT> CLI util copy-instance --help
 NAME
       copy-instance - Copies a source instance to the target instance. Requires
@@ -285,8 +296,9 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --excludeTriggers=<str list>
@@ -489,8 +501,9 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --excludeTriggers=<str list>
@@ -675,8 +688,9 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --excludeTriggers=<str list>
@@ -785,7 +799,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -866,14 +881,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --targetVersion=<str>
             Specifies version of the destination MySQL server. Default: current
             version of Shell.
 
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -1026,7 +1048,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -1107,14 +1130,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --targetVersion=<str>
             Specifies version of the destination MySQL server. Default: current
             version of Shell.
 
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -1248,7 +1278,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "zstd".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "zstd;level=1".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -1329,14 +1360,21 @@ OPTIONS
 --compatibility=<str list>
             Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
-            "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
-            "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
+            "force_innodb", "force_non_standard_fks", "ignore_missing_pks",
+            "ignore_wildcard_grants", "skip_invalid_accounts",
+            "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
 --targetVersion=<str>
             Specifies version of the destination MySQL server. Default: current
             version of Shell.
 
+--skipUpgradeChecks=<bool>
+            Do not execute the upgrade check utility. Compatibility issues
+            related to MySQL version upgrades will not be checked. Use this
+            option only when executing the Upgrade Checker separately. Default:
+            false.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -1439,7 +1477,8 @@ OPTIONS
 
 --compression=<str>
             Compression used when writing the data dump files, one of: "none",
-            "gzip", "zstd". Default: "none".
+            "gzip", "zstd". Compression level may be specified as
+            "gzip;level=8" or "zstd;level=8". Default: "none".
 
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
@@ -1951,8 +1990,8 @@ OPTIONS
             suffixes: k (kilobytes), M (Megabytes), G (Gigabytes). Minimum
             value: 4096. If this option is not specified explicitly, the value
             of the bytesPerChunk dump option is used, but only in case of the
-            files with data size greater than 1.5 * bytesPerChunk. Default:
-            taken from dump.
+            files with data size greater than 1.5 * bytesPerChunk. Not used if
+            table is BULK LOADED. Default: taken from dump.
 
 --sessionInitSql=<str list>
             Execute the given list of SQL statements in each session about to
@@ -1970,6 +2009,10 @@ OPTIONS
             Verify tables against checksums that were computed during dump.
             Default: false.
 
+--disableBulkLoad=<bool>
+            Do not use BULK LOAD feature to load the data, even when available.
+            Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
