@@ -192,9 +192,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -210,9 +208,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -349,12 +344,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -369,12 +358,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -529,13 +512,6 @@ FUNCTIONS
             Sets number of documents to skip on the resultset when a limit has
             been defined.
 
-      skip(numberOfDocs)
-            Sets number of documents to skip on the resultset when a limit has
-            been defined.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the offset() function instead.
-
       sort(...)
             Sets the sorting criteria to be used on the DocResult.
 
@@ -553,13 +529,6 @@ FUNCTIONS
             Appends a value into an array attribute in documents of a
             collection.
 
-      array_delete(docPath)
-            Deletes the value at a specific position in an array attribute in
-            documents of a collection.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the unset() function instead.
-
       array_insert(docPath, value)
             Inserts a value into a specific position in an array attribute in
             documents of a collection.
@@ -579,13 +548,6 @@ FUNCTIONS
             Sets a limit for the documents to be updated by the operations
             added to the handler.
 
-      merge(document)
-            Adds attributes taken from a document into the documents in a
-            collection.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the patch() function instead.
-
       modify(searchCondition)
             Sets the search condition to identify the Documents to be updated
             on the owner Collection.
@@ -683,12 +645,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -710,12 +666,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -743,12 +693,6 @@ DESCRIPTION
       - Transaction handling functions
 
 PROPERTIES
-      affected_item_count
-            Same as get_affected_item_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the affected_items_count property instead.
-
       affected_items_count
             Same as get_affected_items_count
 
@@ -761,12 +705,6 @@ PROPERTIES
       generated_ids
             Same as get_generated_ids.
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -774,12 +712,6 @@ PROPERTIES
             Same as get_warnings_count
 
 FUNCTIONS
-      get_affected_item_count()
-            The the number of affected items for the last operation.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_affected_items_count function instead.
-
       get_affected_items_count()
             The the number of affected items for the last operation.
 
@@ -793,12 +725,6 @@ FUNCTIONS
       get_generated_ids()
             Returns the list of document ids generated on the server.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -832,12 +758,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -871,12 +791,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
