@@ -397,9 +397,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -415,9 +413,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -522,9 +517,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -540,9 +533,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -1414,9 +1404,7 @@ Base Connection Options
 - uri: a URI string.
 - scheme: the protocol to be used on the connection.
 - user: the MySQL user name to be used on the connection.
-- dbUser: alias for user.
 - password: the password to be used on the connection.
-- dbPassword: same as password.
 - host: the hostname or IP address to be used on the connection.
 - port: the port to be used in a TCP connection.
 - socket: the socket file name to be used on a connection through unix sockets.
@@ -1431,9 +1419,6 @@ SSH Tunnel Connection Options
 - ssh-config-file: the SSH configuration file, default is the value of
   shell.options['ssh.configFile']
 
-ATTENTION: The dbUser and dbPassword options are will be removed in a future
-           release.
-
 ATTENTION: The connection options have precedence over options specified in the
            connection options uri
 
@@ -1693,9 +1678,7 @@ Base Connection Options
 - uri: a URI string.
 - scheme: the protocol to be used on the connection.
 - user: the MySQL user name to be used on the connection.
-- dbUser: alias for user.
 - password: the password to be used on the connection.
-- dbPassword: same as password.
 - host: the hostname or IP address to be used on the connection.
 - port: the port to be used in a TCP connection.
 - socket: the socket file name to be used on a connection through unix sockets.
@@ -1710,9 +1693,6 @@ SSH Tunnel Connection Options
 - ssh-config-file: the SSH configuration file, default is the value of
   shell.options['ssh.configFile']
 
-ATTENTION: The dbUser and dbPassword options are will be removed in a future
-           release.
-
 ATTENTION: The connection options have precedence over options specified in the
            connection options uri
 
