@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -99,19 +101,16 @@ class Shell_cmdline_options : public tests::Shell_base_test {
     else if (option == "user")
       return options->connection_options().get_user();
     else if (option == "password" || option == "password1")
-      return options->connection_options().get_mfa_passwords()[0].has_value()
-                 ? std::string(
-                       *options->connection_options().get_mfa_passwords()[0])
+      return options->connection_options().has_password()
+                 ? options->connection_options().get_password()
                  : "";
     else if (option == "password2")
-      return options->connection_options().get_mfa_passwords()[1].has_value()
-                 ? std::string(
-                       *options->connection_options().get_mfa_passwords()[1])
+      return options->connection_options().has_mfa_password(1)
+                 ? options->connection_options().get_mfa_password(1)
                  : "";
     else if (option == "password3")
-      return options->connection_options().get_mfa_passwords()[2].has_value()
-                 ? std::string(
-                       *options->connection_options().get_mfa_passwords()[2])
+      return options->connection_options().has_mfa_password(2)
+                 ? options->connection_options().get_mfa_password(2)
                  : "";
     else if (option == "port")
       return AS__STRING(options->connection_options().get_port());
@@ -160,9 +159,14 @@ class Shell_cmdline_options : public tests::Shell_base_test {
     else if (option == "passwords_from_stdin")
       return AS__STRING(options->passwords_from_stdin);
     else if (option == "prompt_password")
-      return AS__STRING(options->prompt_password);
-    else if (option == "recreate_database")
-      return AS__STRING(options->recreate_database);
+      return AS__STRING(
+          options->connection_options().should_prompt_password(0));
+    else if (option == "prompt_password2")
+      return AS__STRING(
+          options->connection_options().should_prompt_password(1));
+    else if (option == "prompt_password3")
+      return AS__STRING(
+          options->connection_options().should_prompt_password(2));
     else if (option == "trace_protocol")
       return AS__STRING(options->trace_protocol);
     else if (option == "log_level")
@@ -772,13 +776,15 @@ TEST_F(Shell_cmdline_options, default_values) {
   EXPECT_EQ(options.log_level, shcore::Logger::LOG_INFO);
   EXPECT_EQ("table", options.result_format);
   EXPECT_EQ("off", options.wrap_json);
-  EXPECT_FALSE(options.connection_options().get_mfa_passwords()[0].has_value());
-  EXPECT_FALSE(options.connection_options().get_mfa_passwords()[1].has_value());
-  EXPECT_FALSE(options.connection_options().get_mfa_passwords()[2].has_value());
+  EXPECT_FALSE(options.connection_options().has_password());
+  EXPECT_FALSE(options.connection_options().has_mfa_password(1));
+  EXPECT_FALSE(options.connection_options().has_mfa_password(2));
   EXPECT_FALSE(options.passwords_from_stdin);
-  EXPECT_FALSE(options.prompt_password);
+  // prompt password1 by default
+  EXPECT_TRUE(options.connection_options().should_prompt_password(0));
+  EXPECT_FALSE(options.connection_options().should_prompt_password(1));
+  EXPECT_FALSE(options.connection_options().should_prompt_password(2));
   EXPECT_TRUE(options.protocol.empty());
-  EXPECT_FALSE(options.recreate_database);
   EXPECT_TRUE(options.run_file.empty());
   EXPECT_TRUE(!options.connection_options().has_schema());
   EXPECT_TRUE(!options.connection_options().has_scheme());
@@ -825,8 +831,6 @@ TEST_F(Shell_cmdline_options, app) {
                          !IS_NULLABLE, "schema");
   test_option_with_value("user", "u", "root", "", IS_CONNECTION_DATA,
                          !IS_NULLABLE);
-  test_option_with_value("dbuser", "u", "root", "", IS_CONNECTION_DATA,
-                         !IS_NULLABLE, "user");
 #ifdef _WIN32
   test_option_with_value("socket", "S", "/some/socket/path", "",
                          IS_CONNECTION_DATA, !IS_NULLABLE, "sock");
@@ -839,31 +843,22 @@ TEST_F(Shell_cmdline_options, app) {
   test_option_with_no_value("-C", "compress", "REQUIRED");
   test_option_with_no_value("--compress", "compress", "REQUIRED");
   test_option_with_no_value("-p", "prompt_password", "1");
+
   test_option_with_no_value("--password", "prompt_password", "1");
   test_option_with_no_value("--password1", "prompt_password", "1");
+  test_option_with_no_value("--password2", "prompt_password2", "1");
+  test_option_with_no_value("--password3", "prompt_password3", "1");
 
-  test_option_equal_value("dbpassword", "mypwd", IS_CONNECTION_DATA,
-                          "password");
   test_option_equal_value("password1", "mypwd", IS_CONNECTION_DATA, "password");
   test_option_equal_value("password2", "mypwd", IS_CONNECTION_DATA);
   test_option_equal_value("password3", "mypwd", IS_CONNECTION_DATA);
 
-  test_option_space_value("dbpassword", "mypwd", IS_CONNECTION_DATA, "password",
-                          "");
-  test_option_space_value("dbpassword", "mypwd", IS_CONNECTION_DATA,
-                          "prompt_password", "1");
   test_option_space_value("password1", "mypwd", IS_CONNECTION_DATA,
                           "prompt_password", "1");
-  test_option_space_value("password2", "mypwd", IS_CONNECTION_DATA);
-  test_option_space_value("password3", "mypwd", IS_CONNECTION_DATA);
-  test_short_option_value("dbpassword", "p", "mypwd", IS_CONNECTION_DATA,
-                          "password");
-  test_short_option_space_value("dbpassword", "p", "mypwd", IS_CONNECTION_DATA,
-                                "password", "");
-  test_short_option_space_value("dbpassword", "p", "mypwd", IS_CONNECTION_DATA,
-                                "prompt_password", "1");
-  test_option_equal_no_value("dbpassword", true);
-  test_option_with_no_value("--dbpassword", "prompt_password", "1");
+  test_option_space_value("password2", "mypwd", IS_CONNECTION_DATA,
+                          "prompt_password2", "1");
+  test_option_space_value("password3", "mypwd", IS_CONNECTION_DATA,
+                          "prompt_password3", "1");
 
   test_option_with_value("ssl-ca", "", "some_value", "", IS_CONNECTION_DATA,
                          false);
@@ -910,8 +905,6 @@ TEST_F(Shell_cmdline_options, app) {
   test_option_with_no_value("--py", "initial-mode",
                             shell_mode_name(IShell_core::Mode::Python));
 
-  test_option_with_no_value("--recreate-schema", "recreate_database", "1");
-
   test_option_with_no_value("--table", "result_format", "table");
   test_option_with_no_value("--tabbed", "result_format", "tabbed");
   test_option_with_no_value("--vertical", "result_format", "vertical");
@@ -932,7 +925,10 @@ TEST_F(Shell_cmdline_options, app) {
   test_option_equal_value("json", "raw", false, "wrap_json", "json/raw");
   test_option_equal_value("json", "off", false, "wrap_json", "off");
 
+#ifndef NDEBUG
   test_option_with_no_value("--trace-proto", "trace_protocol", "1");
+#endif
+
   test_option_with_no_value("--force", "force", "1");
   test_option_with_no_value("--interactive", "interactive", "1");
   test_option_with_no_value("-i", "interactive", "1");
@@ -1019,148 +1015,6 @@ TEST_F(Shell_cmdline_options, test_session_type_conflicts) {
   test_session_type_conflicts("mysqlx://root@localhost", "--mysql", 0);
 }
 
-TEST_F(Shell_cmdline_options, test_deprecated_arguments) {
-  std::string firstArg, secondArg;
-
-  {
-    SCOPED_TRACE("TESTING: deprecated --node argument");
-    firstArg = "root@localhost:3301";
-    secondArg = "--node";
-
-    char *argv[] = {const_cast<char *>("ut"),
-                    const_cast<char *>(firstArg.c_str()),
-                    const_cast<char *>(secondArg.c_str()), NULL};
-
-    // Redirect cout.
-    std::streambuf *cout_backup = std::cout.rdbuf();
-    std::ostringstream cout;
-    std::cout.rdbuf(cout.rdbuf());
-
-    Shell_options cmd_options(3, argv);
-
-    // Restore old cout.
-    std::cout.rdbuf(cout_backup);
-
-    EXPECT_EQ(0, cmd_options.get().exit_code);
-    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
-                 "mysqlx://root@localhost:3301");
-    MY_EXPECT_OUTPUT_CONTAINS(
-        "The --node option was deprecated, "
-        "please use --mysqlx instead. (Option has been processed "
-        "as --mysqlx).",
-        cout.str());
-  }
-
-  {
-    SCOPED_TRACE("TESTING: deprecated --classic argument");
-    firstArg = "root@localhost:3301";
-    secondArg = "--classic";
-
-    char *argv[] = {const_cast<char *>("ut"),
-                    const_cast<char *>(firstArg.c_str()),
-                    const_cast<char *>(secondArg.c_str()), NULL};
-
-    // Redirect cout.
-    std::streambuf *cout_backup = std::cout.rdbuf();
-    std::ostringstream cout;
-    std::cout.rdbuf(cout.rdbuf());
-
-    Shell_options cmd_options(3, argv);
-
-    // Restore old cout.
-    std::cout.rdbuf(cout_backup);
-
-    EXPECT_EQ(0, cmd_options.get().exit_code);
-    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
-                 "mysql://root@localhost:3301");
-    MY_EXPECT_OUTPUT_CONTAINS(
-        "The --classic option was deprecated, "
-        "please use --mysql instead. (Option has been processed as "
-        "--mysql).",
-        cout.str());
-  }
-
-  {
-    SCOPED_TRACE("TESTING: deprecated --dbpassword argument");
-    firstArg = "root@localhost:3301";
-    secondArg = "--dbpassword=pass";
-
-    char *argv[] = {const_cast<char *>("ut"),
-                    const_cast<char *>(firstArg.c_str()),
-                    const_cast<char *>(secondArg.c_str()), NULL};
-
-    // Redirect cout.
-    std::streambuf *cout_backup = std::cout.rdbuf();
-    std::ostringstream cout;
-    std::cout.rdbuf(cout.rdbuf());
-
-    Shell_options cmd_options(3, argv);
-
-    // Restore old cout.
-    std::cout.rdbuf(cout_backup);
-
-    EXPECT_EQ(0, cmd_options.get().exit_code);
-    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
-                 "root@localhost:3301");
-    MY_EXPECT_OUTPUT_CONTAINS(
-        "The --dbpassword option was deprecated, please use --password "
-        "instead.",
-        cout.str());
-  }
-
-  {
-    SCOPED_TRACE("TESTING: deprecated --dbuser argument");
-    firstArg = "root@localhost:3301";
-    secondArg = "--dbuser=root";
-
-    char *argv[] = {const_cast<char *>("ut"),
-                    const_cast<char *>(firstArg.c_str()),
-                    const_cast<char *>(secondArg.c_str()), NULL};
-
-    // Redirect cout.
-    std::streambuf *cout_backup = std::cout.rdbuf();
-    std::ostringstream cout;
-    std::cout.rdbuf(cout.rdbuf());
-
-    Shell_options cmd_options(3, argv);
-
-    // Restore old cout.
-    std::cout.rdbuf(cout_backup);
-
-    EXPECT_EQ(0, cmd_options.get().exit_code);
-    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
-                 "root@localhost:3301");
-    MY_EXPECT_OUTPUT_CONTAINS(
-        "The --dbuser option was deprecated, please use --user instead.",
-        cout.str());
-  }
-  {
-    SCOPED_TRACE("TESTING: deprecated --recreate-schema argument");
-    firstArg = "root@localhost:3301/some-schema";
-    secondArg = "--recreate-schema";
-
-    char *argv[] = {const_cast<char *>("ut"),
-                    const_cast<char *>(firstArg.c_str()),
-                    const_cast<char *>(secondArg.c_str()), NULL};
-
-    // Redirect cout.
-    std::streambuf *cout_backup = std::cout.rdbuf();
-    std::ostringstream cout;
-    std::cout.rdbuf(cout.rdbuf());
-
-    Shell_options cmd_options(3, argv);
-
-    // Restore old cout.
-    std::cout.rdbuf(cout_backup);
-
-    EXPECT_EQ(0, cmd_options.get().exit_code);
-    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
-                 "root@localhost:3301/some-schema");
-    MY_EXPECT_OUTPUT_CONTAINS("The --recreate-schema option was deprecated.",
-                              cout.str());
-  }
-}
-
 TEST_F(Shell_cmdline_options, test_positional_argument) {
   // Redirect cerr.
   std::streambuf *backup = std::cerr.rdbuf();
@@ -1535,66 +1389,6 @@ TEST_F(Shell_cmdline_options, test_uri_with_password) {
   std::cerr.rdbuf(backup);
 }
 
-TEST_F(Shell_cmdline_options, test_deprecated_ssl) {
-  std::string warning =
-      "The --ssl option was deprecated, please use --ssl-mode instead. ";
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl"),
-                                   const_cast<char *>("something"), NULL};
-
-    std::string error =
-        "--ssl-mode must be any of [DISABLED, PREFERRED, REQUIRED, VERIFY_CA, "
-        "VERIFY_IDENTITY]\n";
-
-    test_deprecated_ssl("--ssl=something", &options, "", error, 1,
-                        mysqlshdk::db::Ssl_mode::Preferred);
-    // This last param is
-    // ignored on this case
-  }
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl"), NULL};
-    std::string mywarning(warning);
-    mywarning.append("(Option has been processed as --ssl-mode=REQUIRED).");
-    test_deprecated_ssl("--ssl", &options, mywarning, "", 0,
-                        mysqlshdk::db::Ssl_mode::Required);
-  }
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl=1"), NULL};
-    std::string mywarning(warning);
-    mywarning.append("(Option has been processed as --ssl-mode=REQUIRED).");
-    test_deprecated_ssl("--ssl=1", &options, mywarning, "", 0,
-                        mysqlshdk::db::Ssl_mode::Required);
-  }
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl=yes"), NULL};
-    std::string mywarning(warning);
-    mywarning.append("(Option has been processed as --ssl-mode=REQUIRED).");
-    test_deprecated_ssl("--ssl=yes", &options, mywarning, "", 0,
-                        mysqlshdk::db::Ssl_mode::Required);
-  }
-
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl=0"), NULL};
-    std::string mywarning(warning);
-    mywarning.append("(Option has been processed as --ssl-mode=DISABLED).");
-    test_deprecated_ssl("--ssl=0", &options, mywarning, "", 0,
-                        mysqlshdk::db::Ssl_mode::Disabled);
-  }
-  {
-    std::vector<char *> options = {const_cast<char *>("ut"),
-                                   const_cast<char *>("--ssl=no"), NULL};
-    std::string mywarning(warning);
-    mywarning.append("(Option has been processed as --ssl-mode=DISABLED).");
-    test_deprecated_ssl("--ssl=no", &options, mywarning, "", 0,
-                        mysqlshdk::db::Ssl_mode::Disabled);
-  }
-}
-
 TEST_F(Shell_cmdline_options, dict_access_for_named_options) {
   Shell_options options(0, nullptr);
 
@@ -1755,8 +1549,10 @@ TEST_F(Shell_cmdline_options, mfa_tests) {
     EXPECT_NO_THROW(so.get().connection_options());
   }
   {
-    char *passwords[] = {const_cast<char *>("--password2=whatever"),
-                         const_cast<char *>("--password3=whatever")};
+    char password2[] = "--password2=whatever";
+    char password3[] = "--password3=whatever";
+    char *passwords[] = {const_cast<char *>(password2),
+                         const_cast<char *>(password3)};
     char *x_proto_args[] = {const_cast<char *>("--mysqlx"),
                             const_cast<char *>("--mx"),
                             const_cast<char *>("--sqlx")};
@@ -1876,7 +1672,9 @@ socket=/sock/et
     EXPECT_NO_THROW(so.get().connection_options());
 
     EXPECT_EQ(3232, so.get().connection_options().get_port());
-    EXPECT_FALSE(so.get().connection_options().has_socket());
+    // socket setting must remain set, but it won't be active because the
+    // transport becomes TCP
+    EXPECT_TRUE(so.get().connection_options().has_socket());
   }
 
   {
@@ -1932,7 +1730,7 @@ port=3232
     EXPECT_EQ(0, so.get().exit_code);
     EXPECT_NO_THROW(so.get().connection_options());
 
-    EXPECT_FALSE(so.get().connection_options().has_port());
+    EXPECT_TRUE(so.get().connection_options().has_port());
     EXPECT_EQ("/tmp/sock", so.get().connection_options().get_socket());
   }
 
@@ -1950,4 +1748,327 @@ port=3232
   }
 }
 
+TEST_F(Shell_cmdline_options, force_password_prompt) {
+  // force password prompt
+  // override port with socket
+  make_mycnf(R"*([mysqlsh]
+user=rooot
+host=localhost
+port=3232
+password=bla
+)*");
+
+  {
+    char uri[] = "root@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), &defaults_file[0], uri,
+                     const_cast<char *>("-p"), NULL};
+    Shell_options so(4, argv0, "",
+                     mysqlsh::Shell_options::Option_flags_set(
+                         mysqlsh::Shell_options::Option_flags::READ_MYCNF));
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), &defaults_file[0], uri,
+                     const_cast<char *>("--password"), NULL};
+    Shell_options so(4, argv0, "",
+                     mysqlsh::Shell_options::Option_flags_set(
+                         mysqlsh::Shell_options::Option_flags::READ_MYCNF));
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  {
+    char uri[] = "root:badpass@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), uri, const_cast<char *>("-p"),
+                     NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  {
+    char uri[] = "root:goodpass@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), const_cast<char *>("-p"), uri,
+                     NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+
+  {
+    char uri[] = "root@localhost";
+    char goodpass[] = "-pgoodpass";
+    char *argv0[] = {const_cast<char *>("ut"), goodpass,
+                     const_cast<char *>("-p"), uri, NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char goodpass[] = "-pgoodpass";
+    char *argv0[] = {const_cast<char *>("ut"), const_cast<char *>("-p"),
+                     goodpass, uri, NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char goodpass[] = "-pgoodpass";
+    char *argv0[] = {const_cast<char *>("ut"), const_cast<char *>("-p"), uri,
+                     goodpass, NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+
+  {
+    char uri[] = "root:goodpass@localhost";
+    char badpass[] = "-pbadpass";
+    char *argv0[] = {const_cast<char *>("ut"), badpass, uri, NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+  {
+    char uri[] = "root:baddpass@localhost";
+    char badpass[] = "-pbadpass";
+    char *argv0[] = {const_cast<char *>("ut"), badpass, uri,
+                     const_cast<char *>("-p"), NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  // mfa
+  {
+    char uri[] = "root:goodpass@localhost";
+    char *argv0[] = {const_cast<char *>("ut"),
+                     const_cast<char *>("--password2"), uri, NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(1));
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(2));
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+  {
+    char uri[] = "root:goodpass@localhost";
+    char *argv0[] = {const_cast<char *>("ut"),
+                     const_cast<char *>("--password3"), uri, NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(1));
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(2));
+    EXPECT_EQ("goodpass", so.get().connection_options().get_password());
+  }
+}
+
+TEST_F(Shell_cmdline_options, no_password) {
+  make_mycnf(R"*([mysqlsh]
+user=rooot
+host=localhost
+port=3232
+password=bla
+)*");
+  {
+    char uri[] = "root@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), &defaults_file[0], uri,
+                     const_cast<char *>("--no-password"), NULL};
+    Shell_options so(4, argv0, "",
+                     mysqlsh::Shell_options::Option_flags_set(
+                         mysqlsh::Shell_options::Option_flags::READ_MYCNF));
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(1));
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(2));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(1));
+    EXPECT_FALSE(so.get().connection_options().has_mfa_password(2));
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char badpass[] = "-pbadpass";
+    char *argv0[] = {const_cast<char *>("ut"), uri, badpass,
+                     const_cast<char *>("--no-password"), NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char badpass[] = "-pbadpass";
+    char *argv0[] = {const_cast<char *>("ut"), uri,
+                     const_cast<char *>("--no-password"), badpass, NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("badpass", so.get().connection_options().get_password());
+  }
+
+  {
+    char uri[] = "root@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), uri,
+                     const_cast<char *>("--no-password"),
+                     const_cast<char *>("-p"), NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_FALSE(so.get().connection_options().has_password());
+  }
+  {
+    char uri[] = "root@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), uri, const_cast<char *>("-p"),
+                     const_cast<char *>("--no-password"), NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+
+  // no password and empty password
+  {
+    char uri[] = "root@localhost";
+    char emptypass[] = "--password=";
+    char *argv0[] = {const_cast<char *>("ut"), uri,
+                     const_cast<char *>("--no-password"), emptypass, NULL};
+    Shell_options so(4, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+
+  // no password and URI empty password
+  {
+    char uri[] = "root:@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), uri,
+                     const_cast<char *>("--no-password"), NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+
+  // no password and URI password
+  {
+    char uri[] = "root:pass@localhost";
+    char *argv0[] = {const_cast<char *>("ut"), uri,
+                     const_cast<char *>("--no-password"), NULL};
+    Shell_options so(3, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+    EXPECT_TRUE(so.get().connection_options().has_password());
+    EXPECT_EQ("", so.get().connection_options().get_password());
+  }
+}
+
+TEST_F(Shell_cmdline_options, password_prompt_default) {
+  // don't prompt for password if no connection options specified
+  {
+    char *argv0[] = {const_cast<char *>("ut"), NULL};
+    Shell_options so(1, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+    EXPECT_FALSE(so.get().has_connection_data());
+    EXPECT_FALSE(so.get().has_connection_data(true));
+    // this should not be relevant because has_connection_data() is called 1st
+    // EXPECT_FALSE(so.get().connection_options().should_prompt_password(0));
+  }
+  // prompt if prompt specifically requested
+  {
+    char *argv0[] = {const_cast<char *>("ut"), const_cast<char *>("-p"), NULL};
+    Shell_options so(2, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+  }
+
+  // prompt if there's any connection option
+  {
+    char *argv0[] = {const_cast<char *>("ut"), const_cast<char *>("-uroot"),
+                     NULL};
+    Shell_options so(2, argv0, "", {});
+    EXPECT_EQ(0, so.get().exit_code);
+    EXPECT_NO_THROW(so.get().connection_options());
+
+    EXPECT_TRUE(so.get().connection_options().should_prompt_password(0));
+  }
+}
+
 }  // namespace shcore
