@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -984,6 +986,11 @@ class Shell_prompt_exe : public tests::Command_line_test {
                         "{\"segments\":[{\"text\":\"ALT_PROMPT\"}]}");
     shcore::create_file("badprompt.json",
                         "\"segments\":[{\"text\":\"ALT_PROMPT\"}]}");
+
+    s_prompt_dir = shcore::path::join_path(::getenv("TMPDIR"), "test-prompt");
+    shcore::copy_dir(
+        shcore::path::join_path(shcore::get_share_folder(), "prompt"),
+        s_prompt_dir);
   }
 
   static void TearDownTestCase() {
@@ -991,15 +998,17 @@ class Shell_prompt_exe : public tests::Command_line_test {
         shcore::path::join_path(shcore::get_user_config_path(), "prompt.json"));
     shcore::delete_file("altprompt.json");
     shcore::delete_file("badprompt.json");
+    shcore::remove_directory(s_prompt_dir);
   }
+
+ protected:
+  static std::string s_prompt_dir;
 };
 
+std::string Shell_prompt_exe::s_prompt_dir;
+
 TEST_F(Shell_prompt_exe, environment) {
-#ifdef HAVE_V8
-  const auto expect_prompt = "mysql-js>";
-#else
-  const auto expect_prompt = "mysql-py>";
-#endif
+  const auto expect_prompt = "mysql-sql>";
   std::string no_theme_prompt = expect_prompt;
 
   // by default this prompt is not necessarily the same as expect_prompt
@@ -1013,7 +1022,7 @@ TEST_F(Shell_prompt_exe, environment) {
   // TS_CP#1 set MYSQLSH_PROMPT_THEME environment variable to a file name , it
   // configures prompt correctly accordingly to file
   shcore::setenv("MYSQLSH_PROMPT_THEME", "altprompt.json");
-  execute({_mysqlsh, "--interactive=full", "-e", "1", nullptr});
+  execute({_mysqlsh, "--interactive=full", "--js", "-e", "1", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("ALT_PROMPT> 1\n1\nALT_PROMPT> ");
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
 
@@ -1048,7 +1057,7 @@ TEST_F(Shell_prompt_exe, environment) {
 TEST_F(Shell_prompt_exe, histignore) {
   // TS_CLO#1  (combined with other tests in Cmdline_shell)
   // TS_CLO#2
-  execute({_mysqlsh, "--histignore=foobar", "-e",
+  execute({_mysqlsh, "--histignore=foobar", "--js", "-e",
            "print(shell.options['history.sql.ignorePattern']);", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("foobar");
 }
@@ -1185,124 +1194,90 @@ TEST_F(Shell_prompt_exe, prompt_variables) {
 
 // Test sample prompts (which in turn would test the whole thing)
 TEST_F(Shell_prompt_exe, sample_prompt_theme_nocolor) {
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_nocolor.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_nocolor.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "nocolor");
 
   int rc =
       execute({_mysqlsh, "--interactive=full", _uri.c_str(), "--schema=mysql",
-               "--ssl-mode=REQUIRED", "-e", "1", nullptr});
+               "--ssl-mode=REQUIRED", "-e", "\\history", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
-#ifdef HAVE_V8
-  EXPECT_PROMPT("MySQL [" + _host + ":" + _port + "+ ssl/mysql] JS> ");
-#else
-  EXPECT_PROMPT("MySQL [" + _host + ":" + _port + "+ ssl/mysql] Py> ");
-#endif
+
+  EXPECT_PROMPT("MySQL [" + _host + ":" + _port + "+ ssl/mysql] SQL> ");
 
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
 }
 
 TEST_F(Shell_prompt_exe, sample_prompt_theme_16) {
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_16.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_16.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "16");
 
   int rc =
       execute({_mysqlsh, "--interactive=full", _uri.c_str(), "--schema=mysql",
-               "--ssl-mode=REQUIRED", "-e", "1", nullptr});
+               "--ssl-mode=REQUIRED", "-e", "\\history", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_V8
-  EXPECT_PROMPT("MySQL \x1B[1m[" + _host + "+ ssl/mysql] \x1B[0mJS> ");
-#else
-  EXPECT_PROMPT("MySQL \x1B[1m[" + _host + "+ ssl/mysql] \x1B[0mPy> ");
-#endif
+  EXPECT_PROMPT("MySQL \x1B[1m[" + _host + "+ ssl/mysql] \x1B[0mSQL> ");
 
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
 }
 
 TEST_F(Shell_prompt_exe, sample_prompt_theme_256) {
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_256.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_256.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "256");
 
   int rc =
       execute({_mysqlsh, "--interactive=full", _uri.c_str(), "--schema=mysql",
-               "--ssl-mode=REQUIRED", "-e", "1", nullptr});
+               "--ssl-mode=REQUIRED", "-e", "\\history", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_V8
   EXPECT_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
       _host + ":" + _port +
-      "+ ssl "
-      "\x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
-      "\x1B[0m\x1B[48;5;221m\x1B[38;5;0m JS \x1B[0m\x1B[48;5;0m> \x1B[0m");
-#else
-  EXPECT_PROMPT(
-      "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
-      "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
-      _host + ":" + _port +
-      "+ ssl "
-      "\x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
-      "\x1B[0m\x1B[48;5;25m\x1B[38;5;15m Py \x1B[0m\x1B[48;5;0m> \x1B[0m");
-#endif
+      "+ ssl \x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
+      "\x1B[0m\x1B[48;5;166m\x1B[38;5;15m SQL \x1B[0m\x1B[48;5;0m> \x1B[0m");
 
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
 }
 
 TEST_F(Shell_prompt_exe, sample_prompt_theme_dbl_256) {
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_dbl_256.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_dbl_256.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "256");
 
   int rc =
       execute({_mysqlsh, "--interactive=full", _uri.c_str(), "--schema=mysql",
-               "--ssl-mode=REQUIRED", "-e", "1", nullptr});
+               "--ssl-mode=REQUIRED", "-e", "\\history", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_V8
   EXPECT_DBL_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
       _host + ":" + _port +
-      "+ ssl "
-      "\x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
-      "\x1B[0m\x1B[48;5;221m\x1B[38;5;0m JS \x1B[0m\n\x1B[48;5;0m  > \x1B[0m");
-#else
-  EXPECT_DBL_PROMPT(
-      "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
-      "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
-      _host + ":" + _port +
-      "+ ssl "
-      "\x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
-      "\x1B[0m\x1B[48;5;25m\x1B[38;5;15m Py \x1B[0m\n\x1B[48;5;0m  > \x1B[0m");
-#endif
+      "+ ssl \x1B[0m\x1B[48;5;242m\x1B[38;5;15m mysql "
+      "\x1B[0m\x1B[48;5;166m\x1B[38;5;15m SQL \x1B[0m\n\x1B[48;5;0m  > "
+      "\x1B[0m");
 
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
 }
 
 TEST_F(Shell_prompt_exe, sample_prompt_theme_256pl) {
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_256pl.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_256pl.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "256");
 
   int rc =
       execute({_mysqlsh, "--interactive=full", _uri.c_str(), "--schema=mysql",
-               "--ssl-mode=REQUIRED", "-e", "1", nullptr});
+               "--ssl-mode=REQUIRED", "-e", "\\history", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_V8
   EXPECT_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[48;5;237m\x1B[38;5;254m\xEE\x82\xB0\x1B[0m\x1B[48;5;237m\x1B[38;5;"
@@ -1311,20 +1286,8 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_256pl) {
       "+ \xEE\x82\xA2 "
       "\x1B[48;5;242m\x1B[38;5;237m\xEE\x82\xB0\x1B[0m\x1B[48;5;242m\x1B[38;5;"
       "15m mysql "
-      "\x1B[48;5;221m\x1B[38;5;242m\xEE\x82\xB0\x1B[0m\x1B[48;5;221m\x1B[38;5;"
-      "0m JS \x1B[0m\x1B[48;5;0m\x1B[38;5;221m\xEE\x82\xB0 \x1B[0m");
-#else
-  EXPECT_PROMPT(
-      "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
-      "\x1B[48;5;237m\x1B[38;5;254m\xEE\x82\xB0\x1B[0m\x1B[48;5;237m\x1B[38;5;"
-      "15m " +
-      _host + ":" + _port +
-      "+ \xEE\x82\xA2 "
-      "\x1B[48;5;242m\x1B[38;5;237m\xEE\x82\xB0\x1B[0m\x1B[48;5;242m\x1B[38;5;"
-      "15m mysql "
-      "\x1B[48;5;25m\x1B[38;5;242m\xEE\x82\xB0\x1B[0m\x1B[48;5;25m\x1B[38;5;"
-      "15m Py \x1B[0m\x1B[48;5;0m\x1B[38;5;25m\xEE\x82\xB0 \x1B[0m");
-#endif
+      "\x1B[48;5;166m\x1B[38;5;242m\xEE\x82\xB0\x1B[0m\x1B[48;5;166m\x1B[38;5;"
+      "15m SQL \x1B[0m\x1B[48;5;0m\x1B[38;5;166m\xEE\x82\xB0 \x1B[0m");
 
   shcore::unsetenv("MYSQLSH_PROMPT_THEME");
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
@@ -1333,8 +1296,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_256pl) {
 #ifdef HAVE_V8
 TEST_F(Shell_prompt_exe, bug28314383_js) {
   static constexpr auto k_file = "close.js";
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_nocolor.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_nocolor.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "nocolor");
   shcore::create_file(k_file,
                       "session.close();\n"
@@ -1366,8 +1328,7 @@ TEST_F(Shell_prompt_exe, bug28314383_js) {
 #ifdef HAVE_PYTHON
 TEST_F(Shell_prompt_exe, bug28314383_py) {
   static constexpr auto k_file = "close.py";
-  shcore::setenv("MYSQLSH_PROMPT_THEME",
-                 shcore::get_binary_folder() + "/prompt_nocolor.json");
+  shcore::setenv("MYSQLSH_PROMPT_THEME", s_prompt_dir + "/prompt_nocolor.json");
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "nocolor");
   shcore::create_file(k_file,
                       "session.close();\n"
@@ -1398,13 +1359,7 @@ TEST_F(Shell_prompt_exe, bug28314383_py) {
 
 TEST_F(Shell_prompt_exe, bug30406283) {
   const std::string prompt_file = "invalid-utf8.json";
-  const auto expect_prompt =
-#ifdef HAVE_V8
-      "mysql-js> "
-#else
-      "mysql-py> "
-#endif
-      "1";
+  const auto expect_prompt = "mysql-sql> ";
 
   shcore::setenv("MYSQLSH_PROMPT_THEME", prompt_file);
   shcore::setenv("MYSQLSH_TERM_COLOR_MODE", "nocolor");
