@@ -33,6 +33,7 @@
 #include <map>
 #include <memory>
 #include <string>
+#include <string_view>
 #include <utility>
 #include <vector>
 
@@ -137,8 +138,11 @@ class Shell_test_env : public ::testing::Test {
   void teardown_recorder();
 
   static void setup_env();
+  static mysqlshdk::utils::Version get_target_server_version() {
+    return _target_server_version;
+  }
 
-  std::string query_replace_hook(const std::string &sql);
+  std::string query_replace_hook(std::string_view sql);
   std::unique_ptr<mysqlshdk::db::IRow> set_replay_row_hook(
       const mysqlshdk::db::Connection_options &target, const std::string &sql,
       std::unique_ptr<mysqlshdk::db::IRow> source);
@@ -147,6 +151,10 @@ class Shell_test_env : public ::testing::Test {
     fprintf(stderr, "%s\n", s.c_str());
   }
 
+  static bool check_min_version_skip_test(bool skip_test = true);
+  static bool check_max_version_skip_test(
+      bool skip_test, const mysqlshdk::utils::Version &version);
+
  protected:
   static std::string _host;  //!< localhost
   static std::string _port;  //!< The port for X protocol, env:MYSQLX_PORT
@@ -197,7 +205,7 @@ class Shell_test_env : public ::testing::Test {
 
   std::map<std::string, std::string>
       _output_tokens;  //!< Tokens for string resolution
-  std::string resolve_string(const std::string &source);
+  std::string resolve_string(std::string source);
 
   void SetUp() override;
   void TearDown() override;
@@ -241,7 +249,6 @@ class Shell_test_env : public ::testing::Test {
     std::string stacktrace_at_open;
   };
 
-  bool m_remove_closed_sessions = true;
   std::list<Open_session> _open_sessions;
   bool check_open_sessions();
   void on_session_connect(std::shared_ptr<mysqlshdk::db::ISession> session);
